@@ -1,25 +1,29 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Alissa Nedossekina <alisa@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Alissa Nedossekina <alisa@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
@@ -65,7 +69,6 @@ class ToolVersion extends  JTable
 	
 	public function check() 
 	{
-		
 		if (!$this->id && trim( $this->toolname ) == '') {
 			$this->setError( JText::_('CONTRIBTOOL_ERROR_VERSION_NO_TOOLNAME') );
 			return false;
@@ -235,7 +238,7 @@ class ToolVersion extends  JTable
 
 	public function unpublish($toolid=NULL, $vid=0)
 	{
-	    	$xlog = &XFactory::getLogger();
+	    	$xlog = &Hubzero_Factory::getLogger();
 
 		if (!$toolid) {
 			return false;
@@ -260,7 +263,8 @@ class ToolVersion extends  JTable
 
 	public function save($toolid=NULL, $version='dev', $create_new = 0)
 	{
-	    	$xlog = &XFactory::getLogger();
+		die('1');
+	    	$xlog = &Hubzero_Factory::getLogger();
 
 		if(!$this->toolid) {
 			$this->toolid= $toolid;
@@ -304,7 +308,7 @@ class ToolVersion extends  JTable
 	{
 	    	if (empty($this->id))
 		{
-	    		$xlog = &XFactory::getLogger();
+	    		$xlog = &Hubzero_Factory::getLogger();
 	    		$query = "SELECT id FROM #__tool_version WHERE toolname=" . $this->_db->Quote($this->toolname) .
 		    		" AND instance=" . $this->_db->Quote($this->instance) . ";";
         		$this->_db->setQuery($query);
@@ -325,7 +329,7 @@ class ToolVersion extends  JTable
 	public function getToolVersions( $toolid, &$versions, $toolname='', $ldap=false, $exclude_dev = 0) 
 	{
 		ximport('Hubzero_Tool');
-	    	$xlog =& XFactory::getLogger();
+	    	$xlog =& Hubzero_Factory::getLogger();
 
 		$objA = new ToolAuthor( $this->_db);	
 
@@ -369,7 +373,7 @@ class ToolVersion extends  JTable
 	
 	public function getVersionInfo($id, $version='', $toolname='', $instance='', $ldap=false)
 	{
-	    	$xlog =& XFactory::getLogger();
+	    	$xlog =& Hubzero_Factory::getLogger();
 
 	    	if ($ldap) {
 		 	$xlog->logDebug("getVersionInfo() ldap read DEPRECATED");
@@ -461,7 +465,7 @@ class ToolVersion extends  JTable
 	
 	
 		// Get some needed libraries
-		//include_once( JPATH_ROOT.DS.'components'.DS.'com_resources'.DS.'resources.html.php' );
+		//include_once( JPATH_ROOT.DS.'components'.DS.'com_resources'.DS.'helpers'.DS.'html.php' );
 		$resource->tarname = $resource->alias.'-r'.$resource->revision.'.tar.gz';
 		$tarball_path = $config->get('sourcecodePath');
 		$resource->tarpath = $tarball_path.DS.$resource->alias.DS;
@@ -504,7 +508,7 @@ class ToolVersion extends  JTable
 
 	public function validToolReg(&$tool, &$err, $id, $ldap, $config, $checker=0, $result=1)
 	{
-	    	$xlog =& XFactory::getLogger();
+	    	$xlog =& Hubzero_Factory::getLogger();
 
 		if ($ldap) {
 		    	$xlog->logDebug("validToolReg() ldap read DEPRECATED");
@@ -689,4 +693,4 @@ class ToolVersion extends  JTable
 
 
 
-?>
+?>
\ No newline at end of file
