@@ -1,25 +1,29 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Shawn Rice <zooley@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Shawn Rice <zooley@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
@@ -306,7 +310,7 @@ class ToolsController
 		$mwdb =& MwUtils::getMWDBO();
 		
 		$html  = '  <tr>'.n;
-		$html .= t.'<form name="insert_host" method="GET" action="index.php">'.n;
+		$html .= t.'<form name="insert_host" method="get" action="index.php">'.n;
 		$html .= t.ToolsHtml::hInput('option',$this->_option);
 		$html .= t.ToolsHtml::hInput('admin',1);
 		$html .= t.ToolsHtml::hInput('table','host');
@@ -347,14 +351,14 @@ class ToolsController
 		$mwdb =& MwUtils::getMWDBO();
 		
 		$headers = array('Hostname','Provisions','Status','Uses','Action');
-		$op = @$_GET['op'];
-		$hostname = @$_GET['hostname'];
-		$hosttype = @$_GET['hosttype'];
-		$status = @$_GET['status'];
-		$item = @$_GET['item'];
+		$op = JRequest::getVar( 'op', '', 'get' );
+		$hostname = JRequest::getVar( 'hostname', '', 'get' );
+		$hosttype = JRequest::getVar( 'hosttype', '', 'get' );
+		$status = JRequest::getVar( 'status', '', 'get' );
+		$item = JRequest::getVar( 'item', '', 'get' );
 		
-		$filter_hostname = @$_GET['filter_hostname'];
-		$filter_hosttype = @$_GET['filter_hosttype'];
+		$filter_hostname = JRequest::getVar( 'filter_hostname', '', 'get' );
+		$filter_hosttype = JRequest::getVar( 'filter_hosttype', '', 'get' );
 		
 		switch($op)
 		{
@@ -455,22 +459,19 @@ class ToolsController
 		return $this->table($rows,$headers,'host_body','host_edit',$vars);
 	}
 
-	//----------------------------------------------------------
-	// 'type' table entries.
-	//----------------------------------------------------------
-	
 	private function type_display() 
 	{
 		// Get the middleware database
 		$mwdb =& MwUtils::getMWDBO();
 
-		$op    = @$_GET['op'];
-		$table = @$_GET['table'];
-		$name  = @$_GET['name'];
-		$value = @$_GET['value'];
-		$item  = @$_GET['item'];
-		$description = @$_GET['description'];
-		$filter_hosttype = @$_GET['filter_hosttype'];
+		$op    = JRequest::getVar( 'op', '', 'get' );
+		$table = JRequest::getVar( 'table', '', 'get' );
+		$name  = JRequest::getVar( 'name', '', 'get' );
+		$value = JRequest::getVar( 'value', '', 'get' );
+		$item  = JRequest::getVar( 'item', '', 'get' );
+		$description = JRequest::getVar( 'description', '', 'get' );
+		$filter_hosttype = JRequest::getVar( 'filter_hosttype', '', 'get' );
+		$filter_usertype = JRequest::getVar( 'filter_usertype', '', 'get' );
 
 		$headers = array('Name','Bit#','Description','References','Action');
 
@@ -648,4 +649,4 @@ class ToolsController
 		$this->_redirect = 'index.php?option='.$this->_option;
 	}
 }
-?>
+?>
\ No newline at end of file
