@@ -1,79 +1,38 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Shawn Rice <zooley@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Shawn Rice <zooley@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
 
-class ContributeController extends JObject
-{	
-	private $_name  = NULL;
-	private $_data  = array();
-	private $_task  = NULL;
+ximport('Hubzero_Controller');
 
-	//-----------
-	
-	public function __construct( $config=array() )
-	{
-		$this->_redirect = NULL;
-		$this->_message = NULL;
-		$this->_messageType = 'message';
-		
-		// Set the controller name
-		if (empty( $this->_name )) {
-			if (isset($config['name'])) {
-				$this->_name = $config['name'];
-			} else {
-				$r = null;
-				if (!preg_match('/(.*)Controller/i', get_class($this), $r)) {
-					echo "Controller::__construct() : Can't get or parse class name.";
-				}
-				$this->_name = strtolower( $r[1] );
-			}
-		}
-		
-		// Set the component name
-		$this->_option = 'com_'.$this->_name;
-	}
-
-	//-----------
-
-	public function __set($property, $value)
-	{
-		$this->_data[$property] = $value;
-	}
-	
-	//-----------
-	
-	public function __get($property)
-	{
-		if (isset($this->_data[$property])) {
-			return $this->_data[$property];
-		}
-	}
-	
-	//-----------
-	
+class ContributeController extends Hubzero_Controller
+{
 	public function execute()
 	{
 		$this->steps = array('Type','Compose','Attach','Authors','Tags','Review');
@@ -88,8 +47,8 @@ class ContributeController extends JObject
 		if ($this->step && !$this->_task) {
 			$this->_task = 'start';
 		}
-		$juser =& JFactory::getUser();
-		if ($juser->get('guest')) {
+
+		if ($this->juser->get('guest')) {
 			$this->_task = ($this->_task) ? 'login' : '';
 		}
 
@@ -121,13 +80,14 @@ class ContributeController extends JObject
 			case 'orderupc':     $this->reorder_author(); break;
 			case 'orderdownc':   $this->reorder_author(); break;
 			
-			case 'new':     $this->edit();   break;
-			case 'edit':    $this->edit();   break;
+			/*case 'new':     $this->edit();   break;
+			case 'edit':    $this->edit();   break;*/
 			case 'save':    $this->save();   break;
 			case 'submit':  $this->submit(); break;
 			case 'delete':  $this->delete(); break;
 			case 'cancel':  $this->delete(); break;
 			case 'discard': $this->delete(); break;
+			case 'retract': $this->retract(); break;
 			
 			case 'start':   $this->steps();  break;
 			case 'login':   $this->login();  break;
@@ -135,39 +95,10 @@ class ContributeController extends JObject
 			default: $this->intro(); break;
 		}
 	}
-	
-	//-----------
-
-	public function redirect()
-	{
-		if ($this->_redirect != NULL) {
-			$app =& JFactory::getApplication();
-			$app->redirect( $this->_redirect, $this->_message );
-		}
-	}
 
-	//-----------
-	
-	private function _getStyles( $option='' ) 
-	{
-		$option = ($option) ? $option : $this->_option;
-		ximport('xdocument');
-		XDocument::addComponentStylesheet($option);
-	}
-	
-	//-----------
-	
-	private function _getScripts()
-	{
-		$document =& JFactory::getDocument();
-		if (is_file(JPATH_ROOT.DS.'components'.DS.$this->_option.DS.$this->_name.'.js')) {
-			$document->addScript('components'.DS.$this->_option.DS.$this->_name.'.js');
-		}
-	}
-	
 	//-----------
 
-	private function _buildPathway() 
+	protected function _buildPathway() 
 	{
 		$app =& JFactory::getApplication();
 		$pathway =& $app->getPathway();
@@ -194,7 +125,7 @@ class ContributeController extends JObject
 	
 	//-----------
 	
-	private function _buildTitle() 
+	protected function _buildTitle() 
 	{
 		$this->_title = JText::_(strtoupper($this->_option));
 		if ($this->_task) {
@@ -282,11 +213,13 @@ class ContributeController extends JObject
 			$this->$preprocess();
 		}
 		
-		$id = JRequest::getInt( 'id', 0 );
+		if (!$this->getError()) {
+			$id = JRequest::getInt( 'id', 0 );
 		
-		$this->check_progress($id);
-		
-		$this->$activestep();
+			$this->check_progress($id);
+
+			$this->$activestep();
+		}
 	}
 	
 	//----------------------------------------------------------
@@ -299,8 +232,7 @@ class ContributeController extends JObject
 		$step++;
 		
 		// Get available resource types
-		$database =& JFactory::getDBO();
-		$rt = new ResourcesType( $database );
+		$rt = new ResourcesType( $this->database );
 		$types = $rt->getMajorTypes();
 		
 		// Output HTML
@@ -318,14 +250,15 @@ class ContributeController extends JObject
 	
 	//-----------
 	
-	protected function step_compose()
+	protected function step_compose($row=null)
 	{
-		$xhub = XFactory::getHub();
+		$xhub = Hubzero_Factory::getHub();
 
 		$type = JRequest::getVar( 'type', '' );
 
-		if ($type == '7')
+		if ($type == '7') {
 			$xhub->redirect(JRoute::_('index.php?option=com_contribtool&task=create'));
+		}
 
 		$step = $this->step;
 		$next_step = $step+1;
@@ -334,8 +267,7 @@ class ContributeController extends JObject
 		$id = JRequest::getInt( 'id', 0 );
 		
 		// Instantiate a new resource object
-		$database =& JFactory::getDBO();
-		$row = new ResourcesResource( $database );
+		$row = new ResourcesResource( $this->database );
 		if ($id) {
 			// Load the resource
 			$row->load( $id );
@@ -354,7 +286,7 @@ class ContributeController extends JObject
 		$view->row = $row;
 		$view->config = $this->config;
 		$view->next_step = $next_step;
-		$view->database = $database;
+		$view->database = $this->database;
 		$view->id = $id;
 		$view->progress = $this->progress;
 		$view->task = 'start';
@@ -381,8 +313,7 @@ class ContributeController extends JObject
 		}
 		
 		// Load the resource
-		$database =& JFactory::getDBO();
-		$row = new ResourcesResource( $database );
+		$row = new ResourcesResource( $this->database );
 		$row->load( $id );
 		
 		// Output HTML
@@ -394,7 +325,7 @@ class ContributeController extends JObject
 		$view->row = $row;
 		$view->config = $this->config;
 		$view->next_step = $next_step;
-		$view->database = $database;
+		$view->database = $this->database;
 		$view->id = $id;
 		$view->progress = $this->progress;
 		$view->task = 'start';
@@ -421,16 +352,13 @@ class ContributeController extends JObject
 		}
 		
 		// Load the resource
-		$database =& JFactory::getDBO();
-		$row = new ResourcesResource( $database );
+		$row = new ResourcesResource( $this->database );
 		$row->load( $id );
 		
 		// Get groups
-		$juser =& JFactory::getUser();
-
-		ximport('xuserhelper');
+		ximport('Hubzero_User_Helper');
 			
-		$groups = XUserHelper::getGroups( $juser->get('id'), 'members' );
+		$groups = Hubzero_User_Helper::getGroups( $this->juser->get('id'), 'members' );
 		
 		// Output HTML
 		$view = new JView( array('name'=>'steps','layout'=>'authors') );
@@ -441,7 +369,7 @@ class ContributeController extends JObject
 		$view->row = $row;
 		$view->groups = $groups;
 		$view->next_step = $next_step;
-		$view->database = $database;
+		$view->database = $this->database;
 		$view->id = $id;
 		$view->progress = $this->progress;
 		$view->task = 'start';
@@ -482,8 +410,7 @@ class ContributeController extends JObject
 		$fa10 = $tconfig->get('focus_area_10');
 		
 		// Instantiate our tag object
-		$database =& JFactory::getDBO();
-		$tagcloud = new ResourcesTags($database);
+		$tagcloud = new ResourcesTags($this->database);
 
 		// Normalize the focus areas
 		$tagfa1 = $tagcloud->normalize_tag($fa1);
@@ -546,6 +473,15 @@ class ContributeController extends JObject
 		}
 		$tags = implode( ', ', $mytagarray );
 
+		$etags = JRequest::getVar( 'tags', '' );
+		if (!$tags) {
+			$tags = $etags;
+		}
+		$err = JRequest::getInt( 'err', 0 );
+		if ($err) {
+			$this->setError( JText::_('Please select one of the focus areas.') );
+		}
+
 		// Output HTML
 		$view = new JView( array('name'=>'steps','layout'=>'tags') );
 		$view->option = $this->_option;
@@ -556,7 +492,7 @@ class ContributeController extends JObject
 		$view->tagfa = $tagfa;
 		$view->fats = $fats;
 		$view->next_step = $next_step;
-		$view->database = $database;
+		$view->database = $this->database;
 		$view->id = $id;
 		$view->progress = $this->progress;
 		$view->task = 'start';
@@ -586,17 +522,15 @@ class ContributeController extends JObject
 		$this->_getStyles('com_resources');
 		
 		// Get some needed libraries
-		include_once( JPATH_ROOT.DS.'components'.DS.'com_resources'.DS.'resources.html.php' );
+		include_once( JPATH_ROOT.DS.'components'.DS.'com_resources'.DS.'helpers'.DS.'html.php' );
 
 		// Load resource info
-		$database =& JFactory::getDBO();
-		$resource = new ResourcesResource( $database );
+		$resource = new ResourcesResource( $this->database );
 		$resource->load( $id );
 		
-		$juser =& JFactory::getUser();
-		if (!$juser->get('guest')) {
-			ximport('xuserhelper');
-			$xgroups = XUserHelper::getGroups($juser->get('id'), 'all');
+		if (!$this->juser->get('guest')) {
+			ximport('Hubzero_User_Helper');
+			$xgroups = Hubzero_User_Helper::getGroups($this->juser->get('id'), 'all');
 			// Get the groups the user has access to
 			$usersgroups = $this->_getUsersGroups($xgroups);
 		} else {
@@ -613,7 +547,7 @@ class ContributeController extends JObject
 		$view->config = $this->config;
 		$view->resource = $resource;
 		$view->next_step = $next_step;
-		$view->database = $database;
+		$view->database = $this->database;
 		$view->id = $id;
 		$view->progress = $this->progress;
 		$view->task = 'submit';
@@ -652,11 +586,8 @@ class ContributeController extends JObject
 	
 	protected function step_compose_process() 
 	{
-	    $juser =& JFactory::getUser();
-		$database =& JFactory::getDBO();
-
 		// Initiate extended database class
-		$row = new ResourcesResource( $database );
+		$row = new ResourcesResource( $this->database );
 		if (!$row->bind( $_POST )) {
 			JError::raiseError( 500, $row->getError() );
 			return;
@@ -664,7 +595,7 @@ class ContributeController extends JObject
 		$isNew = $row->id < 1;
 
 		$row->created = ($row->created) ? $row->created : date( 'Y-m-d H:i:s' );
-		$row->created_by = ($row->created_by) ? $row->created_by : $juser->get('id');
+		$row->created_by = ($row->created_by) ? $row->created_by : $this->juser->get('id');
 
 		// Set status to "composing"
 		if ($isNew) {
@@ -675,10 +606,10 @@ class ContributeController extends JObject
 		$row->publish_up = ($row->publish_up) ? $row->publish_up : date( 'Y-m-d H:i:s' );
 		$row->publish_down = '0000-00-00 00:00:00';
 		$row->modified = date( 'Y-m-d H:i:s' );
-		$row->modified_by = $juser->get('id');
+		$row->modified_by = $this->juser->get('id');
 
 		// Get custom areas, add wrapper tags, and compile into fulltext
-		$type = new ResourcesType( $database );
+		$type = new ResourcesType( $this->database );
 		$type->load( $row->type );
 		
 		$fields = array();
@@ -711,13 +642,17 @@ class ContributeController extends JObject
 				foreach ($fields as $f) 
 				{
 					if ($f[0] == $tagname && end($f) == 1) {
-						JError::raiseError( 500, JText::sprintf('COM_CONTRIBUTE_REQUIRED_FIELD_CHECK', $f[1]) );
+						$this->setError( JText::sprintf('COM_CONTRIBUTE_REQUIRED_FIELD_CHECK', $f[1]) );
+						$this->step--;
+						$this->step_compose($row);
 						return;
 					}
 				}
 			}
 		}
 
+		$row->title = $this->_txtClean($row->title);
+		
 		// Strip any scripting there may be
 		if (trim($row->fulltext)) {
 			$row->fulltext   = $this->_txtClean($row->fulltext);
@@ -750,7 +685,7 @@ class ContributeController extends JObject
 			
 			// Automatically attach this user as the first author
 			$_REQUEST['pid'] = $row->id;
-			$_POST['authid'] = $juser->get('id');
+			$_POST['authid'] = $this->juser->get('id');
 			$_REQUEST['id'] = $row->id;
 			
 			$this->author_save(0);
@@ -777,14 +712,20 @@ class ContributeController extends JObject
 		}
 		
 		// Load the resource
-		$database =& JFactory::getDBO();
-		$row = new ResourcesResource( $database );
+		$row = new ResourcesResource( $this->database );
 		$row->load( $id );
 		
 		// Set the group and access level
 		$row->group_owner = JRequest::getVar( 'group_owner', '' );
 		$row->access = JRequest::getInt( 'access', 0 );
 		
+		if ($row->access > 0 && !$row->group_owner) {
+			$this->setError( JText::_('Please select a group to restrict access to.') );
+			$this->step--;
+			$this->step_authors();
+			return;
+		}
+		
 		// Check content
 		if (!$row->check()) {
 			JError::raiseError( 500, $row->getError() );
@@ -802,14 +743,43 @@ class ContributeController extends JObject
 
 	protected function step_tags_process()
 	{
-		$database =& JFactory::getDBO();
-		$juser =& JFactory::getUser();
-		
 		// Incoming
 		$id    = JRequest::getInt( 'id', 0, 'post' );
 		$tags  = JRequest::getVar( 'tags', '', 'post' );
 		$tagfa = JRequest::getVar( 'tagfa', '', 'post' );
 		
+		$tagcloud = new ResourcesTags($this->database);
+
+		$tconfig =& JComponentHelper::getParams( 'com_tags' );
+		$fa = array();
+		$fa[] = $tagcloud->normalize_tag($tconfig->get('focus_area_01'));
+		$fa[] = $tagcloud->normalize_tag($tconfig->get('focus_area_02'));
+		$fa[] = $tagcloud->normalize_tag($tconfig->get('focus_area_03'));
+		$fa[] = $tagcloud->normalize_tag($tconfig->get('focus_area_04'));
+		$fa[] = $tagcloud->normalize_tag($tconfig->get('focus_area_05'));
+		$fa[] = $tagcloud->normalize_tag($tconfig->get('focus_area_06'));
+		$fa[] = $tagcloud->normalize_tag($tconfig->get('focus_area_07'));
+		$fa[] = $tagcloud->normalize_tag($tconfig->get('focus_area_08'));
+		$fa[] = $tagcloud->normalize_tag($tconfig->get('focus_area_09'));
+		$fa[] = $tagcloud->normalize_tag($tconfig->get('focus_area_10'));
+		$required = false;
+		foreach ($fa as $r) 
+		{
+			if ($r != '') {
+				$required = true;
+			}
+		}
+		//print_r($required);
+		if ($required) {
+			//echo $tagfa; print_r($fa); die;
+			if (!$tagfa || ($tagfa && !in_array($tagfa, $fa))) {
+				$this->_redirect = JRoute::_('index.php?option='.$this->_option.'&step=4&id='.$id.'&err=1&tags='.$tags);
+				$this->_message = JText::_('Please select one of the focus areas.');
+				$this->_messageType = 'error';
+				return;
+			}
+		}
+		
 		if ($tags) {
 			$tags = $tagfa.', '.$tags;
 		} else {
@@ -817,8 +787,8 @@ class ContributeController extends JObject
 		}
 
 		// Tag the resource
-		$rt = new ResourcesTags($database);
-		$rt->tag_object($juser->get('id'), $id, $tags, 1, 0);
+		$rt = new ResourcesTags($this->database);
+		$rt->tag_object($this->juser->get('id'), $id, $tags, 1, 1);
 	}
 
 	//----------------------------------------------------------
@@ -837,8 +807,7 @@ class ContributeController extends JObject
 		}
 	
 		// Load resource info
-		$database =& JFactory::getDBO();
-		$resource = new ResourcesResource( $database );
+		$resource = new ResourcesResource( $this->database );
 		$resource->load( $id );
 
 		// Set a flag for if the resource was already published or not
@@ -868,8 +837,7 @@ class ContributeController extends JObject
 				$apu = explode(',', $apu);
 				$apu = array_map('trim',$apu);
 				
-				$juser =& JFactory::getUser();
-				if (in_array($juser->get('username'),$apu)) {
+				if (in_array($this->juser->get('username'),$apu)) {
 					// Set status to published
 					$resource->published = 1;
 				} else {
@@ -879,7 +847,7 @@ class ContributeController extends JObject
 			}
 			
 			// Get the resource's contributors
-			$helper = new ResourcesHelper( $id, $database );
+			$helper = new ResourcesHelper( $id, $this->database );
 			$helper->getCons();
 
 			$contributors = $helper->_contributors;
@@ -952,13 +920,13 @@ class ContributeController extends JObject
 		$message .= JRoute::_('index.php?option=com_resources&id='.$id);
 
 		// Send e-mail
-		ximport('xhubhelper');
+		ximport('Hubzero_Toolbox');
 		foreach ($contributors as $contributor)
 		{
 			$juser = JUser::getInstance( $contributor->id );
 			if (is_object($juser)) {
 				if ($juser->get('email')) {
-					XHubHelper::send_email($from, $email, $subject, $message);
+					Hubzero_Toolbox::send_email($from, $email, $subject, $message);
 				}
 			}
 		}*/
@@ -1004,10 +972,8 @@ class ContributeController extends JObject
 					$progress[$steps[$i]] = 0;
 				}
 				
-				$database =& JFactory::getDBO();
-				
 				// Load the resource
-				$row = new ResourcesResource( $database );
+				$row = new ResourcesResource( $this->database );
 				$row->load( $id );
 				$row->typetitle = $row->getTypeTitle(0);
 
@@ -1035,11 +1001,9 @@ class ContributeController extends JObject
 					$this->redirect = JRoute::_('index.php?option='.$this->_option);
 					return;
 				}
-				
-				$database =& JFactory::getDBO();
-				
+
 				// Load the resource
-				$resource = new ResourcesResource( $database );
+				$resource = new ResourcesResource( $this->database );
 				$resource->load( $id );
 				
 				// Check if the resource was "published"
@@ -1063,12 +1027,39 @@ class ContributeController extends JObject
 		}
 	}
 	
+	//-----------
+	
+	protected function retract() 
+	{
+		// Incoming
+		$id = JRequest::getInt( 'id', 0 );
+		
+		// Ensure we have an ID to work with
+		if (!$id) {
+			$this->_redirect = JRoute::_('index.php?option='.$this->_option);
+			return;
+		}
+		
+		// Load the resource
+		$resource = new ResourcesResource( $this->database );
+		$resource->load( $id );
+		
+		// Check if it's in pending status
+		if ($resource->published == 3) {
+			// Set it back to "draft" status
+			$resource->published = 2;
+			// Save changes
+			$resource->store();
+		}
+		
+		// Redirect
+		$this->_redirect = JRoute::_('index.php?option='.$this->_option);
+	}
+	
 	//-----------
 
 	protected function markRemovedContribution( $id )
 	{
-		$database =& JFactory::getDBO();
-		
 		// Make sure we have a record to pull
 		if (!$id) {
 			$this->setError( JText::_('COM_CONTRIBUTE_NO_ID') );
@@ -1076,7 +1067,7 @@ class ContributeController extends JObject
 		}
 		
 		// Load resource info
-		$row = new ResourcesResource( $database );
+		$row = new ResourcesResource( $this->database );
 		$row->load( $id );
 		
 		// Mark resource as deleted
@@ -1102,14 +1093,12 @@ class ContributeController extends JObject
 		
 		jimport('joomla.filesystem.folder');
 		
-		$database =& JFactory::getDBO();
-		
 		// Load resource info
-		$row = new ResourcesResource( $database );
+		$row = new ResourcesResource( $this->database );
 		$row->load( $id );
 		
 		// Get the resource's children
-		$helper = new ResourcesHelper( $id, $database );
+		$helper = new ResourcesHelper( $id, $this->database );
 		$helper->getChildren();
 		$children = $helper->children;
 		
@@ -1190,8 +1179,7 @@ class ContributeController extends JObject
 	protected function attach_rename()
 	{
 		// Check if they are logged in
-		$juser =& JFactory::getUser();
-		if ($juser->get('guest')) {
+		if ($this->juser->get('guest')) {
 			return false;
 		}
 		
@@ -1201,9 +1189,7 @@ class ContributeController extends JObject
 
 		// Ensure we have everything we need
 		if ($id && $name != '') {
-			$database =& JFactory::getDBO();
-			
-			$r = new ResourcesResource( $database );
+			$r = new ResourcesResource( $this->database );
 			$r->load( $id );
 			$r->title = $name;
 			$r->store();
@@ -1218,8 +1204,7 @@ class ContributeController extends JObject
 	protected function attach_save()
 	{
 		// Check if they are logged in
-		$juser =& JFactory::getUser();
-		if ($juser->get('guest')) {
+		if ($this->juser->get('guest')) {
 			return false;
 		}
 
@@ -1243,10 +1228,8 @@ class ContributeController extends JObject
 		$file['name'] = JFile::makeSafe($file['name']);
 		$file['name'] = str_replace(' ','_',$file['name']);
 
-		$database =& JFactory::getDBO();
-
 		// Instantiate a new resource object
-		$row = new ResourcesResource( $database );
+		$row = new ResourcesResource( $this->database );
 		if (!$row->bind( $_POST )) {
 			$this->setError( $row->getError() );
 			$this->attachments( $pid );
@@ -1255,7 +1238,7 @@ class ContributeController extends JObject
 		$row->title = ($row->title) ? $row->title : $file['name'];
 		$row->introtext = $row->title;
 		$row->created = date( 'Y-m-d H:i:s' );
-		$row->created_by = $juser->get('id');
+		$row->created_by = $this->juser->get('id');
 		$row->published = 1;
 		$row->publish_up = date( 'Y-m-d H:i:s' );
 		$row->publish_down = '0000-00-00 00:00:00';
@@ -1378,7 +1361,7 @@ class ContributeController extends JObject
 		}
 		
 		// Instantiate a ResourcesAssoc object
-		$assoc = new ResourcesAssoc( $database );
+		$assoc = new ResourcesAssoc( $this->database );
 
 		// Get the last child in the ordering
 		$order = $assoc->getLastOrder( $pid );
@@ -1408,13 +1391,10 @@ class ContributeController extends JObject
 	protected function attach_delete() 
 	{
 		// Check if they are logged in
-		$juser =& JFactory::getUser();
-		if ($juser->get('guest')) {
+		if ($this->juser->get('guest')) {
 			return false;
 		}
 		
-		$database =& JFactory::getDBO();
-		
 		// Incoming parent ID
 		$pid = JRequest::getInt( 'pid', 0 );
 		if (!$pid) {
@@ -1433,7 +1413,7 @@ class ContributeController extends JObject
 		jimport('joomla.filesystem.file');
 	
 		// Load resource info
-		$row = new ResourcesResource( $database );
+		$row = new ResourcesResource( $this->database );
 		$row->load( $id );
 		
 		// Get path and delete directories
@@ -1512,8 +1492,7 @@ class ContributeController extends JObject
 	protected function attachments( $id=null ) 
 	{
 		// Check if they are logged in
-		$juser =& JFactory::getUser();
-		if ($juser->get('guest')) {
+		if ($this->juser->get('guest')) {
 			return false;
 		}
 		
@@ -1529,9 +1508,7 @@ class ContributeController extends JObject
 		}
 		
 		// Initiate a resource helper class
-		$database =& JFactory::getDBO();
-		
-		$helper = new ResourcesHelper( $id, $database );
+		$helper = new ResourcesHelper( $id, $this->database );
 		$helper->getChildren();
 		
 		// Output HTML
@@ -1645,10 +1622,8 @@ class ContributeController extends JObject
 
 		$move = substr($this->_task, 0, (strlen($this->_task) - 1));
 
-		$database =& JFactory::getDBO();
-
 		// Get the element moving down - item 1
-		$resource1 = new ResourcesAssoc( $database );
+		$resource1 = new ResourcesAssoc( $this->database );
 		$resource1->loadAssoc( $pid, $id );
 
 		// Get the element directly after it in ordering - item 2
@@ -1698,16 +1673,14 @@ class ContributeController extends JObject
 			return;
 		}
 		
-		ximport('xprofile');
-		
-		$database =& JFactory::getDBO();
+		ximport('Hubzero_User_Profile');
 		
 		// Incoming authors
 		$authid = JRequest::getInt( 'authid', 0, 'post' );
 		$authorsNewstr = JRequest::getVar( 'new_authors', '', 'post' );
 
 		// Instantiate a resource/contributor association object
-		$rc = new ResourcesContributor( $database );
+		$rc = new ResourcesContributor( $this->database );
 		$rc->subtable = 'resources';
 		$rc->subid = $id;
 		
@@ -1724,7 +1697,7 @@ class ContributeController extends JObject
 			} else {
 				// Perform a check to see if they have a contributors page. If not, we'll need to make one
 				//$juser =& JUser::getInstance( $authid );
-				$xprofile = new XProfile();
+				$xprofile = new Hubzero_User_Profile();
 				$xprofile->load( $authid );
 				if ($xprofile) {
 					$this->_author_check($authid);
@@ -1774,7 +1747,7 @@ class ContributeController extends JObject
 				}
 				
 				// Check if they're already linked to this resource
-				$rcc = new ResourcesContributor( $database );
+				$rcc = new ResourcesContributor( $this->database );
 				$rcc->loadAssociation( $uid, $id, 'resources' );
 				if ($rcc->authorid) {
 					$this->setError( JText::sprintf('COM_CONTRIBUTE_USER_IS_ALREADY_AUTHOR', $cid) );
@@ -1784,7 +1757,7 @@ class ContributeController extends JObject
 				$this->_author_check($juser->get('id'));
 				
 				// New record
-				$xprofile = XProfile::getInstance($juser->get('id'));
+				$xprofile = Hubzero_User_Profile::getInstance($juser->get('id'));
 				$rcc->subtable = 'resources';
 				$rcc->subid = $id;
 				$rcc->authorid = $uid;
@@ -1807,7 +1780,7 @@ class ContributeController extends JObject
 
 	private function _author_check($id)
 	{
-		$xprofile = XProfile::getInstance($id);
+		$xprofile = Hubzero_User_Profile::getInstance($id);
 		if ($xprofile->get('givenName') == '' && $xprofile->get('middleName') == '' && $xprofile->get('surname') == '') {
 			$bits = explode(' ', $xprofile->get('name'));
 			$xprofile->set('surname', array_pop($bits));
@@ -1837,9 +1810,7 @@ class ContributeController extends JObject
 		
 		// Ensure we have the contributor's ID ($id)
 		if ($id) {
-			$database =& JFactory::getDBO();
-			
-			$rc = new ResourcesContributor( $database );
+			$rc = new ResourcesContributor( $this->database );
 			if (!$rc->deleteAssociation( $id, $pid, 'resources' )) {
 				$this->setError( $rc->getError() );
 			}
@@ -1873,10 +1844,8 @@ class ContributeController extends JObject
 
 		$move = substr($this->_task, 0, (strlen($this->_task) - 1));
 
-		$database =& JFactory::getDBO();
-
 		// Get the element moving down - item 1
-		$author1 = new ResourcesContributor( $database );
+		$author1 = new ResourcesContributor( $this->database );
 		$author1->loadAssociation( $id, $pid, 'resources' );
 
 		// Get the element directly after it in ordering - item 2
@@ -1916,8 +1885,6 @@ class ContributeController extends JObject
 
 	protected function authors( $id=null ) 
 	{
-		$database =& JFactory::getDBO();
-		
 		// Incoming
 		if (!$id) {
 			$id = JRequest::getInt( 'id', 0 );
@@ -1929,18 +1896,16 @@ class ContributeController extends JObject
 			return;
 		}
 		
-		// Initiate a resource helper class
-		$database =& JFactory::getDBO();
-		
 		// Get all contributors of this resource
-		$helper = new ResourcesHelper( $id, $database );
+		$helper = new ResourcesHelper( $id, $this->database );
 		$helper->getCons();
 		
 		// Get a list of all existing contributors
-		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_members'.DS.'members.class.php' );
+		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_members'.DS.'tables'.DS.'profile.php' );
+		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_members'.DS.'tables'.DS.'association.php' );
 		
 		// Initiate a members object
-		$mp = new MembersProfile( $database );
+		$mp = new MembersProfile( $this->database );
 		
 		$filters = array();
 		$filters['search'] = '';
@@ -1987,8 +1952,7 @@ class ContributeController extends JObject
 	protected function step_attach_check( $id )
 	{
 		if ($id) {
-			$database =& JFactory::getDBO();
-			$ra = new ResourcesAssoc( $database );
+			$ra = new ResourcesAssoc( $this->database );
 			$total = $ra->getCount( $id );
 		} else {
 			$total = 0;
@@ -2001,8 +1965,7 @@ class ContributeController extends JObject
 	protected function step_authors_check( $id )
 	{
 		if ($id) {
-			$database =& JFactory::getDBO();
-			$rc = new ResourcesContributor( $database );
+			$rc = new ResourcesContributor( $this->database );
 			$contributors = $rc->getCount( $id, 'resources' );
 		} else {
 			$contributors = 0;
@@ -2015,9 +1978,7 @@ class ContributeController extends JObject
 	
 	protected function step_tags_check( $id )
 	{
-		$database =& JFactory::getDBO();
-
-		$rt = new ResourcesTags( $database );
+		$rt = new ResourcesTags( $this->database );
 		$tags = $rt->getTags( $id );
 
 		if (count($tags) > 0) {
@@ -2031,9 +1992,7 @@ class ContributeController extends JObject
 
 	protected function step_review_check( $id ) 
 	{
-		$database =& JFactory::getDBO();
-		
-		$row = new ResourcesResource( $database );
+		$row = new ResourcesResource( $this->database );
 		$row->load( $id );
 	
 		if ($row->published == 1) {
@@ -2049,6 +2008,11 @@ class ContributeController extends JObject
 
 	private function _txtClean( &$text ) 
 	{
+		$text = str_replace('“','"', $text);
+		$text = str_replace('”','"', $text);
+		$text = str_replace("’","'", $text);
+		$text = str_replace("‘","'", $text);
+		
 		$text = preg_replace( '/{kl_php}(.*?){\/kl_php}/s', '', $text );
 		$text = preg_replace( '/{.+?}/', '', $text );
 		$text = preg_replace( "'<style[^>]*>.*?</style>'si", '', $text );
@@ -2061,6 +2025,30 @@ class ContributeController extends JObject
 
 	private function _txtAutoP($pee, $br = 1) 
 	{
+		$trans_tbl = get_html_translation_table(HTML_ENTITIES);
+		foreach ($trans_tbl as $k => $v) 
+		{
+			if ($k != '<' && $k != '>' && $k != '"' && $k != "'") {
+				$ttr[utf8_encode($k)] = $v;
+			}
+		}
+		$pee = strtr($pee, $ttr);
+		
+		$ent = array( 
+		    'Ć'=>'&#262;', 
+		    'ć'=>'&#263;', 
+		    'Č'=>'&#268;', 
+		    'č'=>'&#269;', 
+		    'Đ'=>'&#272;', 
+		    'đ'=>'&#273;', 
+		    'Š'=>'&#352;', 
+		    'š'=>'&#353;', 
+		    'Ž'=>'&#381;', 
+		    'ž'=>'&#382;' 
+		);
+		
+		$pee = strtr($pee, $ent);
+		
 		// converts paragraphs of text into xhtml
 		$pee = $pee . "\n"; // just to make things a little easier, pad the end
 		$pee = preg_replace('|<br />\s*<br />|', "\n\n", $pee);
@@ -2068,7 +2056,7 @@ class ContributeController extends JObject
 		$pee = preg_replace('!(</(?:table|ul|ol|li|pre|form|blockquote|h[1-6])>)!', "$1\n", $pee); // Space things out a little
 		$pee = preg_replace("/(\r\n|\r)/", "\n", $pee); // cross-platform newlines 
 		$pee = preg_replace("/\n\n+/", "\n\n", $pee); // take care of duplicates
-		$pee = preg_replace('/\n?(.+?)(?:\n\s*\n|\z)/s', "\t<p>$1</p>\n", $pee); // make paragraphs, including one at the end 
+		$pee = preg_replace('/\n?(.+?)(?:\n\s*\n|\z)/s', "<p>$1</p>\n", $pee); // make paragraphs, including one at the end 
 		$pee = preg_replace('|<p>\s*?</p>|', '', $pee); // under certain strange conditions it could create a P of entirely whitespace 
 		$pee = preg_replace("|<p>(<li.+?)</p>|", "$1", $pee); // problem with nested lists
 		$pee = preg_replace('|<p><blockquote([^>]*)>|i', "<blockquote$1><p>", $pee);
@@ -2078,7 +2066,7 @@ class ContributeController extends JObject
 		if ($br) $pee = preg_replace('|(?<!<br />)\s*\n|', "<br />\n", $pee); // optionally make line breaks
 		$pee = preg_replace('!(</?(?:table|tr|td|th|div|dl|dd|dt|ul|ol|li|pre|select|form|blockquote|p|h[1-6])[^>]*>)\s*<br />!', "$1", $pee);
 		$pee = preg_replace('!<br />(\s*</?(?:p|li|div|th|pre|td|ul|ol)>)!', '$1', $pee);
-		$pee = preg_replace('/&([^#])(?![a-z]{1,8};)/', '&#038;$1', $pee);
+		//$pee = preg_replace('/&([^#])(?![a-z]{1,8};)/', '&#038;$1', $pee);
 		
 		return $pee; 
 	}
@@ -2117,4 +2105,4 @@ class ContributeController extends JObject
 		return $path;
 	}
 }
-?>
+
