@@ -1,79 +1,38 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Shawn Rice <zooley@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Shawn Rice <zooley@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
 
-class EventsController extends JObject
-{	
-	private $_name  = NULL;
-	private $_data  = array();
-	private $_task  = NULL;
+ximport('Hubzero_Controller');
 
-	//-----------
-	
-	public function __construct( $config=array() )
-	{
-		$this->_redirect = NULL;
-		$this->_message = NULL;
-		$this->_messageType = 'message';
-		
-		// Set the controller name
-		if (empty( $this->_name )) {
-			if (isset($config['name'])) {
-				$this->_name = $config['name'];
-			} else {
-				$r = null;
-				if (!preg_match('/(.*)Controller/i', get_class($this), $r)) {
-					echo "Controller::__construct() : Can't get or parse class name.";
-				}
-				$this->_name = strtolower( $r[1] );
-			}
-		}
-		
-		// Set the component name
-		$this->_option = 'com_'.$this->_name;
-	}
-
-	//-----------
-
-	public function __set($property, $value)
-	{
-		$this->_data[$property] = $value;
-	}
-	
-	//-----------
-	
-	public function __get($property)
-	{
-		if (isset($this->_data[$property])) {
-			return $this->_data[$property];
-		}
-	}
-
-	//-----------
-	
+class EventsController extends Hubzero_Controller
+{
 	public function execute()
 	{
 		$this->_setup();
@@ -102,36 +61,7 @@ class EventsController extends JObject
 	
 	//-----------
 
-	public function redirect()
-	{
-		if ($this->_redirect != NULL) {
-			$app =& JFactory::getApplication();
-			$app->redirect( $this->_redirect, $this->_message );
-		}
-	}
-
-	//-----------
-	
-	private function _getStyles() 
-	{
-		ximport('xdocument');
-		XDocument::addComponentStylesheet($this->_option);
-	}
-
-	//-----------
-	
-	private function _getScripts()
-	{
-		$document =& JFactory::getDocument();
-		if (is_file(JPATH_ROOT.DS.'components'.DS.$this->_option.DS.'js'.DS.$this->_name.'.js')) {
-			$document->addScript('components'.DS.$this->_option.DS.'js'.DS.'calendar.rc4.js');
-			$document->addScript('components'.DS.$this->_option.DS.'js'.DS.$this->_name.'.js');
-		}
-	}
-	
-	//-----------
-
-	private function _buildPathway() 
+	protected function _buildPathway() 
 	{
 		$app =& JFactory::getApplication();
 		$pathway =& $app->getPathway();
@@ -215,7 +145,7 @@ class EventsController extends JObject
 	
 	//-----------
 	
-	private function _buildTitle() 
+	protected function _buildTitle() 
 	{
 		$this->_title = JText::_(strtoupper($this->_name));
 		switch ($this->_task) 
@@ -269,10 +199,8 @@ class EventsController extends JObject
 
 	private function _setup()
 	{
-		$database =& JFactory::getDBO();
-		
 		// Load the events configuration
-		$config = new EventsConfigs( $database );
+		$config = new EventsConfigs( $this->database );
 		$config->load();
 		
 		$this->config = $config;
@@ -298,7 +226,7 @@ class EventsController extends JObject
 			$month = "0$month";
 		}
 		
-		$ee = new EventsEvent( $database );
+		$ee = new EventsEvent( $this->database );
 		
 		// Find the date of the first event
 		$row = $ee->getFirst();
@@ -333,8 +261,7 @@ class EventsController extends JObject
 		
 		$this->category = $category;
 
-		$juser =& JFactory::getUser();
-		$this->gid = intval( $juser->get('gid') );
+		$this->gid = intval( $this->juser->get('gid') );
 	}
 	
 	//----------------------------------------------------------
@@ -343,8 +270,6 @@ class EventsController extends JObject
 
 	protected function year() 
 	{
-		$database =& JFactory::getDBO();
-		
 		// Get some needed info
 		$year   = $this->year;
 		$month  = $this->month;
@@ -360,7 +285,7 @@ class EventsController extends JObject
 		$filters['category'] = $this->category;
 
 		// Retrieve records
-		$ee = new EventsEvent( $database );
+		$ee = new EventsEvent( $this->database );
 		$rows = $ee->getEvents( 'year', $filters );
 
 		// Everyone has access unless restricted to admins in the configuration
@@ -402,8 +327,6 @@ class EventsController extends JObject
 
 	protected function month() 
 	{
-		$database =& JFactory::getDBO();
-		
 		// Get some needed info
 		$offset = $this->offset;
 		$option = $this->_option;
@@ -424,7 +347,7 @@ class EventsController extends JObject
 		$filters['category'] = $this->category;
 		
 		// Retrieve records
-		$ee = new EventsEvent( $database );
+		$ee = new EventsEvent( $this->database );
 		$rows = $ee->getEvents( 'month', $filters );
 
 		// Everyone has access unless restricted to admins in the configuration
@@ -466,8 +389,6 @@ class EventsController extends JObject
 
 	protected function week() 
 	{
-		$database =& JFactory::getDBO();
-		
 		// Get some needed info
 		$offset = $this->offset;
 		$option = $this->_option;
@@ -487,8 +408,8 @@ class EventsController extends JObject
 		$this_enddate = clone($this_date);
 		$this_enddate->addDays( +6 );
 		
-		$sdt = JHTML::_('date', $this_date->year.'-'.$this_date->month.'-'.$this_date->day.' 00:00:00', '%d %b');
-		$edt = JHTML::_('date', $this_enddate->year.'-'.$this_enddate->month.'-'.$this_enddate->day.' 00:00:00', '%d %b');
+		$sdt = JHTML::_('date', $this_date->year.'-'.$this_date->month.'-'.$this_date->day.' 00:00:00', '%d %b',0);
+		$edt = JHTML::_('date', $this_enddate->year.'-'.$this_enddate->month.'-'.$this_enddate->day.' 00:00:00', '%d %b',0);
 		
 		$this_currentdate = $this_date;
 		
@@ -498,7 +419,7 @@ class EventsController extends JObject
 		$filters['gid'] = $this->gid;
 		$filters['category'] = $this->category;
 		
-		$ee = new EventsEvent( $database );
+		$ee = new EventsEvent( $this->database );
 		
 		$rows = array();
 		for ($d = 0; $d < 7; $d++) 
@@ -557,8 +478,6 @@ class EventsController extends JObject
 
 	protected function day() 
 	{
-		$database =& JFactory::getDBO();
-		
 		// Get some needed info
 		$year   = $this->year;
 		$month  = $this->month;
@@ -572,7 +491,7 @@ class EventsController extends JObject
 		$filters['select_date'] = sprintf( "%4d-%02d-%02d", $year, $month, $day );
 		$filters['category'] = $this->category;
 		
-		$ee = new EventsEvent( $database );
+		$ee = new EventsEvent( $this->database );
 		$rows = $ee->getEvents( 'day', $filters );
 
 		// Go through each event and ensure it should be displayed
@@ -626,8 +545,6 @@ class EventsController extends JObject
 
 	protected function details() 
 	{
-		$database =& JFactory::getDBO();
-		
 		// Get some needed info
 		$offset = $this->offset;
 		$year   = $this->year;
@@ -639,7 +556,7 @@ class EventsController extends JObject
 		$id = JRequest::getInt( 'id', 0, 'request' );
 		
 		// Load event
-		$row = new EventsEvent( $database );
+		$row = new EventsEvent( $this->database );
 		$row->load( $id );
 		
 		// Ensure we have an event
@@ -712,10 +629,12 @@ class EventsController extends JObject
 			unset( $text );
 		} 
 		
-		$row->content = nl2br(trim($row->content));
+		$UrlPtrn  = "[^=\"\'](https?:|mailto:|ftp:|gopher:|news:|file:)" . "([^ |\\/\"\']*\\/)*([^ |\\t\\n\\/\"\']*[A-Za-z0-9\\/?=&~_])";
+		$row->content = preg_replace_callback("/$UrlPtrn/", array('EventsHtml','autolink'), trim(stripslashes($row->content)));
+		$row->content = nl2br($row->content);
 		$row->content = str_replace("[[BR]]",'<br />',$row->content);
 		$row->content = str_replace(" * ",'<br />&nbsp;&bull;&nbsp;',$row->content);
-		$row->content = stripslashes($row->content);
+		//$row->content = stripslashes($row->content);
 		
 		$fields = $this->config->getCfg('fields');
 		if (!empty($fields)) {
@@ -748,7 +667,7 @@ class EventsController extends JObject
 		$categories = $this->_getCategories();
 		
 		// Get tags on this event
-		$rt = new EventsTags( $database );
+		$rt = new EventsTags( $this->database );
 		$tags = $rt->get_tag_cloud(0, 0, $row->id);
 		
 		// Set the page title
@@ -770,7 +689,7 @@ class EventsController extends JObject
 		$alias = JRequest::getVar( 'page', '' );
 		
 		// Load the current page
-		$page = new EventsPage( $database );
+		$page = new EventsPage( $this->database );
 		if ($alias) {
 			$page->loadFromAlias( $alias, $row->id );
 		}
@@ -810,7 +729,6 @@ class EventsController extends JObject
 
 	protected function register()
 	{
-		$database =& JFactory::getDBO();
 		$document =& JFactory::getDocument();
 		
 		// Get some needed info
@@ -830,7 +748,7 @@ class EventsController extends JObject
 		}
 		
 		// Load event
-		$event = new EventsEvent( $database );
+		$event = new EventsEvent( $this->database );
 		$event->load( $id );
 		
 		// Ensure we have an event
@@ -865,7 +783,7 @@ class EventsController extends JObject
 		$pathway->addItem( stripslashes($event->title), 'index.php?option='.$this->_option.'&task=details&id='.$event->id );
 		$pathway->addItem( JText::_('EVENTS_REGISTER'),'index.php?option='.$this->_option.'&task=details&id='.$event->id.'&page=register');
 		
-		$page = new EventsPage( $database );
+		$page = new EventsPage( $this->database );
 		$page->alias = $this->_task;
 		
 		// Get the pages for this workshop
@@ -876,10 +794,9 @@ class EventsController extends JObject
 		$now = time();
 		
 		$register = array();
-		$juser =& JFactory::getUser();
-		if (!$juser->get('guest')) {
-			$profile = new XProfile();
-			$profile->load( $juser->get('id') );
+		if (!$this->juser->get('guest')) {
+			$profile = new Hubzero_User_Profile();
+			$profile->load( $this->juser->get('id') );
 			
 			$register['firstname'] = $profile->get('givenName');
 			$register['lastname'] = $profile->get('surname');
@@ -940,7 +857,6 @@ class EventsController extends JObject
 
 	protected function process() 
 	{
-		$database =& JFactory::getDBO();
 		$document =& JFactory::getDocument();
 		
 		// Get some needed info
@@ -960,7 +876,7 @@ class EventsController extends JObject
 		}
 		
 		// Load event
-		$event = new EventsEvent( $database );
+		$event = new EventsEvent( $this->database );
 		$event->load( $id );
 		$this->event = $event;
 		
@@ -981,7 +897,7 @@ class EventsController extends JObject
 		$edbits = explode(' ',$bits[2]);
 		$eday = $edbits[0];
 		
-		$page = new EventsPage( $database );
+		$page = new EventsPage( $this->database );
 		$page->alias = $this->_task;
 		
 		// Get the pages for this workshop
@@ -1088,8 +1004,7 @@ class EventsController extends JObject
 	
 	private function _log($reg)
 	{
-		$database =& JFactory::getDBO();
-		$database->setQuery(
+		$this->database->setQuery(
 			'INSERT INTO #__events_respondents(
 				event_id,
 				first_name, last_name, affiliation, title, city, state, zip, country, telephone, fax, email,
@@ -1098,23 +1013,23 @@ class EventsController extends JObject
 			)
 			VALUES ('.
 				$this->event->id . ', '.
-				$this->_getValueString($database, $reg, array(
+				$this->_getValueString($this->database, $reg, array(
 					'firstname', 'lastname', 'affiliation', 'title', 'city', 'state', 'postalcode', 'country', 'telephone', 'fax', 'email',
 					'website', 'position', 'degree', 'gender', 'arrival', 'departure', 'disability', 
 					'dietary', 'dinner', 'additional', 'comments'
 				)).
 			')'
 		);
-		$database->query();
+		$this->database->query();
 		$races = JRequest::getVar('race', NULL, 'post');
 		if (!is_null($races) && (!isset($races['refused']) || !$races['refused'])) {
-			$resp_id = $database->insertid();
+			$resp_id = $this->database->insertid();
 			foreach (array('nativeamerican', 'asian', 'black', 'hawaiian', 'white', 'hispanic') as $race) 
 			{
 				if (array_key_exists($race, $races) && $races[$race]) {
-					$database->execute(
+					$this->database->execute(
 						'INSERT INTO #__events_respondent_race_rel(respondent_id, race, tribal_affiliation) 
-						VALUES ('.$resp_id.', \''.$race.'\', '.($race == 'nativeamerican' ? $database->quote($races['nativetribe']) : 'NULL').')'
+						VALUES ('.$resp_id.', \''.$race.'\', '.($race == 'nativeamerican' ? $this->database->quote($races['nativetribe']) : 'NULL').')'
 					);
 				}
 			}
@@ -1123,7 +1038,7 @@ class EventsController extends JObject
 
 	//-----------
 
-	private function _getValueString(&$database, $reg, $values)
+	private function _getValueString($database, $reg, $values)
 	{
 		$rv = array();
 		foreach ($values as $val)
@@ -1132,7 +1047,7 @@ class EventsController extends JObject
 			{
 				case 'position':
 					$rv[] = ((isset($reg['position']) || isset($reg['position_other'])) && ($reg['position'] || $reg['position_other'])) 
-						? $database->quote(
+						? $this->database->quote(
 							$reg['position'] ? $reg['position'] : $reg['position_other']
 						) 
 						: 'NULL';
@@ -1148,12 +1063,12 @@ class EventsController extends JObject
 				break;
 				case 'dietary':
 					$rv[] = (($dietary = JRequest::getVar('dietary', NULL, 'post'))) 
-						? $database->quote($dietary['specific']) 
+						? $this->database->quote($dietary['specific']) 
 						: 'NULL';
 				break;
 				case 'arrival': case 'departure':
 					$rv[] = ($date = JRequest::getVar($val, NULL, 'post')) 
-						? $database->quote($date['day'] . ' ' . $date['time'])
+						? $this->database->quote($date['day'] . ' ' . $date['time'])
 						: 'NULL';
 				break;
 				case 'disability':
@@ -1161,7 +1076,7 @@ class EventsController extends JObject
 					$rv[] = ($disability) ? '1' : '0';
 				break;
 				default:
-					$rv[] = array_key_exists($val, $reg) && isset($reg[$val]) ? $database->quote($reg[$val]) : 'NULL';
+					$rv[] = array_key_exists($val, $reg) && isset($reg[$val]) ? $this->database->quote($reg[$val]) : 'NULL';
 			}
 		}
 		return implode($rv, ',');
@@ -1183,10 +1098,8 @@ class EventsController extends JObject
 
 	protected function edit($row=NULL)
 	{		
-		$juser =& JFactory::getUser();
-		
 		// Check if they are logged in
-		if ($juser->get('guest')) {
+		if ($this->juser->get('guest')) {
 			$app =& JFactory::getApplication();
 			$pathway =& $app->getPathway();
 			if (count($pathway->getPathWay()) <= 0) {
@@ -1198,9 +1111,6 @@ class EventsController extends JObject
 			return;
 		}
 		
-		// Get the database connection
-		$database =& JFactory::getDBO();
-		
 		// Push some styles to the tmeplate
 		$document =& JFactory::getDocument();
 		$document->addStyleSheet('components'.DS.$this->_option.DS.'calendar.css');
@@ -1209,7 +1119,7 @@ class EventsController extends JObject
 		$this->_getScripts();
 		
 		// We need at least one category before we can proceed
-		$cat = new EventsCategory( $database );
+		$cat = new EventsCategory( $this->database );
 		if ($cat->getCategoryCount( $this->_option ) < 1) {
 			JError::raiseError( 500, JText::_('EVENTS_LANG_NEED_CATEGORY') );
 			return;
@@ -1220,7 +1130,7 @@ class EventsController extends JObject
 		
 		// Load event object
 		if (!is_object($row)) {
-			$row = new EventsEvent( $database );
+			$row = new EventsEvent( $this->database );
 			$row->load( $id );
 		}
 		
@@ -1267,21 +1177,39 @@ class EventsController extends JObject
 
 			$lists['state'] = JHTML::_('select.genericlist', $arr, 'state', '', 'value', 'text', $row->state, false, false );
 		} else {
-			// No ID - we're creating a new event
-			$year  = $this->year;
-			$month = $this->month;
-			$day   = $this->day;
-			
-			if ($year && $month && $day) {
-				$start_publish = $year.'-'.$month.'-'.$day;
-				$stop_publish = $year.'-'.$month.'-'.$day;
-				$registerby_date = $year.'-'.$month.'-'.$day;
+			if ($row->publish_up && $row->publish_up != '0000-00-00 00:00:00') {
+				$event_up = new EventsDate( $row->publish_up );
+				$start_publish = sprintf( "%4d-%02d-%02d",$event_up->year,$event_up->month,$event_up->day);
+				$start_time = $event_up->hour .':'. $event_up->minute;
+
+				$event_down = new EventsDate( $row->publish_down );
+				$stop_publish = sprintf( "%4d-%02d-%02d",$event_down->year,$event_down->month,$event_down->day);
+				$end_time = $event_down->hour .':'. $event_down->minute;
+
+				$event_registerby = new EventsDate( $row->registerby );
+				$registerby_date = sprintf( "%4d-%02d-%02d",$event_registerby->year,$event_registerby->month,$event_registerby->day);
+				$registerby_time = $event_registerby->hour .':'. $event_registerby->minute;
 			} else {
-				$offset = $this->offset;
+				// No ID - we're creating a new event
+				$year  = $this->year;
+				$month = $this->month;
+				$day   = $this->day;
+
+				if ($year && $month && $day) {
+					$start_publish = $year.'-'.$month.'-'.$day;
+					$stop_publish = $year.'-'.$month.'-'.$day;
+					$registerby_date = $year.'-'.$month.'-'.$day;
+				} else {
+					$offset = $this->offset;
+
+					$start_publish = strftime( "%Y-%m-%d", time()+($offset*60*60) ); //date( "Y-m-d" );
+					$stop_publish = strftime( "%Y-%m-%d", time()+($offset*60*60) );  //date( "Y-m-d" );
+					$registerby_date = strftime( "%Y-%m-%d", time()+($offset*60*60) );  //date( "Y-m-d" );
+				}
 				
-				$start_publish = strftime( "%Y-%m-%d", time()+($offset*60*60) ); //date( "Y-m-d" );
-				$stop_publish = strftime( "%Y-%m-%d", time()+($offset*60*60) );  //date( "Y-m-d" );
-				$registerby_date = strftime( "%Y-%m-%d", time()+($offset*60*60) );  //date( "Y-m-d" );
+				$start_time = "08:00";
+				$end_time = "17:00";
+				$registerby_time = "08:00";
 			}
 
 			// If user hits refresh, try to maintain event form state
@@ -1289,14 +1217,10 @@ class EventsController extends JObject
 			$row->reccurday_month = -1;
 			$row->reccurday_week = -1;
 			$row->reccurday_year = -1;
-			$row->created_by_alias = $juser->get('username');
-			$row->created_by = $juser->get('id');
+			$row->created_by_alias = $this->juser->get('username');
+			$row->created_by = $this->juser->get('id');
 			$row->reccurtype = 0;
 			
-			$start_time = "08:00";
-			$end_time = "17:00";
-			$registerby_time = "08:00";
-			
 			$lists = '';
 		}
 		
@@ -1366,7 +1290,7 @@ class EventsController extends JObject
 		$times['registerby_pm'] = $registerby_pm;
 		
 		// Get tags on this event
-		$rt = new EventsTags( $database );
+		$rt = new EventsTags( $this->database );
 		$lists['tags'] = $rt->get_tag_string($row->id, 0, 0, NULL, 0, 1);
 		
 		// Set the title
@@ -1413,14 +1337,11 @@ class EventsController extends JObject
 	protected function delete()
 	{
 		// Check if they are logged in
-		$juser =& JFactory::getUser();
-		if ($juser->get('guest')) {
+		if ($this->juser->get('guest')) {
 			$this->login();
 			return;
 		}
-		
-		$database =& JFactory::getDBO();
-		
+
 		// Incoming
 		$id = JRequest::getInt( 'id', 0, 'request' );
 		
@@ -1431,7 +1352,7 @@ class EventsController extends JObject
 		}
 		
 		// Load event object
-		$event = new EventsEvent( $database );
+		$event = new EventsEvent( $this->database );
 		$event->load( $id );
 		
 		if (!$this->_authorize($event->created_by)) {
@@ -1443,7 +1364,7 @@ class EventsController extends JObject
 		$event->delete( $id );
 		
 		// Delete any associated pages 
-		$ep = new EventsPage( $database );
+		$ep = new EventsPage( $this->database );
 		$ep->deletePages( $id );
 		
 		// Delete any associated respondents
@@ -1451,15 +1372,15 @@ class EventsController extends JObject
 		$er->deleteRespondents( $id );
 		
 		// Delete tags on this event
-		$rt = new EventsTags( $database );
+		$rt = new EventsTags( $this->database );
 		$rt->remove_all_tags($id);
 		
 		// Load the event's category and update the count
-		$category = new EventsCategory( $database );
+		$category = new EventsCategory( $this->database );
 		$category->updateCount( $event->catid );
 		
 		// Get the HUB configuration
-		//$xhub =& XFactory::getHub();
+		//$xhub =& Hubzero_Factory::getHub();
 		$jconfig =& JFactory::getConfig();
 		
 		// E-mail subject line
@@ -1469,7 +1390,7 @@ class EventsController extends JObject
 		$eview = new JView( array('name'=>'emails','layout'=>'deleted') );
 		$eview->option = $this->_option;
 		$eview->hubShortName = $jconfig->getValue('config.sitename');
-		$eview->juser = $juser;
+		$eview->juser = $this->juser;
 		$eview->event = $event;
 		$message = $eview->loadTemplate();
 		$message = str_replace("\n", "\r\n", $message);
@@ -1486,20 +1407,19 @@ class EventsController extends JObject
 	protected function save() 
 	{
 		// Check if they are logged in
-		$juser =& JFactory::getUser();
-		if ($juser->get('guest')) {
+		if ($this->juser->get('guest')) {
 			$this->login();
 			return;
 		}
-		
-		$database =& JFactory::getDBO();
-		
+
 		$offset = $this->offset;
 		
 		// Incoming
 		$start_time = JRequest::getVar( 'start_time', '08:00', 'post' );
+		$state_time = ($start_time) ? $start_time : '08:00';
 		$start_pm   = JRequest::getInt( 'start_pm', 0, 'post' );
 		$end_time   = JRequest::getVar( 'end_time', '17:00', 'post' );
+		$end_time   = ($end_time) ? $end_time : '17:00';
 		$end_pm     = JRequest::getInt( 'end_pm', 0, 'post' );
 		
 		$reccurweekdays = JRequest::getVar( 'reccurweekdays', array(), 'post' );
@@ -1508,7 +1428,7 @@ class EventsController extends JObject
 		$reccurday_year = JRequest::getVar( 'reccurday_year', '', 'post' );
 
 		// Bind the posted data to an event object
-		$row = new EventsEvent( $database );
+		$row = new EventsEvent( $this->database );
 		if (!$row->bind( $_POST )) {
 			JError::raiseError( 500, $row->getError() );
 			return;
@@ -1518,14 +1438,14 @@ class EventsController extends JObject
 		if ($row->id) {
 			// Existing - update modified info
 			$row->modified = strftime( "%Y-%m-%d %H:%M:%S", time()+($offset*60*60));
-			if ($juser->get('id')) {
-				$row->modified_by = $juser->get('id');
+			if ($this->juser->get('id')) {
+				$row->modified_by = $this->juser->get('id');
 			}
 		} else {
 			// New - set created info
 			$row->created = strftime( "%Y-%m-%d %H:%M:%S", time()+($offset*60*60));
-			if ($juser->get('id')) {
-				$row->created_by = $juser->get('id');
+			if ($this->juser->get('id')) {
+				$row->created_by = $this->juser->get('id');
 			}
 		}
 		
@@ -1604,6 +1524,7 @@ class EventsController extends JObject
 			$end_time = $hrs.':'.$mins;
 		}
 		
+		$rpup = $row->publish_up;
 		if ($row->publish_up) {
 			$publishtime = $row->publish_up.' '.$start_time.':00';
 			$row->publish_up = strftime("%Y-%m-%d %H:%M:%S",strtotime($publishtime));
@@ -1615,9 +1536,11 @@ class EventsController extends JObject
 			$publishtime = $row->publish_down.' '.$end_time.':00';
 			$row->publish_down = strftime("%Y-%m-%d %H:%M:%S",strtotime($publishtime));
 		} else {
-			$row->publish_down = strftime( "%Y-%m-%d 23:59:59", time()+($offset*60*60));
+			$publishtime = $rpup.' '.$end_time.':00';
+			//$row->publish_down = strftime( "%Y-%m-%d 23:59:59", time()+($offset*60*60));
+			$row->publish_down = strftime("%Y-%m-%d %H:%M:%S",strtotime($publishtime));
 		}
-        
+		
 		if ($row->publish_up <> $row->publish_down) {
 			$row->reccurtype = intval( $row->reccurtype );
 		} else {
@@ -1669,6 +1592,17 @@ class EventsController extends JObject
 		$row->state = 1;
 		$row->mask = 0;
 	
+		$pubdow = strtotime($row->publish_down);
+		$pubup = strtotime($row->publish_up);
+		if ($pubdow <= $pubup) {
+			// Set the error message
+			$this->setError('Event end time cannot be before event start time.');
+			// Fall through to the edit view
+			$this->edit($row);
+			return;
+			//$row->publish_down = strftime("%Y-%m-%d %H:%M:%S",strtotime("+1 hour", $pubup));
+		}
+	
 		if (!$row->check()) {
 			// Set the error message
 			$this->setError($row->getError());
@@ -1689,8 +1623,8 @@ class EventsController extends JObject
 		$tags = JRequest::getVar( 'tags', '', 'post' );
 		
 		// Save the tags
-		$rt = new EventsTags( $database );
-		$rt->tag_object($juser->get('id'), $row->id, $tags, 1, 0);
+		$rt = new EventsTags( $this->database );
+		$rt->tag_object($this->juser->get('id'), $row->id, $tags, 1, 0);
 		
 		$jconfig =& JFactory::getConfig();
 		
@@ -1706,7 +1640,7 @@ class EventsController extends JObject
 		}
 		$eview->option = $this->_option;
 		$eview->hubShortName = $jconfig->getValue('config.sitename');
-		$eview->juser = $juser;
+		$eview->juser = $this->juser;
 		$eview->row = $row;
 		$message = $eview->loadTemplate();
 		$message = str_replace("\n", "\r\n", $message);
@@ -1759,12 +1693,10 @@ class EventsController extends JObject
 
 	private function _getCategories() 
 	{
-		$database =& JFactory::getDBO();
-		
 		$sql = "SELECT * FROM #__categories WHERE section='".$this->_option."' AND published = '1' ORDER BY title DESC";
 
-		$database->setQuery($sql);
-		$cats = $database->loadObjectList();
+		$this->database->setQuery($sql);
+		$cats = $this->database->loadObjectList();
 		
 		$c = array();
 		foreach ($cats as $cat) 
@@ -1853,23 +1785,21 @@ class EventsController extends JObject
 	
 	//-----------
 
-	private function _authorize($id='')
+	protected function _authorize($id='')
 	{
-		$juser =& JFactory::getUser();
-		
 		// Check if they are logged in
-		if ($juser->get('guest')) {
+		if ($this->juser->get('guest')) {
 			return false;
 		}
 	
 		// Check if they're a site admin from Joomla
-		if ($juser->authorize($this->_option, 'manage')) {
+		if ($this->juser->authorize($this->_option, 'manage')) {
 			return true;
 		}
 	
 		// Check against events configuration
 		if (!$this->config->getCfg('adminlevel')) {
-			if ($id && $id == $juser->get('id')) {
+			if ($id && $id == $this->juser->get('id')) {
 				return true;
 			}
 		}	
@@ -1877,4 +1807,4 @@ class EventsController extends JObject
 		return false;
 	}
 }
-?>
\ No newline at end of file
+
