@@ -1,85 +1,40 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Alissa Nedossekina <alisa@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Alissa Nedossekina <alisa@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
 
-class FeedbackController extends JObject
-{	
-	private $_name  = NULL;
-	private $_data  = array();
-	private $_task  = NULL;
+ximport('Hubzero_Controller');
 
-	//-----------
-	
-	public function __construct( $config=array() )
-	{
-		$this->_redirect = NULL;
-		$this->_message = NULL;
-		$this->_messageType = 'message';
-		
-		// Set the controller name
-		if (empty( $this->_name )) {
-			if (isset($config['name'])) {
-				$this->_name = $config['name'];
-			} else {
-				$r = null;
-				if (!preg_match('/(.*)Controller/i', get_class($this), $r)) {
-					echo "Controller::__construct() : Can't get or parse class name.";
-				}
-				$this->_name = strtolower( $r[1] );
-			}
-		}
-		
-		// Set the component name
-		$this->_option = 'com_'.$this->_name;
-	}
-
-	//-----------
-
-	public function __set($property, $value)
-	{
-		$this->_data[$property] = $value;
-	}
-	
-	//-----------
-	
-	public function __get($property)
-	{
-		if (isset($this->_data[$property])) {
-			return $this->_data[$property];
-		}
-	}
-	
-	//-----------
-	
+class FeedbackController extends Hubzero_Controller
+{
 	public function execute()
 	{
-		// Load the component config
-		$config =& JComponentHelper::getParams( $this->_option );
-		$this->config = $config;
-		
 		$this->_task = JRequest::getVar( 'task', '', 'post' );
 		if (!$this->_task) {
 			$this->_task = JRequest::getVar( 'task', '', 'get' );
@@ -108,19 +63,9 @@ class FeedbackController extends JObject
 		}
 	}
 
-	//-----------
-
-	public function redirect()
-	{
-		if ($this->_redirect != NULL) {
-			$app =& JFactory::getApplication();
-			$app->redirect( $this->_redirect, $this->_message, $this->_messageType );
-		}
-	}
-
 	//-----------
 	
-	private function _buildPathway() 
+	protected function _buildPathway() 
 	{
 		$app =& JFactory::getApplication();
 		$pathway =& $app->getPathway();
@@ -141,7 +86,7 @@ class FeedbackController extends JObject
 	
 	//-----------
 	
-	private function _buildTitle() 
+	protected function _buildTitle() 
 	{
 		$this->_title = JText::_(strtoupper($this->_option));
 		if ($this->_task) {
@@ -150,24 +95,6 @@ class FeedbackController extends JObject
 		$document =& JFactory::getDocument();
 		$document->setTitle( $this->_title );
 	}
-	
-	//-----------
-	
-	private function _getStyles() 
-	{
-		ximport('xdocument');
-		XDocument::addComponentStylesheet($this->_option);
-	}
-
-	//-----------
-	
-	private function _getScripts()
-	{
-		$document =& JFactory::getDocument();
-		if (is_file('components'.DS.$this->_option.DS.$this->_name.'.js')) {
-			$document->addScript('components'.DS.$this->_option.DS.$this->_name.'.js');
-		}
-	}
 
 	//----------------------------------------------------------
 	// Views
@@ -188,16 +115,14 @@ class FeedbackController extends JObject
 	
 	protected function main() 
 	{
-		$database =& JFactory::getDBO();
-		
 		// Check if wishlist component entry is there
-		$database->setQuery( "SELECT c.id FROM #__components as c WHERE c.option='com_wishlist' AND enabled=1" );
-		$wishlist = $database->loadResult();
+		$this->database->setQuery( "SELECT c.id FROM #__components as c WHERE c.option='com_wishlist' AND enabled=1" );
+		$wishlist = $this->database->loadResult();
 		$wishlist = $wishlist ? 1 : 0;
 		
 		// Check if xpoll component entry is there
-		$database->setQuery( "SELECT c.id FROM #__components as c WHERE c.option='com_xpoll' AND enabled=1" );
-		$xpoll = $database->loadResult();
+		$this->database->setQuery( "SELECT c.id FROM #__components as c WHERE c.option='com_xpoll' AND enabled=1" );
+		$xpoll = $this->database->loadResult();
 		$xpoll = $xpoll ? 1 : 0;
 
 		// Set page title
@@ -226,9 +151,6 @@ class FeedbackController extends JObject
 
 	protected function success_story()
 	{
-		// Logged-in user?
-		$juser =& JFactory::getUser();
-		
 		// Incoming
 		$quote = array();
 		$quote['long'] = JRequest::getVar('quote', '', 'post');
@@ -250,7 +172,7 @@ class FeedbackController extends JObject
 		// Push some styles to the template
 		$this->_getStyles();
 		
-		if($juser->get('guest')) {
+		if ($this->juser->get('guest')) {
 			$this->_msg = JText::_('To submit a success story, you need to be logged in. Please login using the form below:');
 			$this->login();
 			return;
@@ -264,7 +186,7 @@ class FeedbackController extends JObject
 		$view->user = $this->_getUser();
 		$view->quote = $quote;
 		$view->captcha = $captcha;
-		$view->verified = ($juser->get('guest')) ? 0 : 1;
+		$view->verified = ($this->juser->get('guest')) ? 0 : 1;
 		if ($this->getError()) {
 			$view->setError( $this->getError() );
 		}
@@ -299,9 +221,6 @@ class FeedbackController extends JObject
 
 	protected function suggestions() 
 	{
-		// Logged-in user?
-		$juser =& JFactory::getUser();
-		
 		// Incoming
 		$suggestion = array();
 		$suggestion['for'] = JRequest::getVar( 'for', '' );
@@ -329,7 +248,7 @@ class FeedbackController extends JObject
 		$view->task = $this->_task;
 		$view->user = $this->_getUser();
 		$view->suggestion = $suggestion;
-		$view->verified = ($juser->get('guest')) ? 0 : 1;
+		$view->verified = ($this->juser->get('guest')) ? 0 : 1;
 		if ($this->getError()) {
 			$view->setError( $this->getError() );
 		}
@@ -340,9 +259,6 @@ class FeedbackController extends JObject
 
 	protected function report_problems() 
 	{
-		// Logged-in user?
-		$juser =& JFactory::getUser();
-	
 		// Get browser info
 		ximport('Hubzero_Browser');
 		$browser = new Hubzero_Browser();
@@ -373,7 +289,7 @@ class FeedbackController extends JObject
 		
 		// Push some styles to the template
 		$this->_getStyles();
-		
+
 		// Output HTML
 		$view = new JView( array('name'=>'report') );
 		$view->title = $this->_title;
@@ -381,7 +297,7 @@ class FeedbackController extends JObject
 		$view->task = $this->_task;
 		$view->reporter = $this->_getUser();
 		$view->problem = $problem;
-		$view->verified = ($juser->get('guest')) ? 0 : 1;
+		$view->verified = ($this->juser->get('guest')) ? 0 : 1;
 		if ($this->getError()) {
 			$view->setError( $this->getError() );
 		}
@@ -402,11 +318,9 @@ class FeedbackController extends JObject
 	
 		// Push some styles to the template
 		$this->_getStyles();
-	
-		$database =& JFactory::getDBO();
-	
+
 		// Initiate class and bind posted items to database fields
-		$row = new FeedbackQuotes( $database );
+		$row = new FeedbackQuotes( $this->database );
 		if (!$row->bind( $_POST )) {
 			JError::raiseError( 500, $row->getError() );
 			return;
@@ -445,6 +359,7 @@ class FeedbackController extends JObject
 		$row->quote = Hubzero_View_Helper_Html::purifyText($row->quote);
 		$row->quote = str_replace( '<br>', '<br />', $row->quote );
 		$row->date  = date( 'Y-m-d H:i:s', time() );
+		$row->picture = basename($row->picture);
 		
 		// Check content
 		if (!$row->check()) {
@@ -501,11 +416,9 @@ class FeedbackController extends JObject
 		$sum = $suggestion['operand1'] + $suggestion['operand2'];
 		$suggestion['key'] = $this->_generate_hash($sum,date('j'));
 		
-		$juser =& JFactory::getUser();
-	
 		if ($suggester['name'] && $suggestion['for'] && $suggestion['idea'] && $validemail) {			
 			// Are the logged in?
-			if ($juser->get('guest')) {
+			if ($this->juser->get('guest')) {
 				// No - don't trust user
 				// Check CAPTCHA
 				$key = JRequest::getInt( 'krhash', 0 );
@@ -519,7 +432,7 @@ class FeedbackController extends JObject
 					$view->task = $this->_task;
 					$view->user = $suggester;
 					$view->suggestion = $suggestion;
-					$view->verified = ($juser->get('guest')) ? 0 : 1;
+					$view->verified = ($this->juser->get('guest')) ? 0 : 1;
 					$view->setError(3);
 					$view->display();
 					return;
@@ -528,7 +441,7 @@ class FeedbackController extends JObject
 			
 			// Get user's IP and domain
 			$ip = $this->_ip_address();
-			$hostname = gethostbyaddr($_SERVER['REMOTE_ADDR']);
+			$hostname = gethostbyaddr(JRequest::getVar('REMOTE_ADDR','','server'));
 			
 			// Quick spam filter
 			$spam = $this->_detect_spam($suggestion['idea'], $ip);
@@ -540,7 +453,7 @@ class FeedbackController extends JObject
 				$view->task = $this->_task;
 				$view->user = $suggester;
 				$view->suggestion = $suggestion;
-				$view->verified = ($juser->get('guest')) ? 0 : 1;
+				$view->verified = ($this->juser->get('guest')) ? 0 : 1;
 				$view->setError(1);
 				$view->display();
 				return;
@@ -555,7 +468,7 @@ class FeedbackController extends JObject
 			$hub     = array('email' => $suggester['email'], 'name' => $from);
 			
 			// Generate e-mail message
-			$message  = (!$juser->get('guest')) ? JText::_('COM_FEEDBACK_VERIFIED_USER')."\r\n" : '';
+			$message  = (!$this->juser->get('guest')) ? JText::_('COM_FEEDBACK_VERIFIED_USER')."\r\n" : '';
 			$message .= ($suggester['login']) ? JText::_('COM_FEEDBACK_USERNAME').': '. $suggester['login'] ."\r\n" : '';
 			$message .= JText::_('COM_FEEDBACK_NAME').': '. $suggester['name'] ."\r\n";
 			$message .= JText::_('COM_FEEDBACK_AFFILIATION').': '. $suggester['org'] ."\r\n";
@@ -564,14 +477,20 @@ class FeedbackController extends JObject
 			$message .= JText::_('COM_FEEDBACK_IDEA').': '. $suggestion['idea'] ."\r\n";
 	
 			// Send e-mail
-			ximport('xhubhelper');
-			XHubHelper::send_email($admin, $subject, $message);
+			ximport('Hubzero_Toolbox');
+			Hubzero_Toolbox::send_email($admin, $subject, $message);
 			
 			// Get their browser and OS
-			list( $os, $os_version, $browser, $browser_ver ) = $this->_browsercheck($_SERVER['HTTP_USER_AGENT']);
+			ximport('Hubzero_Browser');
+			$hbrowser = new Hubzero_Browser();
+
+			$os = $hbrowser->getOs();
+			$os_version = $hbrowser->getOsVersion();
+			$browser = $hbrowser->getBrowser();
+			$browser_ver = $hbrowser->getBrowserVersion();
 		
 			// Create new support ticket
-			include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_support'.DS.'support.ticket.php' );
+			include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_support'.DS.'tables'.DS.'ticket.php' );
 			
 			$data = array();
 			$data['id']        = NULL;
@@ -590,15 +509,13 @@ class FeedbackController extends JObject
 			$data['browser']   = $browser .' '. $browser_ver;
 			$data['ip']        = $ip;
 			$data['hostname']  = $hostname;
-			$data['uas']       = $_SERVER['HTTP_USER_AGENT'];
+			$data['uas']       = JRequest::getVar('HTTP_USER_AGENT','','server');
 			$data['referrer']  = NULL;
-			$data['cookies']   = (!empty($_COOKIE['sessioncookie'])) ? 1 : 0;
+			$data['cookies']   = (JRequest::getVar('sessioncookie','','cookie')) ? 1 : 0;
 			$data['instances'] = 1;
 			$data['section']   = 1;
 			
-			$database =& JFactory::getDBO();
-			
-			$row = new SupportTicket( $database );
+			$row = new SupportTicket( $this->database );
 			if (!$row->bind( $data )) {
 				$this->setError( $row->getError() );
 			}
@@ -632,7 +549,7 @@ class FeedbackController extends JObject
 			$view->task = $this->_task;
 			$view->user = $suggester;
 			$view->suggestion = $suggestion;
-			$view->verified = ($juser->get('guest')) ? 0 : 1;
+			$view->verified = ($this->juser->get('guest')) ? 0 : 1;
 			if ($this->getError()) {
 				$view->setError( $this->getError() );
 			}
@@ -644,7 +561,15 @@ class FeedbackController extends JObject
 
 	protected function sendreport() 
 	{
-		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_support'.DS.'support.ticket.php' );
+		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_support'.DS.'tables'.DS.'attachment.php' );
+		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_support'.DS.'tables'.DS.'ticket.php' );
+
+		// Get plugins
+		JPluginHelper::importPlugin( 'support' );
+		$dispatcher =& JDispatcher::getInstance();
+
+		// Trigger any events that need to be called before session stop
+		$dispatcher->trigger( 'onPreTicketSubmission', array() );
 
 		// Incoming
 		$no_html  = JRequest::getInt( 'no_html', 0 );
@@ -671,10 +596,13 @@ class FeedbackController extends JObject
 		$sum = $problem['operand1'] + $problem['operand2'];
 		$problem['key'] = $this->_generate_hash($sum,date('j'));
 	
-		$juser =& JFactory::getUser();
+		// Trigger any events that need to be called
+		$customValidation = true;
+		$result = $dispatcher->trigger( 'onValidateTicketSubmission', array($reporter, $problem) );
+		$customValidation = (is_array($result) && !empty($result)) ? $result[0] : $customValidation;
 
 		// Check for some required fields
-		if (!$reporter['name'] || !$reporter['email'] || !$validemail || !$problem['long']) {
+		if (!$reporter['name'] || !$reporter['email'] || !$validemail || !$problem['long'] || !$customValidation) {
 			// Output form with error messages
 			$view = new JView( array('name'=>'report') );
 			$view->title = $this->_title;
@@ -682,7 +610,7 @@ class FeedbackController extends JObject
 			$view->task = 'report_problems';
 			$view->reporter = $reporter;
 			$view->problem = $problem;
-			$view->verified = ($juser->get('guest')) ? 0 : 1;
+			$view->verified = ($this->juser->get('guest')) ? 0 : 1;
 			$view->setError(2);
 			$view->display();
 			return;
@@ -690,10 +618,10 @@ class FeedbackController extends JObject
 		
 		// Get the user's IP
 		$ip = $this->_ip_address();
-		$hostname = gethostbyaddr($_SERVER['REMOTE_ADDR']);
+		$hostname = gethostbyaddr(JRequest::getVar('REMOTE_ADDR','','server'));
 			
 		// Are the logged in?
-		if ($juser->get('guest')) {
+		if ($this->juser->get('guest')) {
 			// No - don't trust user
 			// Check CAPTCHA
 			$key = JRequest::getVar( 'krhash', 0 );
@@ -720,7 +648,7 @@ class FeedbackController extends JObject
 					$view->task = 'report_problems';
 					$view->reporter = $reporter;
 					$view->problem = $problem;
-					$view->verified = ($juser->get('guest')) ? 0 : 1;
+					$view->verified = ($this->juser->get('guest')) ? 0 : 1;
 					$view->setError(3);
 					$view->display();
 					return;
@@ -733,8 +661,8 @@ class FeedbackController extends JObject
 		$source_region  = 'unknown';
 		$source_country = 'unknown';
 		
-		ximport('xgeoutils');
-		$gdb =& GeoUtils::getGODBO();
+		ximport('Hubzero_Geo');
+		$gdb =& Hubzero_Geo::getGODBO();
 		if (is_object($gdb)) {
 			$gdb->setQuery( "SELECT countrySHORT, countryLONG, ipREGION, ipCITY FROM ipcitylatlong WHERE INET_ATON('$ip') BETWEEN ipFROM and ipTO" );
 			$rows = $gdb->loadObjectList();
@@ -778,16 +706,15 @@ class FeedbackController extends JObject
 		$data['browser']   = $problem['browser'] .' '. $problem['browserver'];
 		$data['ip']        = $ip;
 		$data['hostname']  = $hostname;
-		$data['uas']       = $_SERVER['HTTP_USER_AGENT'];
+		$data['uas']       = JRequest::getVar('HTTP_USER_AGENT','','server');
 		$data['referrer']  = $problem['referer'];
-		$data['cookies']   = (!empty($_COOKIE['sessioncookie'])) ? 1 : 0;
+		$data['cookies']   = (JRequest::getVar('sessioncookie','','cookie')) ? 1 : 0;
 		$data['instances'] = 1;
 		$data['section']   = 1;
 		$data['group']     = $group;
 		
 		// Initiate class and bind data to database fields
-		$database =& JFactory::getDBO();
-		$row = new SupportTicket( $database );
+		$row = new SupportTicket( $this->database );
 		if (!$row->bind( $data )) {
 			$this->setError( $row->getError() );
 		}
@@ -804,6 +731,16 @@ class FeedbackController extends JObject
 			$row->getId();
 		}
 		
+		$sconfig = JComponentHelper::getParams( 'com_support' );
+		$attachment = $this->_uploadAttachment( $row->id, $sconfig );
+		$row->report .= ($attachment) ? "\n\n".$attachment : '';
+		$problem['long'] .= ($attachment) ? "\n\n".$attachment : '';
+		
+		// Save the data
+		if (!$row->store()) {
+			$this->setError( $row->getError() );
+		}
+		
 		// Get some email settings
 		$jconfig =& JFactory::getConfig();
 		$admin   = $jconfig->getValue('config.mailfrom');
@@ -811,8 +748,15 @@ class FeedbackController extends JObject
 		$from    = $jconfig->getValue('config.sitename').' web-robot';
 		$hub     = array('email' => $reporter['email'], 'name' => $from);
 		
+		// Parse comments for attachments
+		$xhub =& Hubzero_Factory::getHub();
+		$attach = new SupportAttachment( $this->database );
+		$attach->webpath = $xhub->getCfg('hubLongURL').$sconfig->get('webpath').DS.$row->id;
+		$attach->uppath  = JPATH_ROOT.$sconfig->get('webpath').DS.$row->id;
+		$attach->output  = 'email';
+		
 		// Generate e-mail message
-		$message  = (!$juser->get('guest')) ? JText::_('COM_FEEDBACK_VERIFIED_USER')."\r\n\r\n" : '';
+		$message  = (!$this->juser->get('guest')) ? JText::_('COM_FEEDBACK_VERIFIED_USER')."\r\n\r\n" : '';
 		$message .= ($reporter['login']) ? JText::_('COM_FEEDBACK_USERNAME').': '. $reporter['login'] ."\r\n" : '';
 		$message .= JText::_('COM_FEEDBACK_NAME').': '. $reporter['name'] ."\r\n";
 		$message .= JText::_('COM_FEEDBACK_AFFILIATION').': '. $reporter['org'] ."\r\n";
@@ -821,17 +765,27 @@ class FeedbackController extends JObject
 		$message .= JText::_('COM_FEEDBACK_REGION').': '.$source_city.', '.$source_region.', '.$source_country ."\r\n\r\n";
 		$message .= JText::_('COM_FEEDBACK_OS').': '. $problem['os'] .' '. $problem['osver'] ."\r\n";
 		$message .= JText::_('COM_FEEDBACK_BROWSER').': '. $problem['browser'] .' '. $problem['browserver'] ."\r\n";
-		$message .= JText::_('COM_FEEDBACK_UAS').': '. $_SERVER['HTTP_USER_AGENT'] ."\r\n";
+		$message .= JText::_('COM_FEEDBACK_UAS').': '. JRequest::getVar('HTTP_USER_AGENT','','server') ."\r\n";
 		$message .= JText::_('COM_FEEDBACK_COOKIES').': ';
-		$message .= (!empty($_COOKIE['sessioncookie'])) ? JText::_('COM_FEEDBACK_COOKIES_ENABLED')."\r\n" : JText::_('COM_FEEDBACK_COOKIES_DISABLED')."\r\n";
+		$message .= (JRequest::getVar('sessioncookie','','cookie')) ? JText::_('COM_FEEDBACK_COOKIES_ENABLED')."\r\n" : JText::_('COM_FEEDBACK_COOKIES_DISABLED')."\r\n";
 		$message .= JText::_('COM_FEEDBACK_REFERRER').': '. $problem['referer'] ."\r\n";
 		$message .= ($problem['tool']) ? JText::_('COM_FEEDBACK_TOOL').': '. $problem['tool'] ."\r\n\r\n" : "\r\n";
-		$message .= JText::_('COM_FEEDBACK_PROBLEM_DETAILS').': '. stripslashes($problem['long']) ."\r\n";
+		$message .= JText::_('COM_FEEDBACK_PROBLEM_DETAILS').': '. $attach->parse(stripslashes($problem['long'])) ."\r\n\r\n";
+
+		$juri =& JURI::getInstance();
+		$sef = JRoute::_('index.php?option=com_support&task=ticket&id='. $row->id);
+		if (substr($sef,0,1) == '/') {
+			$sef = substr($sef,1,strlen($sef));
+		}
+		$message .= $juri->base().$sef."\r\n";
 
 		// Send e-mail
-		ximport('xhubhelper');
-		XHubHelper::send_email($admin, $subject, $message);
-
+		ximport('Hubzero_Toolbox');
+		Hubzero_Toolbox::send_email($admin, $subject, $message);
+		
+		// Trigger any events that need to be called before session stop
+		$dispatcher->trigger( 'onTicketSubmission', array($row) );
+		
 		// Output Thank You message
 		$view = new JView( array('name'=>'report', 'layout'=>'thanks') );
 		$view->title = $this->_title;
@@ -844,6 +798,70 @@ class FeedbackController extends JObject
 		}
 		$view->display();
 	}
+	
+	//-----------
+
+	private function _uploadAttachment( $listdir, $sconfig )
+	{
+		if (!$listdir) {
+			$this->setError( JText::_('SUPPORT_NO_UPLOAD_DIRECTORY') );
+			return '';
+		}
+		
+		// Incoming file
+		$file = JRequest::getVar( 'upload', '', 'files', 'array' );
+		if (!$file['name']) {
+			return '';
+		}
+		
+		// Incoming
+		$description = ''; //JRequest::getVar( 'description', '' );
+		
+		// Construct our file path
+		$path = JPATH_ROOT.$sconfig->get('webpath').DS.$listdir;
+		
+		// Build the path if it doesn't exist
+		if (!is_dir( $path )) {
+			jimport('joomla.filesystem.folder');
+			if (!JFolder::create( $path, 0777 )) {
+				$this->setError( JText::_('UNABLE_TO_CREATE_UPLOAD_PATH') );
+				return '';
+			}
+		}
+
+		// Make the filename safe
+		jimport('joomla.filesystem.file');
+		$file['name'] = JFile::makeSafe($file['name']);
+		$file['name'] = str_replace(' ','_',$file['name']);
+		$ext = strtolower(JFile::getExt($file['name']));
+		if (!in_array($ext, array('jpg','jpeg','jpe','png','bmp','gif'))) {
+			return '';
+		}
+
+		// Perform the upload
+		if (!JFile::upload($file['tmp_name'], $path.DS.$file['name'])) {
+			$this->setError( JText::_('ERROR_UPLOADING') );
+			return '';
+		} else {
+			// File was uploaded
+			// Create database entry
+			$description = htmlspecialchars($description);
+			
+			$row = new SupportAttachment( $this->database );
+			$row->bind( array('id'=>0,'ticket'=>$listdir,'filename'=>$file['name'],'description'=>$description) );
+			if (!$row->check()) {
+				$this->setError( $row->getError() );
+			}
+			if (!$row->store()) {
+				$this->setError( $row->getError() );
+			}
+			if (!$row->id) {
+				$row->getID();
+			}
+			
+			return '{attachment#'.$row->id.'}';
+		}
+	}
 
 	//-----------
 
@@ -899,11 +917,9 @@ class FeedbackController extends JObject
 		if (!$tool) {
 			return '';
 		}
-		
-		$database =& JFactory::getDBO();
-		
-		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_resources'.DS.'resources.resource.php');
-		$resource = new ResourcesResource( $database );
+
+		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_resources'.DS.'tables'.DS.'resource.php');
+		$resource = new ResourcesResource( $this->database );
 		$tool = str_replace(':','-',$tool);
 		$resource->loadAlias( $tool );
 		
@@ -912,8 +928,8 @@ class FeedbackController extends JObject
 		}
 			
 		// Get tags on the tools
-		include_once( JPATH_ROOT.DS.'components'.DS.'com_resources'.DS.'resources.tags.php' );
-		$rt = new ResourcesTags($database);
+		include_once( JPATH_ROOT.DS.'components'.DS.'com_resources'.DS.'helpers'.DS.'tags.php' );
+		$rt = new ResourcesTags($this->database);
 		$tags = $rt->getTags( $resource->id, 0, 0, 1 );
 
 		if (!$tags) {
@@ -921,8 +937,8 @@ class FeedbackController extends JObject
 		}
 
 		// Get tag/group associations
-		include_once( JPATH_ROOT.DS.'components'.DS.'com_tags'.DS.'tags.tag.php' );
-		$tt = new TagsGroup( $database );
+		//include_once( JPATH_ROOT.DS.'components'.DS.'com_tags'.DS.'helpers'.DS.'handler.php' );
+		$tt = new TagsGroup( $this->database );
 		$tgas = $tt->getRecords();
 			
 		if (!$tgas) {
@@ -953,6 +969,12 @@ class FeedbackController extends JObject
 
 	protected function upload()
 	{
+		if ($this->juser->get('guest')) {
+			$this->setError( JText::_('COM_FEEDBACK_NOTAUTH') );
+			$this->img( '', 0 );
+			return;
+		}
+		
 		// Incoming
 		$id = JRequest::getInt( 'id', 0 );
 		if (!$id) {
@@ -970,8 +992,7 @@ class FeedbackController extends JObject
 		}
 
 		// Build upload path
-		ximport('fileuploadutils');
-		$dir  = FileUploadUtils::niceidformat( $id );
+		$dir  = Hubzero_View_Helper_Html::niceidformat( $id );
 		$path = JPATH_ROOT;
 		if (substr($this->config->get('uploadpath'), 0, 1) != DS) {
 			$path .= DS;
@@ -1025,11 +1046,24 @@ class FeedbackController extends JObject
 
 	protected function delete()
 	{
+		if ($this->juser->get('guest')) {
+			$this->setError( JText::_('COM_FEEDBACK_NOTAUTH') );
+			$this->img( '', 0 );
+			return;
+		}
+		
 		// Incoming member ID
 		$id = JRequest::getInt( 'id', 0 );
 		if (!$id) {
 			$this->setError( JText::_('COM_FEEDBACK_NO_ID') );
 			$this->img( '', $id );
+			return;
+		}
+		
+		if ($this->juser->get('id') != $id) {
+			$this->setError( JText::_('COM_FEEDBACK_NOTAUTH') );
+			$this->img( '', $this->juser->get('id') );
+			return;
 		}
 		
 		// Incoming file
@@ -1037,11 +1071,13 @@ class FeedbackController extends JObject
 		if (!$file) {
 			$this->setError( JText::_('COM_FEEDBACK_NO_FILE') );
 			$this->img( '', $id );
+			return;
 		}
 		
+		$file = basename($file);
+		
 		// Build the file path
-		ximport('fileuploadutils');
-		$dir  = FileUploadUtils::niceidformat( $id );
+		$dir  = Hubzero_View_Helper_Html::niceidformat( $id );
 		$path = JPATH_ROOT;
 		if (substr($this->config->get('uploadpath'), 0, 1) != DS) {
 			$path .= DS;
@@ -1059,6 +1095,7 @@ class FeedbackController extends JObject
 			if (!JFile::delete($path.DS.$file)) {
 				$this->setError( JText::_('COM_FEEDBACK_UNABLE_TO_DELETE_FILE') );
 				$this->img( $file, $id );
+				return;
 			}
 
 			$file = '';
@@ -1076,8 +1113,7 @@ class FeedbackController extends JObject
 		if (!$id) {
 			$id = JRequest::getInt( 'id', 0 );
 		}
-		ximport('fileuploadutils');
-		$dir = FileUploadUtils::niceidformat( $id );
+		$dir = Hubzero_View_Helper_Html::niceidformat( $id );
 		
 		// Do we have a file or do we need to get one?
 		$file = ($file) 
@@ -1110,20 +1146,18 @@ class FeedbackController extends JObject
 
 	private function _getUser() 
 	{
-		$juser =& JFactory::getUser();
-		
 		$user = array();
 		$user['login'] = '';
 		$user['name']  = '';
 		$user['org']   = '';
 		$user['email'] = '';
 		$user['uid']   = '';
-		
-		if (!$juser->get('guest')) {
-			ximport('xprofile');
+
+		if (!$this->juser->get('guest')) {
+			ximport('Hubzero_User_Profile');
 			
-			$profile = new XProfile();
-			$profile->load( $juser->get('id') );
+			$profile = new Hubzero_User_Profile();
+			$profile->load( $this->juser->get('id') );
 			
 			if (is_object($profile)) {
 				$user['login'] = $profile->get('username');
@@ -1241,7 +1275,7 @@ class FeedbackController extends JObject
 			return FALSE;
 		}
 		
-		return $_SERVER[$index];
+		return TRUE;
 	}
 	
 	//-----------
@@ -1256,13 +1290,13 @@ class FeedbackController extends JObject
 	private function _ip_address()
 	{
 		if ($this->_server('REMOTE_ADDR') AND $this->_server('HTTP_CLIENT_IP')) {
-			 $ip_address = $_SERVER['HTTP_CLIENT_IP'];
+			 $ip_address = JRequest::getVar('HTTP_CLIENT_IP','','server');
 		} elseif ($this->_server('REMOTE_ADDR')) {
-			 $ip_address = $_SERVER['REMOTE_ADDR'];
+			 $ip_address = JRequest::getVar('REMOTE_ADDR','','server');
 		} elseif ($this->_server('HTTP_CLIENT_IP')) {
-			 $ip_address = $_SERVER['HTTP_CLIENT_IP'];
+			 $ip_address = JRequest::getVar('HTTP_CLIENT_IP','','server');
 		} elseif ($this->_server('HTTP_X_FORWARDED_FOR')) {
-			 $ip_address = $_SERVER['HTTP_X_FORWARDED_FOR'];
+			 $ip_address = JRequest::getVar('HTTP_X_FORWARDED_FOR','','server');
 		}
 		
 		if ($ip_address === FALSE) {
@@ -1282,4 +1316,4 @@ class FeedbackController extends JObject
 		return $ip_address;
 	}
 }
-?>
\ No newline at end of file
+
