@@ -1,25 +1,29 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Nicholas J. Kisseberth <nkissebe@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Nicholas J. Kisseberth <nkissebe@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
@@ -78,7 +82,7 @@ class HubController extends JObject
 	
 	private function _cookie_check()
 	{
-		$xhub =& XFactory::getHub();
+		$xhub =& Hubzero_Factory::getHub();
 		$jsession =& JFactory::getSession();
 		$jcookie = $jsession->getName();
 
@@ -120,7 +124,7 @@ class HubController extends JObject
 		$this->_task = JRequest::getVar('task','','method');
 		$this->_act  = JRequest::getVar('act','','method');
 		
-		$xhub =& XFactory::getHub();
+		$xhub =& Hubzero_Factory::getHub();
 
 		if (!isset( $_SERVER['HTTPS'] ) || $_SERVER['HTTPS'] == 'off') {
 			$xhub->redirect( 'https://' . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'] ); 
@@ -182,7 +186,7 @@ class HubController extends JObject
 	public function logout()
 	{       
 		$app  =& JFactory::getApplication();
-		$xhub =& XFactory::getHub();
+		$xhub =& Hubzero_Factory::getHub();
 		
 		// Preform the logout action
 		$error = $app->logout();
@@ -207,7 +211,7 @@ class HubController extends JObject
 
 	public function login($action = 'show')
 	{
-		$xhub =& XFactory::getHub();
+		$xhub =& Hubzero_Factory::getHub();
 		$juser = &JFactory::getUser();
 
 		$return = base64_decode( JRequest::getVar('return', '',  'method', 'base64') );
@@ -323,7 +327,7 @@ class HubController extends JObject
 
 	protected function realm($action = null)
 	{
-		$xhub =& XFactory::getHub();
+		$xhub =& Hubzero_Factory::getHub();
 		
 		if (!$this->_cookie_check()) {
 			return;
@@ -376,7 +380,7 @@ class HubController extends JObject
 	protected function lostusername() 
 	{
 		// Load some needed libraries
-		ximport('xregistrationhelper');
+		ximport('Hubzero_Registration_Helper');
 
 		$this->_view = $this->_task;
 		
@@ -404,7 +408,7 @@ class HubController extends JObject
 		if ($resend) {
 			if (empty($email)) {
 				$this->setError( JText::_('Please provide a valid e-mail address.') );
-			} else if (!XRegistrationHelper::validemail($email)) {
+			} else if (!Hubzero_Registration_Helper::validemail($email)) {
 				$this->setError( JText::_('Invalid e-mail address. Example: someone@somewhere.com') );
 			} else {
 				// Send the account recovery
@@ -426,19 +430,18 @@ class HubController extends JObject
 
 	private function send_account_recovery($email)
 	{
-		ximport('xprofile');
-		ximport('xuserhelper');
-		ximport('xprofile');
-		ximport('xhubhelper');
+		ximport('Hubzero_User_Profile');
+		ximport('Hubzero_User_Helper');
+		ximport('Hubzero_Toolbox');
 		
-		$xhub =& XFactory::getHub();
+		$xhub =& Hubzero_Factory::getHub();
 		$hubShortName = $xhub->getCfg('hubShortName');
 		$hubLongURL = $xhub->getCfg('hubLongURL');
 		$hubMonitorEmail = $xhub->getCfg('hubMonitorEmail');
 		$hubHomeDir = $xhub->getCfg('hubHomeDir');
 
 		// Attempt to load an account with this email address
-		$emailusers = XProfileHelper::find_by_email($email);
+		$emailusers = Hubzero_User_Profile_Helper::find_by_email($email);
 		
 		if (empty($emailusers)) {
 			return JError::raiseError(403, 'Request Invalid: Error locating an account with the email address [' . $email . '].');
@@ -457,9 +460,9 @@ class HubController extends JObject
 		$message .= " registered to this address:\r\n";
 		foreach ($emailusers as $emailuser) 
 		{
-			$xprofile =& XProfile::getInstance($emailuser);
+			$xprofile =& Hubzero_User_Profile::getInstance($emailuser);
 
-			$message .= "\t" . $xprofile->get('login') . "\t(" . $xprofile->get('name') . ")\r\n";
+			$message .= "\t" . $xprofile->get('username') . "\t(" . $xprofile->get('name') . ")\r\n";
 		}
 		$message .= "\r\n";
 		$message .= "You may login to " . $hubShortName . " using ";
@@ -475,7 +478,7 @@ class HubController extends JObject
 		$message .= $hubLongURL .DS.JRoute::_('index.php?option='.$this->_option.'&task=lostpassword') . "\r\n";
 
 		// Send the email
-		if (XHubHelper::send_email($email, $subject, $message)) {
+		if (Hubzero_Toolbox::send_email($email, $subject, $message)) {
 			// Admin email subject
 			$subject = $hubShortName . " Account Recovery";
 			
@@ -483,10 +486,10 @@ class HubController extends JObject
 			$message = "A user has recovered account login information for the email address:\r\n";
 			$message .= "\t" . $email . "\r\n\r\n";
 			$message .= "Click the following link to look up this user's account(s):\r\n";
-			$message .= $hubLongURL . '/whois/?email=' . $email . "\r\n";
+			$message .= $hubLongURL . '/members/whois/?email=' . $email . "\r\n";
 			
 			// Send the admin email
-			XHubHelper::send_email($hubMonitorEmail, $subject, $message);
+			Hubzero_Toolbox::send_email($hubMonitorEmail, $subject, $message);
 		} else { 
 			return JError::raiseError(500, 'Internal Error: Error emailing your account information to the email address [' . $email . '].');
 		}
@@ -499,12 +502,12 @@ class HubController extends JObject
 	protected function lostpassword() 
 	{
 		// Load some needed libraries
-		ximport('xregistrationhelper');
-		ximport('xuserhelper');
-		ximport('xhubhelper');
-		ximport('xprofile');
+		ximport('Hubzero_Registration_Helper');
+		ximport('Hubzero_User_Helper');
+		ximport('Hubzero_Toolbox');
+		ximport('Hubzero_User_Profile');
 		
-		$xprofile =& XFactory::getProfile();
+		$xprofile =& Hubzero_Factory::getProfile();
 
 		$this->_view = $this->_task;
 
@@ -527,7 +530,7 @@ class HubController extends JObject
 		$view->passed = false;
 
 		// Check if the user *can* reset their password
-		if ( is_object($xprofile) && (XUserHelper::isXDomainUser($xprofile->get('uidNumber'))) ) {
+		if ( is_object($xprofile) && (Hubzero_User_Helper::isXDomainUser($xprofile->get('uidNumber'))) ) {
 			$view->setError( JText::_('This is a linked account. To retrieve your password you must do so using the procedures available where the account your are linked to is managed.') );
 			$view->display();
 			return;
@@ -541,7 +544,7 @@ class HubController extends JObject
 		// Was the form submitted?
 		if ($view->reset) {
 			// Attempt to load a user with the given username
-			$xprofile =& XProfile::getInstance($view->login);
+			$xprofile =& Hubzero_User_Profile::getInstance($view->login);
 
 			// Ensure we have a user with this login and e-mail
 			if (!is_object($xprofile)) {
@@ -557,12 +560,12 @@ class HubController extends JObject
 			}
 
 			// Generate a new password
-			$newpass = XRegistrationHelper::userpassgen();
+			$newpass = Hubzero_Registration_Helper::userpassgen();
 
 			// Initiate profile class
-			$profile = new XProfile();
+			$profile = new Hubzero_User_Profile();
 			$profile->load( $xprofile->get('uidNumber') );
-			$profile->set('userPassword', XUserHelper::encrypt_password($newpass));
+			$profile->set('userPassword', Hubzero_User_Helper::encrypt_password($newpass));
 
 			if (!$profile->update()) {
 				$this->setError( JText::_('There was an error resetting your password.') );
@@ -611,12 +614,12 @@ class HubController extends JObject
 			$from['email'] = $jconfig->getValue('config.mailfrom');
 
 			// E-mail the administrator
-			if (!XHubHelper::send_email($jconfig->getValue('config.mailfrom'), $subject, $admmessage)) {
+			if (!Hubzero_Toolbox::send_email($jconfig->getValue('config.mailfrom'), $subject, $admmessage)) {
 				$this->setError(JText::_("There was an error emailing '" . htmlentities($jconfig->getValue('config.mailfrom'),ENT_COMPAT,'UTF-8') . "' about your password change request."));
 			}
 
 			// E-mail the user
-			if (!XHubHelper::send_email($xprofile->get('email'), $subject, $usrmessage)) {
+			if (!Hubzero_Toolbox::send_email($xprofile->get('email'), $subject, $usrmessage)) {
 				$this->setError(JText::_("There was an error emailing '" . htmlentities($xprofile->get('email'),ENT_COMPAT,'UTF-8') . "' your new password."));
 			}
 
@@ -632,4 +635,4 @@ class HubController extends JObject
 		$view->display();
 	}
 }
-?>
+
