@@ -1,25 +1,29 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Shawn Rice <zooley@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Shawn Rice <zooley@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
@@ -57,7 +61,7 @@ if ($this->authorized === 'admin') {
 	$html .= "\t\t".'<p>'.JText::_('The following options are available to administrators only.').'</p>'."\n";
 	$html .= "\t".'</div>'."\n";
 	$html .= "\t".'<fieldset>'."\n";
-	$html .= "\t\t".'<h3>'.JText::_('Admin Options').'</h3>'."\n";
+	$html .= "\t\t".'<legend>'.JText::_('Admin Options').'</legend>'."\n";
 	$html .= "\t\t".'<label>'."\n";
 	$html .= "\t\t\t".'<input type="checkbox" class="option" name="profile[vip]" value="1"';
 	if ($this->profile->get('vip') == 1) { 
@@ -82,7 +86,7 @@ if ($enabled) {
 }
 $html .= "\t".'</div>'."\n";
 $html .= "\t".'<fieldset>'."\n";
-$html .= "\t\t".'<h3>'.JText::_('Contact Information').'</h3>'."\n";
+$html .= "\t\t".'<legend>'.JText::_('Contact Information').'</legend>'."\n";
 $html .= "\t\t".'<input type="hidden" name="id" value="'. $this->profile->get('uidNumber') .'" />'."\n";
 $html .= "\t\t".'<input type="hidden" name="option" value="'. $this->option .'" />'."\n";
 $html .= "\t\t".'<input type="hidden" name="task" value="save" />'."\n";
@@ -191,7 +195,7 @@ if ($this->registration->Phone != REG_HIDE) {
 
 $html .= "\t".'</fieldset><div class="clear"></div>'."\n";
 $html .= "\t".'<fieldset>'."\n";
-$html .= "\t\t".'<h3>'.JText::_('Personal Information').'</h3>'."\n";
+$html .= "\t\t".'<legend>'.JText::_('Personal Information').'</legend>'."\n";
 
 if ($this->registration->Employment != REG_HIDE) {
 	$required = ($this->registration->Employment == REG_REQUIRED) ? '<span class="required">'.JText::_('REQUIRED').'</span>' : '';
@@ -276,7 +280,7 @@ if ($this->registration->Organization != REG_HIDE) {
 	
 	//$orgs = array();
 	//include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_hub'.DS.'xorganization.php' );
-	include_once( JPATH_ROOT.DS.'components'.DS.'com_register'.DS.'register.organization.php' );
+	include_once( JPATH_ROOT.DS.'components'.DS.'com_register'.DS.'tables'.DS.'organization.php' );
 	$database =& JFactory::getDBO();
 	//$xo = new XOrganization( $database );
 	$xo = new RegisterOrganization( $database );
@@ -329,9 +333,9 @@ if ($this->registration->Interests != REG_HIDE) {
 	$message = (!empty($this->xregistration->_invalid['interests'])) ? Hubzero_View_Helper_Html::error($this->xregistration->_invalid['interests']) : '';
 	$fieldclass = ($message) ? ' class="fieldWithErrors"' : '';
 	
-	JPluginHelper::importPlugin( 'tageditor' );
+	JPluginHelper::importPlugin( 'hubzero' );
 	$dispatcher =& JDispatcher::getInstance();
-	$tf = $dispatcher->trigger( 'onTagsEdit', array(array('tags','actags','',$this->tags,'')) );
+	$tf = $dispatcher->trigger( 'onGetMultiEntry', array(array('tags', 'tags', 'actags','',stripslashes($this->tags))) );
 	
 	$html .= "\t\t".'<label'.$fieldclass.'>'."\n";
 	$html .= "\t\t\t".JText::_('MEMBER_FIELD_TAGS').': '.$required."\n";
@@ -345,9 +349,12 @@ if ($this->registration->Interests != REG_HIDE) {
 	$html .= "\t\t".'</label>'."\n";
 }
 
+ximport('Hubzero_Wiki_Editor');
+$editor =& Hubzero_Wiki_Editor::getInstance();
+
 $html .= "\t\t".'<label>'."\n";
 $html .= "\t\t\t".JText::_('BIO').':'."\n";
-$html .= "\t\t\t".'<textarea name="profile[bio]" rows="10" cols="40">'. htmlentities(stripslashes($this->profile->get('bio')),ENT_COMPAT,'UTF-8') .'</textarea>'."\n";
+$html .= "\t\t\t".$editor->display('profile[bio]', 'profilebio', stripslashes($this->profile->get('bio')), '', '40', '10');
 $html .= "\t\t\t".'<span class="hint"><a href="'.JRoute::_('index.php?option=com_topics&scope=&pagename=Help:WikiFormatting').'">Wiki formatting</a> is allowed for Bios.</span>'."\n";
 $html .= "\t\t".'</label>'."\n";
 $html .= "\t".'</fieldset><div class="clear"></div>'."\n";
@@ -360,11 +367,12 @@ if ($this->registration->Citizenship != REG_HIDE
  || $this->registration->Race != REG_HIDE) 
 {
 	$html .= t.'<fieldset>'."\n";
-	$html .= "\t\t".'<h3>'.JText::_('Demographics').'</h3>'."\n";
+	$html .= "\t\t".'<legend>'.JText::_('Demographics').'</legend>'."\n";
 	
 	if ($this->registration->Citizenship != REG_HIDE 
 	 || $this->registration->Residency != REG_HIDE) {
-		$countries = getcountries();
+		ximport('Hubzero_Geo');
+		$countries = Hubzero_Geo::getcountries();
 	}
 
 	if ($this->registration->Citizenship != REG_HIDE) {
@@ -678,7 +686,7 @@ if ($this->registration->OptIn != REG_HIDE) // newsletter Opt-In
 	$fieldclass = ($message) ? ' class="fieldWithErrors"' : '';
 	
 	$html .= "\t".'<fieldset>'."\n";
-	$html .= "\t\t".'<h3>'.JText::_('Updates').'</h3>'."\n";
+	$html .= "\t\t".'<legend>'.JText::_('Updates').'</legend>'."\n";
 	$html .= "\t\t".'<input type="hidden" name="mailPreferenceOption" value="unset" />'."\n";
 	$html .= "\t\t".'<label '.$fieldclass.'><input type="checkbox" class="option" id="mailPreferenceOption" name="mailPreferenceOption" value="1" ';
 	if ($this->profile->get('mailPreferenceOption')) {
@@ -690,7 +698,7 @@ if ($this->registration->OptIn != REG_HIDE) // newsletter Opt-In
 }
 
 $html .= "\t".'<fieldset>'."\n";
-$html .= "\t\t".'<h3>'.JText::_('MEMBER_PICTURE').'</h3>'."\n";
+$html .= "\t\t".'<legend>'.JText::_('MEMBER_PICTURE').'</legend>'."\n";
 $html .= "\t\t".'<iframe width="100%" height="350" border="0" name="filer" id="filer" src="index.php?option='.$this->option.'&amp;no_html=1&amp;task=img&amp;file='.stripslashes($this->profile->get('picture')).'&amp;id='.$this->profile->get('uidNumber').'"></iframe>'."\n";
 $html .= "\t".'</fieldset><div class="clear"></div>'."\n";
 
