@@ -1,25 +1,29 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Shawn Rice <zooley@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Shawn Rice <zooley@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
@@ -41,9 +45,13 @@ foreach ($this->sections as $section)
 $html .= "\t".'</div><!-- / .metadata -->'."\n";
 if ($this->profile->get('picture')) {
 	list($width,$height) = getimagesize(JPATH_ROOT.$this->profile->get('picture'));
+	$name = $this->profile->get('name');
+	$is_generic_image = preg_match('/profile.(?:gif|png)$/', $this->profile->get('picture'));
 	$html .= "\t".'<p class="portrait userImage"><img class="photo" src="'.$this->profile->get('picture').'"';
 	$html .= ($width && $width > 190) ? ' width="190"' : '';
-	$html .= ' alt="'.JText::_('MEMBER_PICTURE').'" /></p>'."\n";
+	if (!$is_generic_image)
+		$html .= ' title="'.htmlentities($name).'"';
+	$html .= ' alt="'.($is_generic_image ? JText::_('MEMBER_PICTURE') : htmlentities($name)).'" /></p>'."\n";
 	if ($this->authorized) {
 		$html .= "\t".'<p><a href="'.JRoute::_('index.php?option='.$this->option.'&task=edit&id='.$this->profile->get('uidNumber')).'">'.JText::_('MEMBERS_UPLOAD_IMAGE').'</a></p>'."\n";
 	}
@@ -111,6 +119,12 @@ if ($this->registration->Employment != REG_HIDE) {
 			case '':
 				$html .= JText::_('n/a');
 				break;
+			case 'universityundergraduate':
+				$html .= JText::_('University / College Undergraduate');
+				break;
+			case 'universitygraduate':
+                                $html .= JText::_('University / College Graduate');
+				break;
 			case 'universitystudent':
 				$html .= JText::_('University / College Student');
 				break;
@@ -221,9 +235,18 @@ if ($this->params->get('access_bio') == 0
  || ($this->params->get('access_bio') == 2 && $this->authorized)
 ) {
 	if ($this->profile->get('bio')) {
-		ximport('wiki.parser');
-		$p = new WikiParser( $this->profile->get('name'), $this->option, 'members'.DS.'profile', 'member' );
-		$bio = $p->parse( n.stripslashes($this->profile->get('bio')), 0, 0 );
+		// Transform the wikitext to HTML
+		$wikiconfig = array(
+			'option'   => $this->option,
+			'scope'    => 'members'.DS.'profile',
+			'pagename' => 'member',
+			'pageid'   => 0,
+			'filepath' => '',
+			'domain'   => '' 
+		);
+		ximport('Hubzero_Wiki_Parser');
+		$p =& Hubzero_Wiki_Parser::getInstance();
+		$bio = $p->parse(stripslashes($this->profile->get('bio')), $wikiconfig);
 	} else {
 		$bio = JText::_('NO_BIOGRAPHY');
 	}
