@@ -1,25 +1,29 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Nicholas J. Kisseberth <nkissebe@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Nicholas J. Kisseberth <nkissebe@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
@@ -73,9 +77,9 @@ if (!defined("n")) {
 		return $o;
 	}
 
-	ximport('xuserhelper');
-	//ximport('xhubhelper');
-	ximport('xgeoutils');
+	ximport('Hubzero_User_Helper');
+	//ximport('Hubzero_Toolbox');
+	ximport('Hubzero_Geo');
 
 	$html  = '<div id="content-header" class="full">'.n;
 	$html .= t.'<h2>'.JText::_('COM_REGISTER_'.strtoupper($this->task)).'</h2>'.n;
@@ -122,14 +126,14 @@ if (!defined("n")) {
 			$html .= '</div>'.n;
 		break;
 	}
-	//$html .= '<form action="'. XHubHelper::thisurl() .'" method="post" id="hubForm">'.n;
+	//$html .= '<form action="'. Hubzero_Toolbox::thisurl() .'" method="post" id="hubForm">'.n;
 	if ($this->task == 'create') {
 		$html .= '<form action="'. JRoute::_('index.php?option='.$this->option) .'" method="post" id="hubForm">'.n;
 	} else {
 		$html .= '<form action="'. JRoute::_('index.php?option='.$this->option.'&task='.$this->task) .'" method="post" id="hubForm">'.n;
 	}
 	
-	$emailusers = XProfileHelper::find_by_email($this->registration['email']);
+	$emailusers = Hubzero_User_Profile_Helper::find_by_email($this->registration['email']);
 
 	if ( ($this->task == 'create' || $this->task == 'proxycreate') && $emailusers) {
 		$html .= '<div class="error">'.n;
@@ -172,7 +176,7 @@ if (!defined("n")) {
 		$html .= t.'</div>'.n;
 		
 		$html .= t.'<fieldset>'.n;
-		$html .= t.t.'<h3>'.JText::_('Login Information').'</h3>'.n;
+		$html .= t.t.'<legend>'.JText::_('Login Information').'</legend>'.n;
 	
 		if ($this->registrationUsername == REG_READONLY)
 		{
@@ -225,7 +229,10 @@ if (!defined("n")) {
 
 			$html .= t.t.'</div>'.n;
 		} 
-
+		$hconfig =& JComponentHelper::getParams('com_hub');
+		if ($hconfig->get('passwordMeter')) {
+			$html .= t.'<input type="hidden" id="passmeter" value="on" />'.n;
+		}
 		$html .= t.'</fieldset>'.n;
 		$html .= t.'<div class="clear"></div>'.n;
 	}
@@ -245,7 +252,7 @@ if (!defined("n")) {
 		$html .= t.'</div>'.n;
 	
 		$html .= t.'<fieldset>'.n;
-		$html .= t.t.'<h3>'.JText::_('Contact Information').'</h3>'.n;
+		$html .= t.t.'<legend>'.JText::_('Contact Information').'</legend>'.n;
 
 		if ($this->registrationFullname != REG_HIDE) // name
 		{
@@ -385,7 +392,7 @@ if (!defined("n")) {
 		$html .= t.'</div>'.n;
 
 		$html .= t.'<fieldset>'.n;
-		$html .= t.t.'<h3>'.JText::_('Personal Information').'</h3>'.n;
+		$html .= t.t.'<legend>'.JText::_('Personal Information').'</legend>'.n;
 
 		if ($this->registrationEmployment != REG_HIDE) // employment status
 		{
@@ -471,9 +478,9 @@ if (!defined("n")) {
 			
 			$orgtext = $this->registration['org'];
 			$org_known = 0;
-			include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_hub'.DS.'xorganization.php' );
+			include_once( JPATH_ROOT.DS.'components'.DS.'com_register'.DS.'tables'.DS.'organization.php' );
 			$database =& JFactory::getDBO();
-			$xo = new XOrganization( $database );
+			$xo = new RegisterOrganization( $database );
 			$orgs = $xo->getOrgs();
 
 			if (count($orgs) <= 0) {
@@ -637,7 +644,7 @@ if (!defined("n")) {
 		$html .= t.t.'<p>Please provide this information if you feel comfortable doing so. This information will not affect the level of service you receive.</p>'.n;
 		$html .= t.'</div>'.n;
 		$html .= t.'<fieldset>'.n;
-		$html .= t.t.'<h3>'.JText::_('Demographics').'</h3>'.n;
+		$html .= t.t.'<legend>'.JText::_('Demographics').'</legend>'.n;
 
 		if ($this->registrationCitizenship != REG_HIDE) // citizenship
 		{
@@ -670,7 +677,7 @@ if (!defined("n")) {
 			if (!$this->registration['countryorigin'] || $this->registration['countryorigin'] == 'US')
 				$html .= t.t.t.t.t.'<option value="">'.JText::_('COM_REGISTER_FORM_SELECT_FROM_LIST').'</option>'.n;
 
-			$countries = GeoUtils::getcountries();
+			$countries = Hubzero_Geo::getcountries();
 
 			foreach ($countries as $country) 
 			{
@@ -719,7 +726,7 @@ if (!defined("n")) {
 				$html .= t.t.t.t.t.'<option value="">'.JText::_('COM_REGISTER_FORM_SELECT_FROM_LIST').'</option>'.n;
 			}
 	
-			$countries = GeoUtils::getcountries();
+			$countries = Hubzero_Geo::getcountries();
 	
 			foreach ($countries as $country) 
 			{
@@ -835,7 +842,7 @@ if (!defined("n")) {
 	//if ($this->registrationHispanic != REG_HIDE || $this->registrationRace != REG_HIDE) // Racial Background Section
 	//{
 		//$html .= t.'<fieldset>'.n;
-		//$html .= t.t.'<h3>'.JText::_('Racial Background').'</h3>'.n;
+		//$html .= t.t.'<legend>'.JText::_('Racial Background').'</legend>'.n;
 
 		if ($this->registrationHispanic != REG_HIDE) // hispanic
 		{
@@ -862,7 +869,7 @@ if (!defined("n")) {
 			}
 	
 			$html .= t.t.'<fieldset'.$fieldclass.'>'.n;
-			$html .= t.t.t.'<legend>Hispanic or Latino (<a class="popup 700x500" href="/components/com_myaccount/raceethnic.html">more information</a>) ';
+			$html .= t.t.t.'<legend>Hispanic or Latino (<a class="popup 700x500" href="/register/raceethnic">more information</a>) ';
 	
 			$html .= $required;
 			$html .= '</legend>'.n;
@@ -919,7 +926,7 @@ if (!defined("n")) {
 				$this->registration['race'] = array(trim($this->registration['race']));
 
 			$html .= t.t.'<fieldset'.$fieldclass.'>'.n;
-			$html .= t.t.t.'<legend>U.S. Citizens and Permanent Residents Only (<a class="popup 675x678" href="/components/com_myaccount/raceethnic.html">more information</a>) '.$required.'</legend>'.n;
+			$html .= t.t.t.'<legend>U.S. Citizens and Permanent Residents Only (<a class="popup 675x678" href="/register/raceethnic">more information</a>) '.$required.'</legend>'.n;
 			$html .= t.t.t.'<p class="hint">'.JText::_('Select one or more that apply.').'</p>'.n;
 			
 			$html .= t.t.t.'<label><input type="checkbox" class="option" name="racenativeamerican" id="racenativeamerican" value="nativeamerican" ';
@@ -969,7 +976,7 @@ if (!defined("n")) {
 		// interests info: role interest(s), educational level(s), reason for account
 	
 		$html .= t.'<fieldset>'.n;
-		$html .= t.t.'<h3>'.JText::_('Updates').'</h3>'.n;
+		$html .= t.t.'<legend>'.JText::_('Updates').'</legend>'.n;
 
 		if ($this->registrationOptIn != REG_HIDE) // newsletter Opt-In
 		{
@@ -993,7 +1000,7 @@ if (!defined("n")) {
 	if ($this->registrationTOU != REG_HIDE)
 	{
 		$html .= t.'<fieldset>'.n;
-		$html .= t.t.'<h3>'.JText::_('Terms &amp; Conditions').'</h3>'.n;
+		$html .= t.t.'<legend>'.JText::_('Terms &amp; Conditions').'</legend>'.n;
 	
 		if ($this->registrationTOU != REG_HIDE)
 		{
@@ -1028,6 +1035,7 @@ if (!defined("n")) {
 	$html .= t.'<input type="hidden" name="option" value="'.$this->option.'" />'.n;
 	$html .= t.'<input type="hidden" name="task" value="'.$this->task.'" />'.n;
 	$html .= t.'<input type="hidden" name="act" value="submit" />'.n;
+	$html .= t.JHTML::_( 'form.token' );
 
 	$return_g = JRequest::getVar('return', null, 'get');
 
@@ -1039,3 +1047,4 @@ if (!defined("n")) {
 	$html .= '</div><!-- / .main section -->'.n;
 
 	echo $html;
+
