@@ -1,84 +1,40 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Shawn Rice <zooley@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Shawn Rice <zooley@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
 
-class ResourcesController extends JObject
+ximport('Hubzero_Controller');
+
+class ResourcesController extends Hubzero_Controller
 {
-	private $_name  = NULL;
-	private $_data  = array();
-	private $_task  = NULL;
-
-	//-----------
-	
-	public function __construct( $config=array() )
-	{
-		$this->_redirect = NULL;
-		$this->_message = NULL;
-		$this->_messageType = 'message';
-		
-		// Set the controller name
-		if (empty( $this->_name )) {
-			if (isset($config['name'])) {
-				$this->_name = $config['name'];
-			} else {
-				$r = null;
-				if (!preg_match('/(.*)Controller/i', get_class($this), $r)) {
-					echo "Controller::__construct() : Can't get or parse class name.";
-				}
-				$this->_name = strtolower( $r[1] );
-			}
-		}
-		
-		// Set the component name
-		$this->_option = 'com_'.$this->_name;
-	}
-
-	//-----------
-
-	public function __set($property, $value)
-	{
-		$this->_data[$property] = $value;
-	}
-	
-	//-----------
-	
-	public function __get($property)
-	{
-		if (isset($this->_data[$property])) {
-			return $this->_data[$property];
-		}
-	}
-	
-	//-----------
-	
 	public function execute()
 	{
-		$config =& JComponentHelper::getParams( $this->_option );
-		$this->config = $config;
-		
 		$this->_task  = JRequest::getVar( 'task', '' );
 		$this->_id    = JRequest::getInt( 'id', 0 );
 		$this->_alias = JRequest::getVar( 'alias', '' );
@@ -115,44 +71,10 @@ class ResourcesController extends JObject
 			default: $this->intro(); break;
 		}
 	}
-	
-	//-----------
-
-	public function redirect()
-	{
-		if ($this->_redirect != NULL) {
-			$app =& JFactory::getApplication();
-			$app->redirect( $this->_redirect, $this->_message );
-		}
-	}
 
 	//-----------
 	
-	private function _getStyles() 
-	{
-		ximport('xdocument');
-		XDocument::addComponentStylesheet($this->_option);
-	}
-	
-	//-----------
-	
-	private function _getScripts($script='')
-	{
-		$document =& JFactory::getDocument();
-		if ($script) {
-			if (is_file(JPATH_ROOT.DS.'components'.DS.$this->_option.DS.$script.'.js')) {
-				$document->addScript('components'.DS.$this->_option.DS.$script.'.js');
-			}
-		} else {
-			if (is_file(JPATH_ROOT.DS.'components'.DS.$this->_option.DS.$this->_name.'.js')) {
-				$document->addScript('components'.DS.$this->_option.DS.$this->_name.'.js');
-			}
-		}
-	}
-	
-	//-----------
-	
-	private function _buildPathway() 
+	protected function _buildPathway() 
 	{
 		$app =& JFactory::getApplication();
 		$pathway =& $app->getPathway();
@@ -194,7 +116,7 @@ class ResourcesController extends JObject
 	
 	//-----------
 	
-	private function _buildTitle() 
+	protected function _buildTitle() 
 	{
 		if (!$this->_title) {
 			$this->_title = JText::_(strtoupper($this->_option));
@@ -363,8 +285,8 @@ class ResourcesController extends JObject
 		$view->config = $this->config;
 		
 		// Incoming
-		$view->tag = JRequest::getVar( 'tag', '' );
-		$view->tag2 = JRequest::getVar( 'with', '' );
+		$view->tag = preg_replace("/[^a-zA-Z0-9]/", "", strtolower(JRequest::getVar( 'tag', '' )));
+		$view->tag2 = preg_replace("/[^a-zA-Z0-9]/", "", strtolower(JRequest::getVar( 'with', '' )));
 		$view->type = strtolower(JRequest::getVar( 'type', 'tools' ));
 		
 		$view->supportedtag = $this->config->get('supportedtag');
@@ -502,7 +424,8 @@ class ResourcesController extends JObject
 				// Get extra filter options
 				$bits['filters'] = array();
 				if ($this->config->get('show_audience') && $bits['type'] == 7) {
-					include_once(JPATH_ROOT.DS.'administrator'.DS.'components'.DS.$this->_option.DS.'resources.audience.php');
+					include_once(JPATH_ROOT.DS.'administrator'.DS.'components'.DS.$this->_option.DS.'tables'.DS.'audience.php');
+					include_once(JPATH_ROOT.DS.'administrator'.DS.'components'.DS.$this->_option.DS.'tables'.DS.'audience.level.php');
 					$rL = new ResourceAudienceLevel( $database );
 					$bits['filters'] = $rL->getLevels();
 				}
@@ -545,6 +468,10 @@ class ResourcesController extends JObject
 				$params->merge( $rparams );
 				$bits['params'] = $params;
 				
+				$resource->_type = new ResourcesType( $database );
+				$resource->_type->load($resource->type);
+				$resource->_type->_params = new JParameter( $resource->_type->params );
+				
 				// Version checks (tools only)
 				if ($resource->type == 7 && $resource->alias) {
 					$tables = $database->getTableList();
@@ -577,6 +504,9 @@ class ResourcesController extends JObject
 				$helper = new ResourcesHelper($resource->id, $database);
 				$helper->getFirstChild();
 				
+				$helper->getContributorIDs();
+				$bits['authorized'] = $this->_authorize( $helper->contributorIDs );
+				
 				// Get the first child
 				if ($helper->firstChild || $resource->type == 7) {
 					$bits['primary_child'] = ResourcesHtml::primary_child( $this->_option, $resource, $helper->firstChild, '' );
@@ -734,10 +664,19 @@ class ResourcesController extends JObject
 			return;
 		}
 
+		// Initiate a resource helper class
+		$helper = new ResourcesHelper( $resource->id, $database );
+
+		// Is the visitor authorized to edit this resource?
+		$helper->getContributorIDs();
+		$authorized = $this->_authorize( $helper->contributorIDs );
+
 		// Make sure they have access to view this resource
-		if ($this->checkGroupAccess($resource)) {
-			JError::raiseError( 403, JText::_('ALERTNOTAUTH') );
-			return;
+		if ($resource->access == 4) {
+			if ($this->checkGroupAccess($resource) && !$authorized) {
+				JError::raiseError( 403, JText::_('ALERTNOTAUTH') );
+				return;
+			}
 		}
 
 		// Build the pathway
@@ -746,9 +685,24 @@ class ResourcesController extends JObject
 		$typenorm = strtolower($typenorm);
 		
 		$app =& JFactory::getApplication();
-		$pathway =& $app->getPathway();
-		$pathway->addItem($resource->getTypeTitle(),JRoute::_('index.php?option='.$this->_option.'&type='.$typenorm));
+		if ($resource->group_owner) {
+			// Alter the pathway to reflect a group owned resource
+			ximport('Hubzero_Group');
+			$group = Hubzero_Group::getInstance( $resource->group_owner );
 
+			$pathway =& $app->getPathway();
+			$pathway->_pathway = array();
+			$pathway->_count = 0;
+			
+			$pathway->addItem('Groups',JRoute::_('index.php?option=com_groups'));
+			$pathway->addItem(stripslashes($group->get('description')),JRoute::_('index.php?option=com_groups&gid='.$resource->group_owner));
+			$pathway->addItem('Resources',JRoute::_('index.php?option=com_groups&gid='.$resource->group_owner.'&active=resources'));
+			$pathway->addItem($resource->getTypeTitle(),JRoute::_('index.php?option=com_groups&gid='.$resource->group_owner.'&active=resources&area='.$typenorm));
+		} else {
+			$pathway =& $app->getPathway();
+			$pathway->addItem($resource->getTypeTitle(),JRoute::_('index.php?option='.$this->_option.'&type='.$typenorm));
+		}
+		
 		// Tool development version requested
 		$juser =& JFactory::getUser();
 		if ($juser->get('guest') && $revision=='dev') {
@@ -828,14 +782,14 @@ class ResourcesController extends JObject
 		}
 
 		// Record the hit
-		//$resource->hit( $id );
+		$resource->hit( $id );
 		
 		// Initiate a resource helper class
-		$helper = new ResourcesHelper( $resource->id, $database );
+		/*$helper = new ResourcesHelper( $resource->id, $database );
 
 		// Is the visitor authorized to edit this resource?
 		$helper->getContributorIDs();
-		$authorized = $this->_authorize( $helper->contributorIDs );
+		$authorized = $this->_authorize( $helper->contributorIDs );*/
 		
 		// Do not show for tool versions
 		if ($thistool && $revision!='dev') {
@@ -849,6 +803,10 @@ class ResourcesController extends JObject
 		$sections = array();
 		$cats = array();
 		
+		$resource->_type = new ResourcesType( $database );
+		$resource->_type->load($resource->type);
+		$resource->_type->_params = new JParameter( $resource->_type->params );
+		
 		// We need to do this here because we need some stats info to pass to the body
 		if (!$thistool) {
 			// Trigger the functions that return the areas we'll be using
@@ -880,8 +838,8 @@ class ResourcesController extends JObject
 		
 		$juser =& JFactory::getUser();
 		if (!$juser->get('guest')) {
-			ximport('xuserhelper');
-			$xgroups = XUserHelper::getGroups($juser->get('id'), 'all');
+			ximport('Hubzero_User_Helper');
+			$xgroups = Hubzero_User_Helper::getGroups($juser->get('id'), 'all');
 			// Get the groups the user has access to
 			$usersgroups = $this->getUsersGroups($xgroups);
 		} else {
@@ -894,7 +852,7 @@ class ResourcesController extends JObject
 		// Build the HTML of the "about" tab
 		if ($resource->type == 7 && $resource->alias && !$no_html && strtolower($tab) == 'about') {	
 			// Tool page view
-			$body = ResourcesHtml::abouttool( $database, $authorized, $usersgroups, $resource, $helper, $this->config, $sections, $thistool, $curtool, $alltools, $revision, $params, $attribs, $this->_option, $fsize );
+			$body = ResourcesHtml::abouttool( $database, $authorized, $usersgroups, $resource, $helper, $this->config, $sections, $thistool, $curtool, $alltools, $resource->revision, $params, $attribs, $this->_option, $fsize );
 		} else if (strtolower($tab) == 'about') {
 			// Default view of about tab
 			$body = ResourcesHtml::aboutnontool( $database, $authorized, $usersgroups, $resource, $helper, $this->config, $sections, $params, $attribs, $this->_option, $fsize );
@@ -1036,8 +994,8 @@ class ResourcesController extends JObject
 		$jdoc->setMimeEncoding('application/rss+xml');
 
 		// Start a new feed object
-		ximport('xfeed');
-		$doc = new XDocumentFeed;
+		ximport('Hubzero_Document_Feed');
+		$doc = new Hubzero_Document_Feed;
 		$app =& JFactory::getApplication();
 		$params =& $app->getParams();
 
@@ -1167,7 +1125,7 @@ class ResourcesController extends JObject
 		
 		$dimg = $this->checkForImage('itunes_artwork', $this->config->get('uploadpath'), $resource->created, $resource->id);
 		if ($dimg) {
-			$dimage = new XFeedImage();
+			$dimage = new Hubzero_Document_Feed_Image();
 			$dimage->url = $dimg;
 			$dimage->title = trim(Hubzero_View_Helper_Html::shortenText(html_entity_decode($dtitle.' '.JText::_('COM_RESOURCES_RSS_ARTWORK')), 250, 0));
 			$dimage->link = $base.$doc->link;
@@ -1175,7 +1133,7 @@ class ResourcesController extends JObject
 			$doc->itunes_image = $dimage;
 		}
 		
-		$owner = new XFeedItunesOwner;
+		$owner = new Hubzero_Document_Feed_ItunesOwner;
 		$owner->email = $jconfig->getValue('config.mailfrom');
 		$owner->name = $jconfig->getValue('config.sitename');
 		
@@ -1257,7 +1215,7 @@ class ResourcesController extends JObject
 				}
 				
 				// Load individual item creator class
-				$item = new XFeedItem();
+				$item = new Hubzero_Document_Feed_Item();
 				$item->title       = $title;
 				$item->link        = $link;
 				$item->description = $description;
@@ -1267,7 +1225,7 @@ class ResourcesController extends JObject
 				
 				$img = $this->checkForImage('itunes_artwork', $this->config->get('uploadpath'), $row->created, $row->id);
 				if ($img) {
-					$image = new XFeedImage();
+					$image = new Hubzero_Document_Feed_Image();
 					$image->url = $img;
 					$image->title = $title.' '.JText::_('COM_RESOURCES_RSS_ARTWORK');
 					$image->link = $base.$link;
@@ -1298,7 +1256,7 @@ class ResourcesController extends JObject
 					if (file_exists( $podcastp )) {
 						$fs = filesize( $podcastp );
 
-						$enclosure = new XFeedEnclosure; //JObject;
+						$enclosure = new Hubzero_Document_Feed_Enclosure; //JObject;
 						$enclosure->url = $podcast;
 						switch ( ResourcesHtml::getFileExtension($podcast) ) 
 						{
@@ -1442,7 +1400,7 @@ class ResourcesController extends JObject
 	protected function download()
 	{
 		// Get some needed libraries
-		ximport('xserver');
+		ximport('Hubzero_Content_Server');
 
 		$database =& JFactory::getDBO();
 
@@ -1545,7 +1503,7 @@ class ResourcesController extends JObject
 		}
 		
 		// Initiate a new content server and serve up the file
-		$xserver = new XContentServer();
+		$xserver = new Hubzero_Content_Server();
 		$xserver->filename($filename);
 		$xserver->disposition('inline');
 		$xserver->acceptranges(false); // @TODO fix byte range support
@@ -1574,7 +1532,7 @@ class ResourcesController extends JObject
 			return;
 		}
 		
-		ximport('xserver');
+		ximport('Hubzero_Content_Server');
 		
 		$database =& JFactory::getDBO();
 		
@@ -1605,7 +1563,7 @@ class ResourcesController extends JObject
 		}
 		
 		// Serve up the file
-		$xserver = new XContentServer();
+		$xserver = new Hubzero_Content_Server();
 		$xserver->filename($tarpath . $tarname);
 		$xserver->disposition('attachment');
 		$xserver->acceptranges(false); // @TODO fix byte range support
@@ -1674,9 +1632,7 @@ class ResourcesController extends JObject
 	{
 		$database =& JFactory::getDBO();
 		
-		ximport('fileuploadutils');
-		
-		$xhub =& XFactory::getHub();
+		$xhub =& Hubzero_Factory::getHub();
 		$hubDOIpath = $this->config->get('doi');
 		
 		// Incoming
@@ -1710,7 +1666,7 @@ class ResourcesController extends JObject
 		// Build the download path
 		$path = JPATH_ROOT.$this->config->get('webpath');
 		$date = $row->created;
-		$dir_resid = FileUploadUtils::niceidformat( $row->id );
+		$dir_resid = Hubzero_View_Helper_Html::niceidformat( $row->id );
 		if ($date && ereg("([0-9]{4})-([0-9]{2})-([0-9]{2})[ ]([0-9]{2}):([0-9]{2}):([0-9]{2})", $date, $regs )) {
 			$date = mktime( $regs[4], $regs[5], $regs[6], $regs[2], $regs[3], $regs[1] );
 		}
@@ -1718,12 +1674,15 @@ class ResourcesController extends JObject
 		$dir_month = date('m', $date);
 		$path .= DS.$dir_year.DS.$dir_month.DS.$dir_resid.DS;
 
-		if (!is_dir($path)) {
-			FileUploadUtils::make_path($path);
+		if (!is_dir( $path )) {
+			jimport('joomla.filesystem.folder');
+			if (!JFolder::create( $path, 0777 )) {
+				$this->setError( 'Error. Unable to create path.' );
+			}
 		}
 		
 		// Build the URL for this resource
-		$sef = JRoute::_('index.php?option='.$this->_option.a.'id='.$row->id);
+		$sef = JRoute::_('index.php?option='.$this->_option.'&id='.$row->id);
 		if (substr($sef,0,1) == '/') {
 			$sef = substr($sef,1,strlen($sef));
 		}
@@ -1909,28 +1868,27 @@ class ResourcesController extends JObject
 	//	Checks
 	//----------------------------------------------------------
 
-	private function _authorize($contributorIDs=array()) 
+	protected function _authorize($contributorIDs=array()) 
 	{
 		// Check if they are logged in
-		$juser =& JFactory::getUser();
-		if ($juser->get('guest')) {
+		if ($this->juser->get('guest')) {
 			return false;
 		}
 		
 		// Check if they're a site admin (from Joomla)
-		if ($juser->authorize($this->_option, 'manage')) {
+		if ($this->juser->authorize($this->_option, 'manage')) {
 			return true;
 		}
 		
 		// Check if they're the resource creator
 		$resource = $this->resource;
-		if (is_object($resource) && $resource->created_by == $juser->get('id')) {
+		if (is_object($resource) && $resource->created_by == $this->juser->get('id')) {
 			return true;
 		}
 		
 		// Check if they're a resource "contributor"
 		if (is_array($contributorIDs)) {
-			if (in_array($juser->get('id'), $contributorIDs)) {
+			if (in_array($this->juser->get('id'), $contributorIDs)) {
 				return true;
 			}
 		}
@@ -1942,7 +1900,7 @@ class ResourcesController extends JObject
 	
 	private function checkGroupAccess($resource)
 	{	
-		//$juser =& XFactory::getUser();
+		//$juser =& Hubzero_Factory::getUser();
 		$juser =& JFactory::getUser();
 		if (!$juser->get('guest')) {
 			// Check if they're a site admin (from Joomla)
@@ -1950,8 +1908,8 @@ class ResourcesController extends JObject
 				return false;
 			}
 			
-			ximport('xuserhelper');
-			$xgroups = XUserHelper::getGroups($juser->get('id'), 'all');
+			ximport('Hubzero_User_Helper');
+			$xgroups = Hubzero_User_Helper::getGroups($juser->get('id'), 'all');
 			// Get the groups the user has access to
 			$usersgroups = $this->getUsersGroups($xgroups);
 		} else {
@@ -2003,7 +1961,7 @@ class ResourcesController extends JObject
 	
 	//-----------
 
-	private function getUsersGroups($groups)
+	public function getUsersGroups($groups)
 	{
 		$arr = array();
 		if (!empty($groups)) {
@@ -2081,4 +2039,4 @@ class ResourcesController extends JObject
 		return false;
 	}
 }
-?>
\ No newline at end of file
+
