@@ -1,93 +1,43 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Alissa Nedossekina <alisa@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Alissa Nedossekina <alisa@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
 
-class StoreController extends JObject
-{	
-	private $_name  = NULL;
-	private $_data  = array();
-	private $_task  = NULL;
+ximport('Hubzero_Controller');
 
-	//-----------
-	
-	public function __construct( $config=array() )
+class StoreController extends Hubzero_Controller
+{
+	public function execute()
 	{
-		$this->_redirect = NULL;
-		$this->_message = NULL;
-		$this->_messageType = 'message';
-		
-		// Set the controller name
-		if (empty( $this->_name )) {
-			if (isset($config['name'])) {
-				$this->_name = $config['name'];
-			} else {
-				$r = null;
-				if (!preg_match('/(.*)Controller/i', get_class($this), $r)) {
-					echo "Controller::__construct() : Can't get or parse class name.";
-				}
-				$this->_name = strtolower( $r[1] );
-			}
-		}
-		
-		// Set the component name
-		$this->_option = 'com_'.$this->_name;
 		// Get the component parameters
 		$aconfig =& JComponentHelper::getParams( 'com_answers' );
 		$this->infolink =  $aconfig->get('infolink') ? $aconfig->get('infolink') : '/kb/points/';
-	}
-
-	//-----------
-
-	public function __set($property, $value)
-	{
-		$this->_data[$property] = $value;
-	}
-	
-	//-----------
-	
-	public function __get($property)
-	{
-		if (isset($this->_data[$property])) {
-			return $this->_data[$property];
-		}
-	}
-	
-	//-----------
-	
-	public function execute()
-	{
-		// Check if the store is enabled or not
-		//$this->config = new StoreConfig($this->_option);
-		$component =& JComponentHelper::getComponent( $this->_option );
-		if (!trim($component->params)) {
-			return $this->abort();
-		} else {
-			$config =& JComponentHelper::getParams( $this->_option );
-		}
-		$this->config = $config;
 		
 		if (!$this->config->get('store_enabled')) {
 			// Redirect to home page
@@ -102,60 +52,21 @@ class StoreController extends JObject
 		
 		switch ($this->_task) 
 		{
-			case 'cart':     $this->cart();           break;
-			case 'checkout': $this->checkout();       break;
+			case 'cart':     $this->cart();     break;
+			case 'checkout': $this->checkout(); break;
 			case 'process':  $this->process();  break;
 			case 'finalize': $this->finalize(); break;
-			case 'accept':   $this->accept();         break;
+			case 'accept':   $this->accept();   break;
 			
 			default: $this->storefront(); break;
 		}
 	}
 
-	//-----------
-
-	public function redirect()
-	{
-		if ($this->_redirect != NULL) {
-			$app =& JFactory::getApplication();
-			$app->redirect( $this->_redirect, $this->_message, $this->_messageType );
-		}
-	}
-
 	//----------------------------------------------------------
 	// Private functions
 	//----------------------------------------------------------
 
-	private function _getStyles($option='') 
-	{
-		ximport('xdocument');
-		if ($option) {
-			XDocument::addComponentStylesheet('com_'.$option);
-		} else {
-			XDocument::addComponentStylesheet($this->_option);
-		}
-	}
-	
-	//-----------
-	
-	private function _getScripts($option='',$name='')
-	{
-		$document =& JFactory::getDocument();
-		if ($option) {
-			$name = ($name) ? $name : $option;
-			if (is_file(JPATH_ROOT.DS.'components'.DS.'com_'.$option.DS.$name.'.js')) {
-				$document->addScript('components'.DS.'com_'.$option.DS.$name.'.js');
-			}
-		} else {
-			if (is_file(JPATH_ROOT.DS.'components'.DS.$this->_option.DS.$this->_name.'.js')) {
-				$document->addScript('components'.DS.$this->_option.DS.$this->_name.'.js');
-			}
-		}
-	}
-	
-	//-----------
-	
-	private function _buildPathway() 
+	protected function _buildPathway() 
 	{
 		$app =& JFactory::getApplication();
 		$pathway =& $app->getPathway();
@@ -201,7 +112,7 @@ class StoreController extends JObject
 	
 	//-----------
 	
-	private function _buildTitle() 
+	protected function _buildTitle() 
 	{
 		$this->_title = JText::_(strtoupper($this->_option));
 		if ($this->_task) {
@@ -235,24 +146,6 @@ class StoreController extends JObject
 			return(0);
 		}
 	}
-
-	//-----------
-	
-	private function _authorize() 
-	{
-		// Check if they are logged in
-		$juser =& JFactory::getUser();
-		if ($juser->get('guest')) {
-			return false;
-		}
-		
-		// Check if they're a site admin (from Joomla)
-		if ($juser->authorize($this->_option, 'manage')) {
-			return true;
-		}
-
-		return false;
-	}
 	
 	//----------------------------------------------------------
 	// Views
@@ -283,8 +176,7 @@ class StoreController extends JObject
 		$view->filters['sortby'] = JRequest::getVar( 'sortby', '' );
 		
 		// Get the most recent store items
-		$database =& JFactory::getDBO();
-		$obj = new Store($database);
+		$obj = new Store($this->database);
 		$view->rows = $obj->getItems('retrieve', $view->filters, $this->config);
 		
 		// Push some styles to the template
@@ -326,8 +218,7 @@ class StoreController extends JObject
 		$this->_buildPathway();
 
 		// Need to login to view cart
-		$juser =& JFactory::getUser();
-		if ($juser->get('guest')) {
+		if ($this->juser->get('guest')) {
 			$this->login();
 			return;
 		}
@@ -347,8 +238,6 @@ class StoreController extends JObject
 			return;
 		}
 		
-		$database =& JFactory::getDBO();
-			
 		// Incoming
 		$view->action = JRequest::getVar( 'action', '');
 		$view->id = JRequest::getInt( 'item', 0 );
@@ -356,7 +245,7 @@ class StoreController extends JObject
 		// Check if item exists
 		$purchasetype = '';
 		if ($view->id) {
-			$objStore = new Store( $database );
+			$objStore = new Store( $this->database );
 			$iteminfo = $objStore->getInfo($view->id);
 			if (!$iteminfo) {
 				$view->id = 0;
@@ -366,17 +255,17 @@ class StoreController extends JObject
 		}
 
 		// Get cart object
-		$item = new Cart( $database );
+		$item = new Cart( $this->database );
 				
 		switch ($view->action)
 		{
 			case 'add': 
 				// Check if item is already there, then update quantity or save new
-				$found = $item->checkCartItem($view->id, $juser->get('id'));		
+				$found = $item->checkCartItem($view->id, $this->juser->get('id'));		
 		
 				if (!$found && $view->id) {					
 					$item->itemid = $view->id;
-					$item->uid = $juser->get('id');
+					$item->uid = $this->juser->get('id');
 					$item->type = $purchasetype;
 					$item->added = date( 'Y-m-d H:i:s', time() );
 					$item->quantity = 1;
@@ -388,25 +277,25 @@ class StoreController extends JObject
 						return;
 					}
 					
-					$view->msg = JText::_('MSG_ADDED_TO_CART');	
+					$view->msg = JText::_('COM_STORE_MSG_ADDED_TO_CART');	
 				}
 			break;
 			
 			case 'update': 
 				// Update quantaties and selections					
-				$item->saveCart(array_map('trim',$_POST), $juser->get('id'));
+				$item->saveCart(array_map('trim',$_POST), $this->juser->get('id'));
 			break;
 			
 			case 'remove': 
 				// Update quantaties and selections
 				if ($view->id) {
-					$item->deleteCartItem($view->id, $juser->get('id'));	
+					$item->deleteCartItem($view->id, $this->juser->get('id'));	
 				}			
 			break;
 			
 			case 'empty': 
 				// Empty all
-				$item->deleteCartItem('', $juser->get('id'), 'all');
+				$item->deleteCartItem('', $this->juser->get('id'), 'all');
 			break;
 			
 			default:  
@@ -415,20 +304,20 @@ class StoreController extends JObject
 		}
 		
 		// Check available user funds		
-		$BTL = new BankTeller( $database, $juser->get('id') );
+		$BTL = new Hubzero_Bank_Teller( $this->database, $this->juser->get('id') );
 		$balance = $BTL->summary();
 		$credit  = $BTL->credit_summary();
 		$funds   = $balance - $credit;			
 		$view->funds = ($funds > 0) ? $funds : 0;
 	
 		// Calculate total
-		$view->cost = $item->getCartItems($juser->get('id'), 'cost');
+		$view->cost = $item->getCartItems($this->juser->get('id'), 'cost');
 		
 		// Get cart items		
-		$view->rows = $item->getCartItems($juser->get('id'));
+		$view->rows = $item->getCartItems($this->juser->get('id'));
 
 		// Output HTML
-		$view->juser = $juser;
+		$view->juser = $this->juser;
 		if ($this->getError()) {
 			$view->setError( $this->getError() );
 		}
@@ -452,8 +341,7 @@ class StoreController extends JObject
 		$this->_buildPathway();
 		
 		// Check authorization
-		$juser =& JFactory::getUser();
-		if ($juser->get('guest')) {
+		if ($this->juser->get('guest')) {
 			$this->login();
 			return;
 		}
@@ -465,19 +353,17 @@ class StoreController extends JObject
 		$view->infolink = $this->infolink;
 		$view->final = false;
 		
-		$database =& JFactory::getDBO();
-		
 		// Get cart object
-		$item = new Cart( $database );
+		$item = new Cart( $this->database );
 			
 		// Update quantaties and selections					
-		$item->saveCart(array_map('trim',$_POST), $juser->get('id'));
+		$item->saveCart(array_map('trim',$_POST), $this->juser->get('id'));
 		
 		// Calculate total
-		$view->cost = $item->getCartItems($juser->get('id'), 'cost');
+		$view->cost = $item->getCartItems($this->juser->get('id'), 'cost');
 		
 		// Check available user funds		
-		$BTL = new BankTeller($database, $juser->get('id'));
+		$BTL = new Hubzero_Bank_Teller($this->database, $this->juser->get('id'));
 		$balance = $BTL->summary();
 		$credit  = $BTL->credit_summary();
 		$funds   = $balance - $credit;			
@@ -489,18 +375,18 @@ class StoreController extends JObject
 		}
 		
 		// Get cart items		
-		$view->items = $item->getCartItems($juser->get('id'));
+		$view->items = $item->getCartItems($this->juser->get('id'));
 		
 		// Clean-up unavailable items
-		$item->deleteUnavail($juser->get('id'), $view->items);
+		$item->deleteUnavail($this->juser->get('id'), $view->items);
 				
 		// Updated item list		
-		$view->items = $item->getCartItems($juser->get('id'));
+		$view->items = $item->getCartItems($this->juser->get('id'));
 		
 		// Output HTML
-		$view->juser = $juser;
-		$view->xprofile = new XProfile;
-		$view->xprofile->load( $juser->get('id') );
+		$view->juser = $this->juser;
+		$view->xprofile = new Hubzero_User_Profile;
+		$view->xprofile->load( $this->juser->get('id') );
 		$view->posted = array();
 		if ($this->getError()) {
 			$view->setError( $this->getError() );
@@ -527,32 +413,29 @@ class StoreController extends JObject
 		$this->_buildPathway();
 		
 		// Check authorization
-		$juser =& JFactory::getUser();
-		if ($juser->get('guest')) {
+		if ($this->juser->get('guest')) {
 			$this->login();
 			return;
 		}
-		
-		$database =& JFactory::getDBO();
 
 		$now = date( 'Y-m-d H:i:s', time() );
 		
 		// Get cart object
-		$item = new Cart( $database );
+		$item = new Cart( $this->database );
 		
 		// Calculate total
-		$cost = $item->getCartItems($juser->get('id'),'cost');
+		$cost = $item->getCartItems($this->juser->get('id'),'cost');
 		
 		// Check available user funds		
-		$BTL = new BankTeller( $database, $juser->get('id') );
+		$BTL = new Hubzero_Bank_Teller( $this->database, $this->juser->get('id') );
 		$balance = $BTL->summary();
 		$credit = $BTL->credit_summary();
 		$funds = $balance - $credit;			
 		$funds = ($funds > 0) ? $funds : '0';
 		
 		// Get cart items		
-		$items = $item->getCartItems($juser->get('id'));
-		if (!$items) {
+		$items = $item->getCartItems($this->juser->get('id'));
+		if (!$items or $cost > $funds ) {
 			$this->cart();
 			return;
 		}
@@ -562,7 +445,7 @@ class StoreController extends JObject
 	
 		// make sure email address is valid
 		$validemail = $this->_checkValidEmail($shipping['email']);
-		$email = ($validemail) ? $shipping['email'] : $juser->get('email');
+		$email = ($validemail) ? $shipping['email'] : $this->juser->get('email');
 			
 		// Format posted info
 		$details  = JText::_('COM_STORE_SHIP_TO').':'."\r\n";
@@ -580,8 +463,8 @@ class StoreController extends JObject
 		$details .= ($shipping['comments']) ? "\r\n".(Hubzero_View_Helper_Html::purifyText($shipping['comments'])) : 'N/A';
 			
 		// Register a new order
-		$order = new Order($database);
-		$order->uid     = $juser->get('id');
+		$order = new Order($this->database);
+		$order->uid     = $this->juser->get('id');
 		$order->total   = $cost;
 		$order->status  = '0'; // order placed
 		$order->ordered = $now;
@@ -595,15 +478,15 @@ class StoreController extends JObject
 		}
 		
 		// Get order ID
-		$objO = new Order($database);
-		$orderid = $objO->getOrderID($juser->get('id'), $now);
+		$objO = new Order($this->database);
+		$orderid = $objO->getOrderID($this->juser->get('id'), $now);
 			
 		if ($orderid) {
 			// Transfer cart items to order
 			foreach ($items as $itm) 
 			{
-				$orderitem = new OrderItem( $database );
-				$orderitem->uid        = $juser->get('id');
+				$orderitem = new OrderItem( $this->database );
+				$orderitem->uid        = $this->juser->get('id');
 				$orderitem->oid        = $orderid;
 				$orderitem->itemid     = $itm->itemid;
 				$orderitem->price      = $itm->price;
@@ -615,16 +498,10 @@ class StoreController extends JObject
 					JError::raiseError( 500, $orderitem->getError() );
 					return;
 				}
-				
-				// Delete item from cart
-				if (!$item->deleteItem($itm->itemid, $juser->get('id'))) {
-					JError::raiseError( 500, $item->getError() );
-					return;
-				}
 			}
 			
 			// Put the purchase amount on hold
-			$BTL = new BankTeller( $database, $juser->get('id') );
+			$BTL = new Hubzero_Bank_Teller( $this->database, $this->juser->get('id') );
 			$BTL->hold($order->total, JText::_('COM_STORE_BANKING_HOLD'), 'store', $orderid);
 			
 			$jconfig =& JFactory::getConfig();
@@ -652,11 +529,14 @@ class StoreController extends JObject
 			// Send confirmation
 			JPluginHelper::importPlugin( 'xmessage' );
 			$dispatcher =& JDispatcher::getInstance();
-			if (!$dispatcher->trigger( 'onSendMessage', array( 'store_notifications', $subject, $message, $hub, array($juser->get('id')), $this->_option ))) {
+			if (!$dispatcher->trigger( 'onSendMessage', array( 'store_notifications', $subject, $message, $hub, array($this->juser->get('id')), $this->_option ))) {
 				$this->setError( JText::_('COM_STORE_ERROR_MESSAGE_FAILED') );
 			}
 		}
 		
+		// Empty cart
+		$item->deleteCartItem('', $this->juser->get('id'), 'all');
+		
 		// Instantiate a new view
 		$view = new JView( array('name'=>'completed') );
 		$view->option = $this->_option;
@@ -664,7 +544,7 @@ class StoreController extends JObject
 		$view->infolink = $this->infolink;
 		
 		// Output HTML
-		$view->juser = $juser;
+		$view->juser = $this->juser;
 		$view->orderid = $orderid;
 		if ($this->getError()) {
 			$view->setError( $this->getError() );
@@ -689,26 +569,23 @@ class StoreController extends JObject
 		$this->_buildPathway();
 		
 		// Check authorization
-		$juser =& JFactory::getUser();
-		if ($juser->get('guest')) {
+		if ($this->juser->get('guest')) {
 			$this->login();
 			return;
 		}
 		
-		$database =& JFactory::getDBO();
-		
 		// Get cart object
-		$item = new Cart( $database );
+		$item = new Cart( $this->database );
 		
 		// Calculate total
-		$cost = $item->getCartItems($juser->get('id'),'cost');
+		$cost = $item->getCartItems($this->juser->get('id'),'cost');
 		
 		if (!$cost) {
 			$this->setError( JText::_('COM_STORE_ERR_EMPTY_ORDER') );
 		}
 		
 		// Check available user funds		
-		$BTL = new BankTeller( $database, $juser->get('id') );
+		$BTL = new Hubzero_Bank_Teller( $this->database, $this->juser->get('id') );
 		$balance = $BTL->summary();
 		$credit = $BTL->credit_summary();
 		$funds = $balance - $credit;			
@@ -719,7 +596,7 @@ class StoreController extends JObject
 		}
 		
 		// Get cart items		
-		$items = $item->getCartItems($juser->get('id'));
+		$items = $item->getCartItems($this->juser->get('id'));
 				
 		// Get shipping info 
 		$posted = array_map('trim',$_POST);
@@ -750,13 +627,13 @@ class StoreController extends JObject
 		$view->option = $this->_option;
 		$view->title = $this->_title;
 		$view->infolink = $this->infolink;
-		$view->juser = $juser;
-		$view->xprofile = new XProfile;
-		$view->xprofile->load( $juser->get('id') );
+		$view->juser = $this->juser;
+		$view->xprofile = new Hubzero_User_Profile;
+		$view->xprofile->load( $this->juser->get('id') );
 		if ($this->getError()) {
 			$view->setError( $this->getError() );
 		}
 		$view->display();
 	}
 }
-?>
\ No newline at end of file
+
