@@ -1,86 +1,42 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Shawn Rice <zooley@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Shawn Rice <zooley@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
 
-class SupportController extends JObject
-{	
-	private $_name  = NULL;
-	private $_data  = array();
-	private $_task  = NULL;
+ximport('Hubzero_Controller');
 
-	//-----------
-	
-	public function __construct( $config=array() )
-	{
-		$this->_redirect = NULL;
-		$this->_message = NULL;
-		$this->_messageType = 'message';
-		
-		// Set the controller name
-		if (empty( $this->_name )) {
-			if (isset($config['name'])) {
-				$this->_name = $config['name'];
-			} else {
-				$r = null;
-				if (!preg_match('/(.*)Controller/i', get_class($this), $r)) {
-					echo "Controller::__construct() : Can't get or parse class name.";
-				}
-				$this->_name = strtolower( $r[1] );
-			}
-		}
-		
-		// Set the component name
-		$this->_option = 'com_'.$this->_name;
-	}
-
-	//-----------
-
-	public function __set($property, $value)
-	{
-		$this->_data[$property] = $value;
-	}
-	
-	//-----------
-	
-	public function __get($property)
-	{
-		if (isset($this->_data[$property])) {
-			return $this->_data[$property];
-		}
-	}
-
-	//-----------
-	
+class SupportController extends Hubzero_Controller
+{
 	public function execute()
 	{
-		// Get the component parameters
-		$this->config = new SupportConfig( $this->_option );
-
-		$this->database = JFactory::getDBO();
-
+		$this->acl = SupportACL::getACL();
+		
 		$this->_task = JRequest::getVar( 'task', '', 'post' );
 		if (!$this->_task) {
 			$this->_task = JRequest::getVar( 'task', '', 'get' );
@@ -97,6 +53,7 @@ class SupportController extends JObject
 			case 'feed':       $this->feed();       break;
 			case 'delete':     $this->delete();     break;
 			case 'index':      $this->index();      break;
+			case 'stats':      $this->stats();      break;
 			
 			case 'reportabuse': $this->reportabuse(); break;
 			case 'savereport':  $this->savereport();  break;
@@ -104,49 +61,10 @@ class SupportController extends JObject
 			default: $this->index(); break;
 		}
 	}
-
-	//-----------
-
-	public function redirect()
-	{
-		if ($this->_redirect != NULL) {
-			$app =& JFactory::getApplication();
-			$app->redirect( $this->_redirect, $this->_message, $this->_messageType );
-		}
-	}
-
-	//-----------
-
-	private function _getStyles($option='') 
-	{
-		ximport('xdocument');
-		if ($option) {
-			XDocument::addComponentStylesheet('com_'.$option);
-		} else {
-			XDocument::addComponentStylesheet($this->_option);
-		}
-	}
 	
 	//-----------
 	
-	private function _getScripts($option='',$name='')
-	{
-		$document =& JFactory::getDocument();
-		if ($option) {
-			$name = ($name) ? $name : $option;
-			if (is_file(JPATH_ROOT.DS.'components'.DS.'com_'.$option.DS.$name.'.js')) {
-				$document->addScript('components'.DS.'com_'.$option.DS.$name.'.js');
-			}
-		} else {
-			if (is_file(JPATH_ROOT.DS.'components'.DS.$this->_option.DS.$this->_name.'.js')) {
-				$document->addScript('components'.DS.$this->_option.DS.$this->_name.'.js');
-			}
-		}
-	}
-	
-	//-----------
-	
-	private function _buildPathway($ticket=null) 
+	protected function _buildPathway($ticket=null) 
 	{
 		$app =& JFactory::getApplication();
 		$pathway =& $app->getPathway();
@@ -169,37 +87,207 @@ class SupportController extends JObject
 		if (is_object($ticket) && $ticket->id) {
 			$pathway->addItem(
 				'#'.$ticket->id,
-				'index.php?option='.$this->_option.a.'task=ticket'.a.'id='.$ticket->id
+				'index.php?option='.$this->_option.'&task=ticket&id='.$ticket->id
 			);
 		}
 	}
 	
 	//-----------
 	
-	private function _buildTitle($ticket=null) 
+	protected function _buildTitle($ticket=null) 
 	{
-		$title = JText::_(strtoupper($this->_name));
+		$this->_title = JText::_(strtoupper($this->_name));
 		if ($this->_task) {
-			$title .= ': '.JText::_(strtoupper($this->_task));
+			$this->_title .= ': '.JText::_(strtoupper($this->_task));
 		}
 		if (is_object($ticket) && $ticket->id) {
-			$title .= ' #'.$ticket->id;
+			$this->_title .= ' #'.$ticket->id;
 		}
 		$document =& JFactory::getDocument();
-		$document->setTitle( $title );
+		$document->setTitle( $this->_title );
 	}
 	
 	//----------------------------------------------------------
 	// Views
 	//----------------------------------------------------------
 	
-	protected function index() 
+	protected function stats() 
 	{
-		ximport('xmodule');
+		// Check authorization
+		$juser =& JFactory::getUser();
+		if ($juser->get('guest')) {
+			return $this->login();
+		}
 		
 		// Instantiate a new view
-		jimport('joomla.application.component.view');
+		$view = new JView( array('name'=>'stats') );
+		$view->option = $this->_option;
+		$view->title = JText::_(strtoupper($this->_name));
 		
+		$view->authorized = $this->authorize();
+		//if ($view->authorized != 'admin') {
+		if (!$this->acl->check('read','tickets')) {
+			$this->_return = JRoute::_('index.php?option='.$this->_option.'&task=tickets');
+		}
+		
+		// Set the page title
+		$this->_buildTitle();
+		
+		// Set the pathway
+		$this->_buildPathway();
+		
+		// Push some styles to the template
+		$this->_getStyles();
+		
+		$type = JRequest::getVar('type', 'submitted');
+		$view->type = ($type == 'automatic') ? 1 : 0;
+		
+		$view->group = JRequest::getVar('group', '');
+		
+		$view->sort = JRequest::getVar('sort', 'name');
+		
+		// Set up some dates
+		$jconfig =& JFactory::getConfig();
+		$this->offset = $jconfig->getValue('config.offset');
+		
+		$year  = JRequest::getInt('year', strftime("%Y", time()+($this->offset*60*60)));
+		$month = strftime("%m", time()+($this->offset*60*60));
+		$day   = strftime("%d", time()+($this->offset*60*60));
+		if ($day<="9"&ereg("(^[1-9]{1})",$day)) {
+			$day = "0$day";
+		}
+		if ($month<="9"&ereg("(^[1-9]{1})",$month)) {
+			$month = "0$month";
+		}
+		
+		$startday = 0;
+		$numday = ((date("w",mktime(0,0,0,$month,$day,$year))-$startday)%7);
+		if ($numday == -1) {
+			$numday = 6;
+		} 
+		$week_start = mktime(0, 0, 0, $month, ($day - $numday), $year );
+		$week = strftime("%d", $week_start );
+		
+		$view->year = $year;
+		$view->opened = array();
+		$view->closed = array();
+		
+		$st = new SupportTicket( $this->database );
+		
+		// Get opened ticket information
+		$view->opened['year'] = $st->getCountOfTicketsOpened($view->type, $year, '01', '01', $view->group);
+		
+		$view->opened['month'] = $st->getCountOfTicketsOpened($view->type, $year, $month, '01', $view->group);
+		
+		$view->opened['week'] = $st->getCountOfTicketsOpened($view->type, $year, $month, $week, $view->group);
+		
+		// Currently open tickets
+		$view->opened['open'] = $st->getCountOfOpenTickets($view->type, false, $view->group);
+		
+		// Currently unassigned tickets
+		$view->opened['unassigned'] = $st->getCountOfOpenTickets($view->type, true, $view->group);
+		
+		// Get closed ticket information
+		$view->closed['year'] = $st->getCountOfTicketsClosed($view->type, $year, '01', '01', null, $view->group);
+		
+		$view->closed['month'] = $st->getCountOfTicketsClosed($view->type, $year, $month, '01', null, $view->group);
+		
+		$view->closed['week'] = $st->getCountOfTicketsClosed($view->type, $year, $month, $week, null, $view->group);
+		
+		// Users
+		$view->users = null;
+		
+		if ($view->group) {
+			$query = "SELECT a.username, a.name, a.id"
+				. "\n FROM #__users AS a, #__xgroups AS g, #__xgroups_members AS gm"
+				. "\n WHERE g.cn='".$view->group."' AND g.gidNumber=gm.gidNumber AND gm.uidNumber=a.id"
+				. "\n ORDER BY a.name";
+		} else {
+			$query = "SELECT a.username, a.name, a.id"
+				. "\n FROM #__users AS a"
+				. "\n INNER JOIN #__core_acl_aro AS aro ON aro.value = a.id"	// map user to aro
+				. "\n INNER JOIN #__core_acl_groups_aro_map AS gm ON gm.aro_id = aro.id"	// map aro to group
+				. "\n INNER JOIN #__core_acl_aro_groups AS g ON g.id = gm.group_id"
+				. "\n WHERE a.block = '0' AND g.id=25"
+				. "\n ORDER BY a.name";
+		}
+		
+		$this->database->setQuery( $query );
+		$users = $this->database->loadObjectList();
+		if ($users) {
+			$u = array();
+			$p = array();
+			$g = array();
+			foreach ($users as $user) 
+			{
+				$user->closed = array();
+				
+				// Get closed ticket information
+				$user->closed['year'] = $st->getCountOfTicketsClosed($view->type, $year, '01', '01', $user->username, $view->group);
+
+				$user->closed['month'] = $st->getCountOfTicketsClosed($view->type, $year, $month, '01', $user->username, $view->group);
+
+				$user->closed['week'] = $st->getCountOfTicketsClosed($view->type, $year, $month, $week, $user->username, $view->group);
+				
+				$p[$user->id] = $user;
+				switch ($view->sort) 
+				{
+					case 'year':
+						$u[$user->id] = $user->closed['year'];
+					break;
+					case 'month':
+						$u[$user->id] = $user->closed['month'];
+					break;
+					case 'week':
+						$u[$user->id] = $user->closed['week'];
+					break;
+					case 'name':
+					default:
+						$u[$user->id] = $user->name;
+					break;
+				}
+			}
+			if ($view->sort != 'name') {
+				arsort($u);
+			} else {
+				asort($u);
+			}
+			foreach ($u as $k=>$v) 
+			{
+				$g[] = $p[$k];
+			}
+			
+			$view->users = $g;
+		}
+		
+		// Get avgerage lifetime
+		$view->lifetime = $st->getAverageLifeOfTicket($view->type, $year, $view->group);
+		
+		// Tickets over time
+		$view->closedmonths = array();
+		for ($i = 1; $i <= 12; $i++) 
+		{
+			$view->closedmonths[$i] = $st->getCountOfTicketsClosedInMonth($view->type, $year, sprintf( "%02d",$i), $view->group);
+		}
+		
+		$view->openedmonths = array();
+		for ($i = 1; $i <= 12; $i++) 
+		{
+			$view->openedmonths[$i] = $st->getCountOfTicketsOpenedInMonth($view->type, $year, sprintf( "%02d",$i), $view->group);
+		}
+		
+		// Output HTML
+		if ($this->getError()) {
+			$view->setError( $this->getError() );
+		}
+		$view->display();
+	}
+	
+	//-----------
+	
+	protected function index() 
+	{
+		// Instantiate a new view
 		$view = new JView( array('name'=>'index') );
 		$view->title = JText::_(strtoupper($this->_name));
 		
@@ -211,7 +299,6 @@ class SupportController extends JObject
 		
 		// Push some styles to the template
 		$this->_getStyles();
-		$this->_getStyles('answers');
 		
 		// Output HTML
 		if ($this->getError()) {
@@ -225,8 +312,6 @@ class SupportController extends JObject
 	protected function login()
 	{
 		// Instantiate a new view
-		jimport('joomla.application.component.view');
-
 		$view = new JView( array('name'=>'login') );
 		$view->title = ucfirst($this->_name).': '.ucfirst($this->_task);
 		
@@ -242,36 +327,34 @@ class SupportController extends JObject
 	protected function tickets() 
 	{
 		// Instantiate a new view
-		jimport('joomla.application.component.view');
-		
 		$view = new JView( array('name'=>'tickets') );
 		$view->title = JText::_(strtoupper($this->_name)).': '.JText::_(strtoupper($this->_task));
 		$view->option = $this->_option;
 		$view->database = $this->database;
 
 		// Incoming
-		$view->filters = $this->getFilters();
+		$view->filters = $this->_getFilters();
 
 		// Check authorization
 		$juser =& JFactory::getUser();
 		if ($juser->get('guest')) {
 			return $this->login();
 		}
-		
-		$view->authorized = $this->authorize();
-		if (!$view->authorized) {
+	
+		if (!$this->acl->check('read','tickets')) {
 			$view->filters['owner'] = $juser->get('username');
 			$view->filters['reportedby'] = $juser->get('username');
 		}
+		$view->authorized = $this->authorize();
 
 		// Create a Ticket object
 		$obj = new SupportTicket( $this->database );
 
 		// Record count
-		$total = $obj->getTicketsCount( $view->filters, $view->authorized );
+		$total = $obj->getTicketsCount( $view->filters, $this->acl->check('read','tickets') );
 
 		// Fetch results
-		$view->rows = $obj->getTickets( $view->filters, $view->authorized );
+		$view->rows = $obj->getTickets( $view->filters, $this->acl->check('read','tickets') );
 
 		// Initiate paging class
 		jimport('joomla.html.pagination');
@@ -289,6 +372,8 @@ class SupportController extends JObject
 		// Get some needed scripts
 		$this->_getScripts();
 		
+		$view->acl = $this->acl;
+		
 		// Output HTML
 		if ($this->getError()) {
 			$view->setError( $this->getError() );
@@ -314,15 +399,13 @@ class SupportController extends JObject
 		}
 		
 		// Instantiate a new view
-		jimport('joomla.application.component.view');
-		
 		$view = new JView( array('name'=>'ticket') );
 		$view->title = JText::_(strtoupper($this->_name)).': '.JText::_(strtoupper($this->_task));
 		$view->option = $this->_option;
 		$view->database = $this->database;
 		
 		// Incoming
-		$view->filters = $this->getFilters();
+		$view->filters = $this->_getFilters();
 
 		// Initiate database class and load info
 		$view->row = new SupportTicket( $this->database );
@@ -333,14 +416,44 @@ class SupportController extends JObject
 			return;
 		}
 		
+		if ($view->row->login == $juser->get('username') 
+		 || $view->row->owner == $juser->get('username')) {
+			if (!$this->acl->check('read','tickets')) {
+				$this->acl->setAccess('read','tickets',1);
+			}
+			if (!$this->acl->check('update','tickets')) {
+				$this->acl->setAccess('update','tickets',-1);
+			}
+			if (!$this->acl->check('create','comments')) {
+				$this->acl->setAccess('create','comments',-1);
+			}
+			if (!$this->acl->check('read','comments')) {
+				$this->acl->setAccess('read','comments',1);
+			}
+		}
+		
+		if ($this->acl->authorize($view->row->group)) {
+			$this->acl->setAccess('read','tickets',1);
+			$this->acl->setAccess('update','tickets',1);
+			$this->acl->setAccess('delete','tickets',1);
+			$this->acl->setAccess('create','comments',1);
+			$this->acl->setAccess('read','comments',1);
+			$this->acl->setAccess('create','private_comments',1);
+			$this->acl->setAccess('read','private_comments',1);
+		}
+		
 		// Ensure the user is authorized to view this ticket
 		$view->authorized = $this->authorize($view->row->group);
-		if ($view->row->login != $juser->get('username') 
+		/*if ($view->row->login != $juser->get('username') 
 		 && $view->row->owner != $juser->get('username') 
 		 && !$view->authorized 
 		 && $view->row->section!=2) {
 			JError::raiseError( 403, JText::_('SUPPORT_NOT_AUTH') );
 			return;
+		}*/
+		if (!$this->acl->check('read','tickets')) {
+			JError::raiseError( 403, JText::_('SUPPORT_NOT_AUTH') );
+			return;
 		}
 		
 		// Get the next and previous support tickets
@@ -387,14 +500,22 @@ class SupportController extends JObject
 		
 		// Get comments
 		$sc = new SupportComment( $this->database );
-		$view->comments = $sc->getComments( $view->authorized, $view->row->id );
+		$view->comments = $sc->getComments( $this->acl->check('read','private_comments'), $view->row->id );
 
 		// Parse comment text for attachment tags
-		$xhub =& XFactory::getHub();
+		$juri =& JURI::getInstance();
+		
+		$webpath = str_replace('//','/',$juri->base().$this->config->get('webpath').DS.$id);
+		if (isset( $_SERVER['HTTPS'] )) {
+			$webpath = str_replace('http:','https:',$webpath);
+		}
+		if (!strstr( $webpath, '://' )) {
+			$webpath = str_replace(':/','://',$webpath);
+		}
 		
 		$attach = new SupportAttachment( $this->database );
-		$attach->webpath = $xhub->getCfg('hubLongURL').$this->config->parameters['webpath'].DS.$id;
-		$attach->uppath  = JPATH_ROOT.$this->config->parameters['webpath'].DS.$id;
+		$attach->webpath = $webpath;
+		$attach->uppath  = JPATH_ROOT.$this->config->get('webpath').DS.$id;
 		$attach->output  = 'web';
 		for ($i=0; $i < count($view->comments); $i++) 
 		{
@@ -409,14 +530,18 @@ class SupportController extends JObject
 			$comment->comment = $attach->parse($comment->comment);
 		}
 		
+		$view->row->report = $attach->parse($view->row->report);
+		
 		// Get severities
-		$view->lists['severities'] = $this->config->getSeverities();
+		$view->lists['severities'] = SupportUtilities::getSeverities($this->config->get('severities'));
 		
 		// Populate the list of assignees based on if the ticket belongs to a group or not
 		if (trim($view->row->group)) {
-			$view->lists['owner'] = $this->_userSelectGroup( 'owner', $view->row->owner, 1, '', trim($view->row->group) );
+			$view->lists['owner'] = $this->_userSelectGroup( 'ticket[owner]', $view->row->owner, 1, '', trim($view->row->group) );
+		} elseif (trim($this->config->get('group'))) {
+			$view->lists['owner'] = $this->_userSelectGroup( 'ticket[owner]', $view->row->owner, 1, '', trim($this->config->get('group')) );
 		} else {
-			$view->lists['owner'] = $this->_userSelect( 'owner', $view->row->owner, 1 );
+			$view->lists['owner'] = $this->_userSelect( 'ticket[owner]', $view->row->owner, 1 );
 		}
 		
 		// Set the pathway
@@ -431,6 +556,8 @@ class SupportController extends JObject
 		// Get some needed scripts
 		$this->_getScripts();
 		
+		$view->acl = $this->acl;
+		
 		// Output HTML
 		if ($this->getError()) {
 			$view->setError( $this->getError() );
@@ -455,7 +582,7 @@ class SupportController extends JObject
 		$doc->link = JRoute::_('index.php?option='.$this->_option.'&task=tickets');
 
 		// Incoming
-		$filters = $this->getFilters();
+		$filters = $this->_getFilters();
 
 		// Create a Ticket object
 		$obj = new SupportTicket( $this->database );
@@ -463,7 +590,7 @@ class SupportController extends JObject
 		// Fetch results
 		$rows = $obj->getTickets( $filters, true );
 
-		$xhub =& XFactory::getHub();
+		$xhub =& Hubzero_Factory::getHub();
 		
 		$doc->title = $xhub->getCfg('hubShortName').' '.JText::_('SUPPORT_RSS_TITLE');
 		$doc->description = JText::sprintf('SUPPORT_RSS_DESCRIPTION',$xhub->getCfg('hubShortName'));
@@ -509,13 +636,22 @@ class SupportController extends JObject
 	{
 	    $juser =& JFactory::getUser();
 		
-		// make sure we are still logged in
+		// Make sure we are still logged in
 		if ($juser->get('guest')) {
 			return $this->login();
 		}
 		
 		// Incoming
-		$id = JRequest::getInt( 'id', 0 );
+		$incoming = JRequest::getVar('ticket', array(), 'post');
+		
+		// Trim all posted items
+		$incoming = array_map('trim',$incoming);
+	
+		$id = JRequest::getInt('id', 0, 'post');
+		if (!$id) {
+			JError::raiseError( 500, JText::_('No Ticket ID provided.') );
+			return;
+		}
 	
 		// Instantiate the tagging class - we'll need this a few times
 		$st = new SupportTags( $this->database );
@@ -529,12 +665,9 @@ class SupportController extends JObject
 			$oldtags = $st->get_tag_string( $id, 0, 0, NULL, 0, 1 );
 		}
 	
-		// Trim and addslashes all posted items
-		$_POST = array_map('trim',$_POST);
-	
 		// Initiate class and bind posted items to database fields
 		$row = new SupportTicket( $this->database );
-		if (!$row->bind( $_POST )) {
+		if (!$row->bind( $incoming )) {
 			echo SupportHtml::alert( $row->getError() );
 			exit();
 		}
@@ -578,9 +711,9 @@ class SupportController extends JObject
 		
 		// Save the tags
 		$tags = trim(JRequest::getVar( 'tags', '', 'post' ));
-		if ($tags) {
-			$st->tag_object( $juser->get('id'), $row->id, $tags, 0, false );
-		}
+		//if ($tags) {
+			$st->tag_object( $juser->get('id'), $row->id, $tags, 0, true );
+		//}
 
 		// We must have a ticket ID before we can do anything else
 		if ($id) {
@@ -593,6 +726,13 @@ class SupportController extends JObject
 					$row->resolved = '';
 					$row->store();
 				}
+				// If a comment was posted by the ticket submitter to a "waiting user response" ticket, change status.
+				$ccreated_by = JRequest::getVar( 'username', '' );
+				if ($row->status == 1 && $ccreated_by == $row->login) {
+					$row->status = 0;
+					$row->resolved = '';
+					$row->store();
+				}
 			}
 			
 			// Compare fields to find out what has changed for this ticket and build a changelog
@@ -629,13 +769,13 @@ class SupportController extends JObject
 			}
 
 			// Were there any changes?
-			$log = implode(n,$changelog);
+			$log = implode("\n",$changelog);
 			if ($log != '') {
-				$log = '<ul class="changelog">'.n.$log.'</ul>'.n;
+				$log = '<ul class="changelog">'."\n".$log.'</ul>'."\n";
 			}
 			
 			$attachment = $this->upload( $row->id );
-			$comment .= ($attachment) ? n.n.$attachment : '';
+			$comment .= ($attachment) ? "\n\n".$attachment : '';
 			
 			// Create a new support comment object and populate it
 			$rowc = new SupportComment( $this->database );
@@ -661,13 +801,13 @@ class SupportController extends JObject
 				// Only do the following if a comment was posted
 				// otherwise, we're only recording a changelog
 				if ($comment || $row->owner != $old->owner) {
-					$xhub =& XFactory::getHub();
+					$xhub =& Hubzero_Factory::getHub();
 					$jconfig =& JFactory::getConfig();
 					
 					// Parse comments for attachments
 					$attach = new SupportAttachment( $this->database );
-					$attach->webpath = $xhub->getCfg('hubLongURL').$this->config->parameters['webpath'].DS.$id;
-					$attach->uppath  = JPATH_ROOT.$this->config->parameters['webpath'].DS.$id;
+					$attach->webpath = $xhub->getCfg('hubLongURL').$this->config->get('webpath').DS.$id;
+					$attach->uppath  = JPATH_ROOT.$this->config->get('webpath').DS.$id;
 					$attach->output  = 'email';
 
 					// Build e-mail components
@@ -679,30 +819,30 @@ class SupportController extends JObject
 					$from['name']  = $jconfig->getValue('config.sitename').' '.JText::_(strtoupper($this->_name));
 					$from['email'] = $jconfig->getValue('config.mailfrom');
 		
-					$message  = '----------------------------'.r.n;
-					$message .= strtoupper(JText::_('TICKET')).': '.$row->id.r.n;
-					$message .= strtoupper(JText::_('TICKET_DETAILS_SUMMARY')).': '.stripslashes($row->summary).r.n;
-					$message .= strtoupper(JText::_('TICKET_DETAILS_CREATED')).': '.$row->created.r.n;
+					$message  = '----------------------------'."\r\n";
+					$message .= strtoupper(JText::_('TICKET')).': '.$row->id."\r\n";
+					$message .= strtoupper(JText::_('TICKET_DETAILS_SUMMARY')).': '.stripslashes($row->summary)."\r\n";
+					$message .= strtoupper(JText::_('TICKET_DETAILS_CREATED')).': '.$row->created."\r\n";
 					$message .= strtoupper(JText::_('TICKET_DETAILS_CREATED_BY')).': '.$row->name;
-					$message .= ($row->login) ? ' ('.$row->login.')'.r.n : r.n;
-					$message .= '----------------------------'.r.n.r.n;
-					$message .= JText::sprintf('TICKET_EMAIL_COMMENT_POSTED',$row->id).': '.$rowc->created_by.r.n;
-					$message .= JText::_('TICKET_EMAIL_COMMENT_CREATED').': '.$rowc->created.r.n.r.n;
+					$message .= ($row->login) ? ' ('.$row->login.')'."\r\n" : "\r\n";
+					$message .= '----------------------------'."\r\n\r\n";
+					$message .= JText::sprintf('TICKET_EMAIL_COMMENT_POSTED',$row->id).': '.$rowc->created_by."\r\n";
+					$message .= JText::_('TICKET_EMAIL_COMMENT_CREATED').': '.$rowc->created."\r\n\r\n";
 					if ($row->owner != $old->owner) {
 						if ($old->owner == '') {
-							$message .= JText::_('TICKET_FIELD_OWNER').' '.JText::_('TICKET_SET_TO').' "'.$row->owner.'"'.r.n.r.n;
+							$message .= JText::_('TICKET_FIELD_OWNER').' '.JText::_('TICKET_SET_TO').' "'.$row->owner.'"'."\r\n\r\n";
 						} else {
-							$message .= JText::_('TICKET_FIELD_OWNER').' '.JText::_('TICKET_CHANGED_FROM').' "'.$old->owner.'" to "'.$row->owner.'"'.r.n.r.n;
+							$message .= JText::_('TICKET_FIELD_OWNER').' '.JText::_('TICKET_CHANGED_FROM').' "'.$old->owner.'" to "'.$row->owner.'"'."\r\n\r\n";
 						}
 					}
-					$message .= $attach->parse($comment).r.n.r.n;
+					$message .= $attach->parse($comment)."\r\n\r\n";
 
 					$juri =& JURI::getInstance();
-					$sef = JRoute::_('index.php?option='.$this->_option.a.'task=ticket'.a.'id='. $row->id);
+					$sef = JRoute::_('index.php?option='.$this->_option.'&task=ticket&id='. $row->id);
 					if (substr($sef,0,1) == '/') {
 						$sef = substr($sef,1,strlen($sef));
 					}
-					$message .= $juri->base().$sef.r.n;
+					$message .= $juri->base().$sef."\r\n";
 
 					// An array for all the addresses to be e-mailed
 					$emails = array();
@@ -717,23 +857,29 @@ class SupportController extends JObject
 					if ($email_submitter == 1) {
 						// Is the comment private? If so, we do NOT send e-mail to the 
 						// submitter regardless of the above setting
-						$zuser =& JUser::getInstance($row->login);
-						if ($rowc->access != 1 && is_object($zuser)) {
-							$type = 'support_reply_submitted';
-							if ($row->status == 1) {
-								$element = $row->id;
-								$description = 'index.php?option='.$this->_option.a.'task=ticket'.a.'id='.$row->id;
-							} else {
-								$element = null;
-								$description = '';
-								if ($row->status == 2) {
-									$type = 'support_close_submitted';
+						if ($rowc->access != 1) {
+							$zuser =& JUser::getInstance($row->login);
+							// Make sure there even IS an e-mail and it's valid
+							if (is_object($zuser) && $zuser->get('id')) {
+								$type = 'support_reply_submitted';
+								if ($row->status == 1) {
+									$element = $row->id;
+									$description = 'index.php?option='.$this->_option.'&task=ticket&id='.$row->id;
+								} else {
+									$element = null;
+									$description = '';
+									if ($row->status == 2) {
+										$type = 'support_close_submitted';
+									}
 								}
-							}
-							
-							if (!$dispatcher->trigger( 'onSendMessage', array( $type, $subject, $message, $from, array($zuser->get('id')), $this->_option ))) {
-								$this->setError( JText::_('Failed to message ticket submitter.') );
-							} else {
+
+								if (!$dispatcher->trigger( 'onSendMessage', array( $type, $subject, $message, $from, array($zuser->get('id')), $this->_option ))) {
+									$this->setError( JText::_('Failed to message ticket submitter.') );
+								} else {
+									$emaillog[] = '<li>'.JText::_('TICKET_EMAILED_SUBMITTER').' - '.$row->email.'</li>';
+								}
+							} else if ($row->email && SupportUtilities::checkValidEmail($row->email)) {
+								$emails[] = $row->email;
 								$emaillog[] = '<li>'.JText::_('TICKET_EMAILED_SUBMITTER').' - '.$row->email.'</li>';
 							}
 						}
@@ -776,7 +922,7 @@ class SupportController extends JObject
 									continue;
 								}
 							// Make sure it's a valid e-mail address
-							} else if (SupportUtils::check_validEmail($acc)) {
+							} else if (SupportUtilities::checkValidEmail($acc)) {
 								$emails[] = $acc;
 								$emaillog[] = '<li>'.JText::_('TICKET_EMAILED_CC').' - '.$acc.'</li>';
 							}
@@ -786,13 +932,13 @@ class SupportController extends JObject
 					// Send an e-mail to each address
 					foreach ($emails as $email)
 					{
-						SupportUtils::send_email($email, $subject, $message, $from);
+						SupportUtilities::sendEmail($email, $subject, $message, $from);
 					}
 					
 					// Were there any changes?
-					$elog = implode(n,$emaillog);
+					$elog = implode("\n",$emaillog);
 					if ($elog != '') {
-						$rowc->changelog .= '<ul class="emaillog">'.n.$elog.'</ul>'.n;
+						$rowc->changelog .= '<ul class="emaillog">'."\n".$elog.'</ul>'."\n";
 						
 						// Save the data
 						if (!$rowc->store()) {
@@ -817,7 +963,7 @@ class SupportController extends JObject
 	
 		// Check for an ID
 		if (!$id) {
-			$this->_redirect = JRoute::_('index.php?option='.$this->_option.a.'task=tickets');
+			$this->_redirect = JRoute::_('index.php?option='.$this->_option.'&task=tickets');
 			return;
 		}
 		
@@ -834,7 +980,7 @@ class SupportController extends JObject
 		$ticket->delete( $id );
 		
 		// Output messsage and redirect
-		$this->_redirect = JRoute::_('index.php?option='.$this->_option.a.'task=tickets');
+		$this->_redirect = JRoute::_('index.php?option='.$this->_option.'&task=tickets');
 	}
 
 	//-----------
@@ -866,12 +1012,12 @@ class SupportController extends JObject
 		*/
 		
 		// trim and addslashes all posted items
-		$_POST = array_map('trim',$_POST);
-		$_POST = array_map('addslashes',$_POST);
+		$incoming = array_map('trim',$_POST);
+		$incoming = array_map('addslashes',$incoming);
 	
 		// initiate class and bind posted items to database fields
 		$row = new SupportTicket( $this->database );
-		if (!$row->bind( $_POST )) {
+		if (!$row->bind( $incoming )) {
 			return $row->getError();
 		}
 		
@@ -986,8 +1132,9 @@ class SupportController extends JObject
 			}
 			
 			// clean any cross-site scripting from report
-			$row->summary = TextFilter::cleanXss($row->summary);
-			$row->report  = TextFilter::cleanXss($row->report);
+			ximport('Hubzero_Filter');
+			$row->summary = Hubzero_Filter::cleanXss($row->summary);
+			$row->report  = Hubzero_Filter::cleanXss($row->report);
 			$row->report  = str_replace( '<br>', '<br />', $row->report );
 			$row->report  = ''.$row->report;
 			
@@ -1035,8 +1182,6 @@ class SupportController extends JObject
 		}
 		
 		// Instantiate a new view
-		jimport('joomla.application.component.view');
-
 		$view = new JView( array('name'=>'reportabuse') );
 		$view->title = ucfirst($this->_name).': '.ucfirst($this->_task);
 		$view->option = $this->_option;
@@ -1111,8 +1256,6 @@ class SupportController extends JObject
 		$email = 0; // turn off
 		
 		// Instantiate a new view
-		jimport('joomla.application.component.view');
-
 		$view = new JView( array('name'=>'thanks') );
 		$view->title = ucfirst($this->_name).': '.ucfirst($this->_task);
 		$view->option = $this->_option;
@@ -1123,16 +1266,17 @@ class SupportController extends JObject
 		$view->returnlink = JRequest::getVar( 'link', '' );
 			
 		// Trim and addslashes all posted items
-		$_POST = array_map('trim',$_POST);
+		$incoming = array_map('trim',$_POST);
 	
 		// Initiate class and bind posted items to database fields
 		$row = new ReportAbuse( $this->database );
-		if (!$row->bind( $_POST )) {
+		if (!$row->bind( $incoming )) {
 			echo SupportHtml::alert( $row->getError() );
 			exit();
 		}
 
-		$row->report     = TextFilter::cleanXss($row->report);
+		ximport('Hubzero_Filter');
+		$row->report     = Hubzero_Filter::cleanXss($row->report);
 		$row->report     = nl2br($row->report);
 		$row->created_by = $juser->get('id');
 		$row->created    = date( 'Y-m-d H:i:s', time() );
@@ -1172,8 +1316,8 @@ class SupportController extends JObject
 			
 			foreach ($tos as $to) 
 			{
-				if (SupportUtils::check_validEmail($to)) {
-					if (!SupportUtils::send_email($from, $to, $subject, $message)) {
+				if (SupportUtilities::checkValidEmail($to)) {
+					if (!SupportUtilities::sendEmail($from, $to, $subject, $message)) {
 						$this->setError( JText::sprintf('ERROR_FAILED_TO_SEND_EMAIL',$to) );
 					}
 				}
@@ -1200,7 +1344,7 @@ class SupportController extends JObject
 	// General functions
 	//----------------------------------------------------------
 
-	private function getFilters()
+	private function _getFilters()
 	{
 		// Query filters defaults
 		$filters = array();
@@ -1243,6 +1387,18 @@ class SupportController extends JObject
 		// Loop through each chunk (filter:option)
 		foreach ($chunks as $chunk) 
 		{
+			if (!strstr($chunk,':')) {
+				if ((substr($chunk, 0, 1) == '"' 
+				 || substr($chunk, 0, 1) == "'") 
+				 && (substr($chunk, -1) == '"' 
+				 || substr($chunk, -1) == "'")) {
+					$chunk = substr($chunk, 1, -1);  // Remove any surrounding quotes
+				}
+
+				$filters['search'] = $chunk;
+				continue;
+			}
+			
 			// Break each chunk into its pieces (filter, option)
 			$pieces = explode(':', $chunk);
 			
@@ -1338,32 +1494,64 @@ class SupportController extends JObject
 	
 	private function _userSelectGroup( $name, $active, $nouser=0, $javascript=NULL, $group='' ) 
 	{
-		ximport('xgroup');
-		
-		$xgroup = new XGroup();
-		$xgroup->select( $group );
-		
 		$users = array();
 		if ($nouser) {
 			$users[] = JHTML::_('select.option', '', 'No User', 'value', 'text');
 		}
 		
-		if ($xgroup->get('gidNumber')) {
-			$members = $xgroup->get('members');
+		ximport('Hubzero_Group');
+		
+		if (strstr($group,',')) {
+			$groups = explode(',',$group);
+			if (is_array($groups)) {
+				foreach ($groups as $g) 
+				{
+					$hzg = Hubzero_Group::getInstance( trim($g) );
 
-			foreach ($members as $member) 
-			{
-				$u =& JUser::getInstance($member);
-				if (!is_object($u)) {
-					continue;
+					if ($hzg->get('gidNumber')) {
+						$members = $hzg->get('members');
+
+						//$users[] = '<optgroup title="'.stripslashes($hzg->description).'">';
+						$users[] = JHTML::_('select.optgroup', stripslashes($hzg->description) );
+						foreach ($members as $member) 
+						{
+							$u =& JUser::getInstance($member);
+							if (!is_object($u)) {
+								continue;
+							}
+
+							$m = new stdClass();
+							$m->value = $u->get('username');
+							$m->text  = $u->get('name');
+							$m->groupname = $g;
+
+							$users[] = $m;
+						}
+						//$users[] = '</optgroup>';
+						$users[] = JHTML::_('select.option', '</OPTGROUP>' );
+					}
 				}
+			}
+		} else {
+			$hzg = Hubzero_Group::getInstance( $group );
 
-				$m = new stdClass();
-				$m->value = $u->get('username');
-				$m->text  = $u->get('name');
-				$m->groupname = $group;
+			if ($hzg && $hzg->get('gidNumber')) {
+				$members = $hzg->get('members');
 
-				$users[] = $m;
+				foreach ($members as $member) 
+				{
+					$u =& JUser::getInstance($member);
+					if (!is_object($u)) {
+						continue;
+					}
+
+					$m = new stdClass();
+					$m->value = $u->get('username');
+					$m->text  = $u->get('name');
+					$m->groupname = $group;
+
+					$users[] = $m;
+				}
 			}
 		}
 		
@@ -1400,7 +1588,7 @@ class SupportController extends JObject
 		$description = JRequest::getVar( 'description', '' );
 		
 		// Construct our file path
-		$path = JPATH_ROOT.$this->config->parameters['webpath'].DS.$listdir;
+		$path = JPATH_ROOT.$this->config->get('webpath').DS.$listdir;
 		
 		// Build the path if it doesn't exist
 		if (!is_dir( $path )) {
@@ -1459,13 +1647,12 @@ class SupportController extends JObject
 		}
 		
 		// Was a specific group set in the config?
-		$group = trim($this->config->parameters['group']);
+		$group = trim($this->config->get('group'));
 		if ($group or $toolgroup) {
-			ximport('xgroup');
-			ximport('xuserhelper');
+			ximport('Hubzero_User_Helper');
 			
 			// Check if they're a member of this group
-			$ugs = XUserHelper::getGroups( $juser->get('id') );
+			$ugs = Hubzero_User_Helper::getGroups( $juser->get('id') );
 			if ($ugs && count($ugs) > 0) {
 				foreach ($ugs as $ug) 
 				{
@@ -1482,4 +1669,4 @@ class SupportController extends JObject
 		return false;
 	}
 }
-?>
+
