@@ -1,86 +1,43 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Shawn Rice <zooley@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Shawn Rice <zooley@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
 
-class TagsController extends JObject
-{	
-	private $_name  = NULL;
-	private $_data  = array();
-	private $_task  = NULL;
+ximport('Hubzero_Controller');
 
-	//-----------
-	
-	public function __construct( $config=array() )
-	{
-		$this->_redirect = NULL;
-		$this->_message = NULL;
-		$this->_messageType = 'message';
-		
-		// Set the controller name
-		if (empty( $this->_name )) {
-			if (isset($config['name'])) {
-				$this->_name = $config['name'];
-			} else {
-				$r = null;
-				if (!preg_match('/(.*)Controller/i', get_class($this), $r)) {
-					echo "Controller::__construct() : Can't get or parse class name.";
-				}
-				$this->_name = strtolower( $r[1] );
-			}
-		}
-		
-		// Set the component name
-		$this->_option = 'com_'.$this->_name;
-	}
-
-	//-----------
-
-	public function __set($property, $value)
-	{
-		$this->_data[$property] = $value;
-	}
-	
-	//-----------
-	
-	public function __get($property)
-	{
-		if (isset($this->_data[$property])) {
-			return $this->_data[$property];
-		}
-	}
-	
-	//-----------
-	
+class TagsController extends Hubzero_Controller
+{
 	public function execute()
-	{	
-		$this->database = JFactory::getDBO();
-		
+	{
 		$this->_task = strtolower(JRequest::getVar('task', ''));
 
-		switch ( $this->_task ) 
+		switch ($this->_task) 
 		{
 			case 'autocomplete': $this->autocomplete(); break;
 			case 'cancel': $this->cancel(); break;
@@ -98,16 +55,6 @@ class TagsController extends JObject
 			default: $this->intro(); break;
 		}
 	}
-	
-	//-----------
-
-	public function redirect()
-	{
-		if ($this->_redirect != NULL) {
-			$app =& JFactory::getApplication();
-			$app->redirect( $this->_redirect, $this->_message, $this->_messageType );
-		}
-	}
 
 	//----------------------------------------------------------
 	// Views
@@ -192,8 +139,10 @@ class TagsController extends JObject
 		
 		$addtag = trim(JRequest::getVar('addtag', ''));
 		
+		//$search = trim(JRequest::getVar('tags', ''));
+		
 		// Ensure we were passed a tag
-		if (!$tagstring && !$addtag) {
+		if (!$tagstring && !$addtag && !$search) {
 			JError::raiseError( 404, JText::_('COM_TAGS_NO_TAG') );
 			return;
 		}
@@ -205,6 +154,19 @@ class TagsController extends JObject
 		} else {
 			$tgs = array();
 		}
+		/*if ($search) {
+			// Break the string into individual tags
+			$stgs = explode(',', $search);
+			$stgs = array_map('trim',$stgs);
+		} else {
+			$stgs = array();
+		}
+		foreach ($stgs as $stg) 
+		{
+			if (!in_array($stg,$tgs)) {
+				$tgs[] = $stg;
+			}
+		}*/
 		
 		// See if we're adding any tags to the search list
 		if ($addtag && !in_array($addtag,$tgs)) {
@@ -212,7 +174,7 @@ class TagsController extends JObject
 		}
 
 		// Sanitize the tag
-		$t = new Tags( $this->database );
+		$t = new TagsHandler( $this->database );
 		
 		$tags = array();
 		$added = array();
@@ -374,7 +336,12 @@ class TagsController extends JObject
 		$this->_getStyles();
 		
 		// Output HTML
-		$view = new JView( array('name'=>'tag') );
+		$format = JRequest::getVar('format', '');
+		if ($format == 'xml') {
+			$view = new JView( array('name'=>'tag', 'layout'=>'xml') );
+		} else {
+			$view = new JView( array('name'=>'tag') );
+		}
 		$view->title = $title;
 		$view->authorized = $authorized;
 		$view->tags = $tags;
@@ -388,6 +355,7 @@ class TagsController extends JObject
 		$view->sort = $sort;
 		$view->total = $total;
 		$view->tagstring = $tagstring;
+		$view->search = implode(', ',$tgs);
 		if ($this->getError()) {
 			$view->setError( $this->getError() );
 		}
@@ -414,7 +382,8 @@ class TagsController extends JObject
 		if (count($rows) > 0) {
 			foreach ($rows as $row) 
 			{
-				$json[] = '"'.$row->raw_tag.'"';
+				//$json[] = '"'.$row->raw_tag.'"';
+				$json[] = '["'.htmlentities(stripslashes($row->raw_tag),ENT_COMPAT,'UTF-8').'","'.$row->tag.'"]';
 			}
 		}
 		
@@ -451,7 +420,7 @@ class TagsController extends JObject
 		$tgs = explode(' ', $tagstring);
 		
 		// Sanitize the tag
-		$t = new Tags( $this->database );
+		$t = new TagsHandler( $this->database );
 		
 		$tags = array();
 		foreach ($tgs as $tag) 
@@ -485,6 +454,7 @@ class TagsController extends JObject
 
 		// Get the active category
 		$area = JRequest::getVar( 'area', '' );
+		$sort = JRequest::getVar( 'sort', '' );
 
 		if (!$area) {
 			$t = array();
@@ -505,6 +475,7 @@ class TagsController extends JObject
 				$tags,
 				$limit,
 				$limitstart,
+				$sort,
 				$activeareas)
 			);
 		
@@ -541,7 +512,7 @@ class TagsController extends JObject
 
 		// Start outputing results if any found
 		if (count($rows) > 0) {
-			include_once( JPATH_ROOT.DS.'components'.DS.'com_resources'.DS.'resources.extended.php' );
+			include_once( JPATH_ROOT.DS.'components'.DS.'com_resources'.DS.'helpers'.DS.'helper.php' );
 			
 			foreach ($rows as $row)
 			{
@@ -591,7 +562,12 @@ class TagsController extends JObject
 	protected function browse()
 	{
 		// Instantiate a new view
-		$view = new JView( array('name'=>'browse') );
+		$format = JRequest::getVar('format', '');
+		if ($format == 'xml') {
+			$view = new JView( array('name'=>'browse', 'layout'=>'xml') );
+		} else {
+			$view = new JView( array('name'=>'browse') );
+		}
 		$view->option = $this->_option;
 		$view->title = JText::_(strtoupper($this->_option)) .': '. JText::_(strtoupper($this->_option).'_'.strtoupper($this->_task));
 		
@@ -605,20 +581,28 @@ class TagsController extends JObject
 		$view->filters = array();
 		$view->filters['start']  = JRequest::getInt('limitstart', 0);
 		$view->filters['search'] = urldecode(JRequest::getString('search'));
+		$view->total = 0;
 		
 		$t = new TagsTag( $this->database );
+		
+		$order = JRequest::getVar('order', '');
+		if ($order == 'usage') {
+			$limit = JRequest::getInt('limit', $config->getValue('config.list_limit'));
+			
+			$view->rows = $t->getTopTags( $limit );
+		} else {
+			// Record count
+			$view->total = $t->getCount( $view->filters );
 
-		// Record count
-		$total = $t->getCount( $view->filters );
-		
-		$view->filters['limit']  = JRequest::getInt('limit', $config->getValue('config.list_limit'));
-		
-		// Get records
-		$view->rows = $t->getRecords( $view->filters );
-		
-		// Initiate paging
-		jimport('joomla.html.pagination');
-		$view->pageNav = new JPagination( $total, $view->filters['start'], $view->filters['limit'] );
+			$view->filters['limit'] = JRequest::getInt('limit', $config->getValue('config.list_limit'));
+
+			// Get records
+			$view->rows = $t->getRecords( $view->filters );
+
+			// Initiate paging
+			jimport('joomla.html.pagination');
+			$view->pageNav = new JPagination( $view->total, $view->filters['start'], $view->filters['limit'] );
+		}
 
 		// Set the pathway
 		$this->_buildPathway();
@@ -703,7 +687,7 @@ class TagsController extends JObject
 		
 		$row->raw_tag = trim($row->raw_tag);
 		
-		$t = new Tags();
+		$t = new TagsHandler($this->database);
 		$row->tag = $t->normalize_tag($row->raw_tag);
 
 		// Check content
@@ -774,44 +758,8 @@ class TagsController extends JObject
 	//----------------------------------------------------------
 	// Private functions
 	//----------------------------------------------------------
-	
-	private function _authorize()
-	{
-		// Check if they are logged in
-		$juser =& JFactory::getUser();
-		if ($juser->get('guest')) {
-			return false;
-		}
-		
-		// Check if they're a site admin (from Joomla)
-		if ($juser->authorize($this->_option, 'manage')) {
-			return true;
-		}
 
-		return false;
-	}
-	
-	//-----------
-	
-	private function _getStyles() 
-	{
-		ximport('xdocument');
-		XDocument::addComponentStylesheet($this->_option);
-	}
-
-	//-----------
-	
-	private function _getScripts()
-	{
-		$document =& JFactory::getDocument();
-		if (is_file(JPATH_ROOT.DS.'components'.DS.$this->_option.DS.$this->_name.'.js')) {
-			$document->addScript('components'.DS.$this->_option.DS.$this->_name.'.js');
-		}
-	}
-	
-	//-----------
-
-	private function _buildPathway($tags=null) 
+	protected function _buildPathway($tags=null) 
 	{
 		$app =& JFactory::getApplication();
 		$pathway =& $app->getPathway();
@@ -847,7 +795,7 @@ class TagsController extends JObject
 	
 	//-----------
 	
-	private function _buildTitle($tags=null) 
+	protected function _buildTitle($tags=null) 
 	{
 		$title = JText::_(strtoupper($this->_option));
 		if ($this->_task && $this->_task != 'view') {
@@ -866,4 +814,4 @@ class TagsController extends JObject
 		$document->setTitle( $title );
 	}
 }
-?>
\ No newline at end of file
+
