@@ -1,24 +1,29 @@
 <?php
 /**
- * @author		Alissa Nedossekina <alisa@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * @license		GNU General Public License, version 2 (GPLv2) 
+ * @package     hubzero-cms
+ * @author      Alissa Nedossekina <alisa@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     GNU General Public License, version 2 (GPLv2) 
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
@@ -129,7 +134,7 @@ class WishlistController extends JObject
 		$this->banking = $this->config->get('banking') && $banking ? $this->config->get('banking') : 0;
 		
 		if ($banking) {
-			ximport( 'bankaccount' );
+			ximport('Hubzero_Bank');
 		}	
 			
 		switch( $this->getTask() ) 
@@ -159,6 +164,7 @@ class WishlistController extends JObject
 			case 'savevote':    $this->savevote();      break;
 			case 'savereply':   $this->savereply();   	break;
 			case 'reply':      	$this->reply();  	  	break;	
+			case 'deletereply': $this->deletereply();   break;
 			
 			// Autocompleter - called via AJAX
 			case 'autocomplete': $this->autocomplete(); break;
@@ -185,11 +191,11 @@ class WishlistController extends JObject
 
 	public function _getStyles($option='', $css='')
 	{
-		ximport('xdocument');
+		ximport('Hubzero_Document');
 		if ($option) {
-			XDocument::addComponentStylesheet($option, $css);
+			Hubzero_Document::addComponentStylesheet($option, $css);
 		} else {
-			XDocument::addComponentStylesheet($this->_option);
+			Hubzero_Document::addComponentStylesheet($this->_option);
 		}
 
 	}
@@ -248,6 +254,7 @@ class WishlistController extends JObject
 					);
 				break;				
 				case 'add':
+				case 'savewish':
 				case 'editwish':
 					$pathway->addItem( 
 						$this->_taskname, 
@@ -311,6 +318,32 @@ class WishlistController extends JObject
 	// Views
 	//----------------------------------------------------------
 
+	protected function abort() 
+	{
+		// Set the page title
+		$document =& JFactory::getDocument();
+		$document->setTitle( JText::_(strtoupper($this->_name)) );
+
+		// Set the pathway
+		$app =& JFactory::getApplication();
+		$pathway =& $app->getPathway();
+		if (count($pathway->getPathWay()) <= 0) {
+			$pathway->addItem(JText::_(strtoupper($this->_name)),'index.php?option='.$this->_option);
+		}
+		
+		$this->setError( JText::_('Wishlist not configured.') );
+		
+		// Output HTML
+		$view = new JView( array('name'=>'error') );
+		$view->title = JText::_(strtoupper($this->_name));
+		if ($this->getError()) {
+			$view->setError( $this->getError() );
+		}
+		$view->display();
+	}
+	
+	//-----------
+
 	public function login() 
 	{
 		$view = new JView( array('name'=>'login') );
@@ -336,6 +369,10 @@ class WishlistController extends JObject
 		$refid  = JRequest::getInt( 'rid', 0 );
 		$cat   	= JRequest::getVar( 'category', '' );
 		$saved  = JRequest::getInt( 'saved', 0 );
+
+		if (empty($id) && empty($cat) && empty($refid)) {
+			$id = $this->mainlist;
+		}
 		
 		// are we viewing this from within a plugin?
 		$plugin = (isset($this->plugin) && $this->plugin!='') ? $this->plugin : '';
@@ -381,8 +418,7 @@ class WishlistController extends JObject
 				
 				// create private list for group
 				if(Hubzero_Group::exists($refid)) {
-					$group = new XGroup();
-					$group->select($refid);	
+					$group = Hubzero_Group::getInstance($refid);
 					$id = $obj->createlist($cat, $refid, 0, $group->cn.' '.JText::_('WISHLIST_NAME_GROUP'));
 				}
 			}						
@@ -467,6 +503,13 @@ class WishlistController extends JObject
 			$wishlist->items = $objWish->get_wishes($wishlist->id, $filters, $this->_admin, $juser);	
 			$total = $objWish->get_count($wishlist->id, $filters, $this->_admin, $juser);
 			
+			// Get count of granted wishes
+			$sp_filters = $filters;
+			$sp_filters['filterby'] = 'granted';
+			$wishlist->granted_count = $objWish->get_count($wishlist->id, $sp_filters, $this->_admin, $juser);
+			$wishlist->granted_percentage = $total > 0 && $wishlist->granted_count > 0 ?  round(($wishlist->granted_count/$total) * 100, 0 ) : 0;
+			
+			// Some extras
 			$wishlist->saved = $saved;
 			$wishlist->banking = $this->banking ? $this->banking : 0;
 			$wishlist->banking = $wishlist->category=='user' ? 0 : $this->banking; // do not allow points for individual wish lists		
@@ -486,6 +529,7 @@ class WishlistController extends JObject
 		$view->pageNav = $pageNav;
 		$view->wishlist = $wishlist;
 		$view->filters = $filters;
+		$view->database = $database;
 		$view->abuse = true;
 		if ($this->getError()) {
 			$view->setError( $this->getError() );
@@ -604,8 +648,8 @@ class WishlistController extends JObject
 			$wish->prev = $objWish->getWishId('prev', $wishid, $wish->wishlist, $this->_admin, $juser->get('id'), $filters);
 			$wish->next = $objWish->getWishId('next', $wishid, $wish->wishlist, $this->_admin, $juser->get('id'), $filters);
 			
-			// Update average value for importance (this is tricky is MySQL)
-			$votesplit = isset($this->config->parameters['votesplit']) ? trim($this->config->parameters['votesplit']) : 0;
+			// Update average value for importance (this is tricky MySQL)
+			$votesplit = $this->config->get('votesplit')  ? trim($this->config->get('votesplit') ) : 0;
 			if(count($wishlist->advisory) > 0 && $votesplit) {
 				$objR = new WishRank ( $database );
 				$votes = $objR->get_votes($wish->id);
@@ -666,7 +710,7 @@ class WishlistController extends JObject
 
 			// check available user funds	
 			if($action == 'addbonus' && $this->banking) {	
-				$BTL 		= new BankTeller( $database, $juser->get('id') );
+				$BTL 		= new Hubzero_Bank_Teller( $database, $juser->get('id') );
 				$balance 	= $BTL->summary();
 				$credit 	= $BTL->credit_summary();
 				$funds 		= $balance - $credit;			
@@ -681,8 +725,7 @@ class WishlistController extends JObject
 				$wish->cats = $cats;
 				
 				if($wishlist->category=='group') {
-					$group = new XGroup();
-					$group->select($wishlist->referenceid);
+					$group = Hubzero_Group::getInstance($wishlist->referenceid);
 					$wishlist->cn = $group->cn;
 				}				
 			}
@@ -712,7 +755,7 @@ class WishlistController extends JObject
 		}		
 		
 		if ( $this->_task=='reply') {
-			$addcomment = & new XComment( $database );
+			$addcomment = & new Hubzero_Comment( $database );
 			$addcomment->referenceid = $this->referenceid;
 			$addcomment->category = $this->cat;
 				
@@ -801,7 +844,7 @@ class WishlistController extends JObject
 			return;
 		}
 		$obj->description  = rtrim(stripslashes($obj->description));
-		$obj->description  = TextFilter::cleanXss($obj->description);
+		$obj->description  = Hubzero_Filter::cleanXss($obj->description);
 		$obj->description  = nl2br($obj->description);
 	
 		// check content
@@ -820,7 +863,7 @@ class WishlistController extends JObject
 		$newowners = $this->makeArray(rtrim($_POST['newowners']));
 		$newgroups = $this->makeArray(rtrim($_POST['newgroups']));
 		
-		$allow_advisory = isset($this->config->parameters['allow_advisory']) ? $this->config->parameters['allow_advisory'] : 0;
+		$allow_advisory = $this->config->get('allow_advisory') ? $this->config->get('allow_advisory') : 0;
 		$newadvisory = $allow_advisory ? $this->makeArray(rtrim($_POST['newadvisory'])) : array();
 		
 		if(!empty($newowners)) {
@@ -908,7 +951,7 @@ class WishlistController extends JObject
 		$wishlist->nativeowners = $nativeowners['individuals'];
 		$wishlist->nativegroups = $nativeowners['groups'];
 		
-		$wishlist->allow_advisory = isset($this->config->parameters['allow_advisory']) ? $this->config->parameters['allow_advisory'] : 0;
+		$wishlist->allow_advisory = $this->config->get('allow_advisory') ? $this->config->get('allow_advisory') : 0;
 
 		$view = new JView( array('name'=>'settings') );
 		$view->title = $this->_title;
@@ -1004,10 +1047,18 @@ class WishlistController extends JObject
 		if ($old->pagetext != $page->pagetext or (!$create_revision && $pageid)) {
 				
 			// Transform the wikitext to HTML
-			ximport('wiki.parser');
-			$p = new WikiParser( $objWish->id, $this->_option, 'wishlist'.DS.$wishlist->id, $objWish->id );
-			$page->pagehtml = $p->parse( $page->pagetext );
-				
+			$wikiconfig = array(
+				'option'   => $this->_option,
+				'scope'    => 'wishlist'.DS.$wishlist->id,
+				'pagename' => $objWish->id,
+				'pageid'   => $objWish->id,
+				'filepath' => '',
+				'domain'   => '' 
+			);
+			ximport('Hubzero_Wiki_Parser');
+			$p =& Hubzero_Wiki_Parser::getInstance();
+			$page->pagehtml = $p->parse($page->pagetext, $wikiconfig);
+			
 			// Store content
 			if (!$page->store()) {
 				JError::raiseError( 500, $page->getError() );
@@ -1040,7 +1091,7 @@ class WishlistController extends JObject
 		
 		else if ($new_assignee) {
 				// Build e-mail components
-				$xhub =& XFactory::getHub();
+				$xhub =& Hubzero_Factory::getHub();
 				$jconfig =& JFactory::getConfig();
 				$admin_email = $jconfig->getValue('config.mailfrom');
 									
@@ -1053,7 +1104,7 @@ class WishlistController extends JObject
 					
 				$name = JText::_('UNKNOWN');
 				$login = JText::_('UNKNOWN');
-				$ruser =& XProfile::getInstance($objWish->proposed_by);
+				$ruser =& Hubzero_User_Profile::getInstance($objWish->proposed_by);
 				if (is_object($ruser)) {
 					$name = $ruser->get('name');
 					$login = $ruser->get('username');
@@ -1193,7 +1244,7 @@ class WishlistController extends JObject
 		// Is banking turned on?
 		$funds = 0;
 		if ($this->banking) {
-			$BTL = new BankTeller( $database, $juser->get('id') );
+			$BTL = new Hubzero_Bank_Teller( $database, $juser->get('id') );
 			$balance = $BTL->summary();
 			$credit  = $BTL->credit_summary();
 			$funds   = $balance - $credit;			
@@ -1247,12 +1298,20 @@ class WishlistController extends JObject
 			return;
 		}
 		
+		// Get wish list info
+		$objWishlist = new Wishlist ( $database );			
+		$wishlist = $objWishlist->get_wishlist($listid);
+		
 		// trim and addslashes all posted items
 		$_POST = array_map('trim',$_POST);
 		
 		// initiate class and bind posted items to database fields
 		$row = new Wish ( $database );
-		if (!$row->bind( $_POST )) {
+		if( !JRequest::getVar( 'subject', '')) {
+			$this->setError( JText::_('WISHLIST_ERROR_NO_SUBJECT') );
+			$row->bind( $_POST );
+		}
+		else if (!$row->bind( $_POST )) {
 			JError::raiseError( 500, $row->getError() );
 			return;
 		}
@@ -1284,24 +1343,38 @@ class WishlistController extends JObject
 		// Error view
 		if($this->getError()) {
 			// Set the pathway
-			$app =& JFactory::getApplication();
-			$pathway =& $app->getPathway();
-			if (count($pathway->getPathWay()) <= 0) {
-				$pathway->addItem(JText::_(strtoupper($this->_name)),'index.php?option='.$this->_option);
-			}
-				
-			$view = new JView( array('name'=>'error') );
+			$this->_taskpath = $wishid 
+			? 'index.php?option='.$this->_option.a.'task=editwish'.a.'category='.$wishlist->category.a.'rid='.$wishlist->referenceid.a.'wishid='.$wishid
+			: 'index.php?option='.$this->_option.a.'task=add'.a.'category='.$wishlist->category.a.'rid='.$wishlist->referenceid;
+			$this->_taskname = $wishid
+								? JText::_('COM_WISHLIST_EDITWISH')
+								: JText::_('COM_WISHLIST_ADD');
+			$this->_buildPathway($wishlist);
+			
+			// Get URL to page explaining virtual economy
+			$aconfig =& JComponentHelper::getParams( 'com_answers' );
+			$infolink = $aconfig->get('infolink') ? $aconfig->get('infolink') : '/kb/points/';
+			
+			$view = new JView( array('name'=>'editwish' ));
 			$view->title = JText::_(strtoupper($this->_name));
-			if ($this->getError()) {
-				$view->setError( $this->getError() );
-			}
+			$view->config = $this->config;
+			$view->option = $this->_option;
+			$view->task = $this->_task;
+			$view->admin = $this->_admin;
+			$view->juser = $juser;
+			$view->wishlist = $wishlist;
+			$view->wish = $row;
+			$view->infolink = $infolink;
+			$view->funds = $funds;
+			$view->banking = $this->banking;
+			$view->setError( $this->getError() );
 			$view->display();
-			return;				
+			return;			
 		}
 				
 		$row->anonymous 	= JRequest::getInt( 'anonymous', 0 );
 		$row->private	    = JRequest::getInt( 'private', 0 );
-		$row->about     	= TextFilter::cleanXss($row->about);
+		$row->about     	= Hubzero_Filter::cleanXss($row->about);
 		$row->proposed    	= ($wishid) ? $row->proposed : date( 'Y-m-d H:i:s', time() );
 
 		// check content
@@ -1325,15 +1398,11 @@ class WishlistController extends JObject
 		// Add/change the tags
 		$tagging = new WishTags( $database );
 		$tagging->tag_object($juser->get('id'), $row->id, $tags, 1, 1);
-
-		// Get wish list info
-		$objWishlist = new Wishlist ( $database );			
-		$wishlist = $objWishlist->get_wishlist($listid);
 			
 		// send message about a new wish
 		if(!$wishid) {
 			// Build e-mail components
-			$xhub =& XFactory::getHub();
+			$xhub =& Hubzero_Factory::getHub();
 			$jconfig =& JFactory::getConfig();
 			$admin_email = $jconfig->getValue('config.mailfrom');
 					
@@ -1382,7 +1451,7 @@ class WishlistController extends JObject
 	
 		if($reward && $this->banking) {		
 			// put the  amount on hold
-			$BTL = new BankTeller( $database, $juser->get('id') );
+			$BTL = new Hubzero_Bank_Teller( $database, $juser->get('id') );
 			$BTL->hold($reward, JText::_('BANKING_HOLD').' #'.$row->id.' '.JText::_('FOR').' '.$wishlist->title, 'wish', $row->id);
 		}
 					
@@ -1501,7 +1570,7 @@ class WishlistController extends JObject
 				
 				if($changed) {
 					// Build e-mail components
-					$xhub =& XFactory::getHub();
+					$xhub =& Hubzero_Factory::getHub();
 					$jconfig =& JFactory::getConfig();
 					$admin_email = $jconfig->getValue('config.mailfrom');
 					
@@ -1517,7 +1586,7 @@ class WishlistController extends JObject
 					
 					$name = JText::_('UNKNOWN');
 					$login = JText::_('UNKNOWN');
-					$ruser =& XProfile::getInstance($objWish->proposed_by);
+					$ruser =& Hubzero_User_Profile::getInstance($objWish->proposed_by);
 					if (is_object($ruser)) {
 						$name = $ruser->get('name');
 						$login = $ruser->get('username');
@@ -1637,9 +1706,8 @@ class WishlistController extends JObject
 			
 			// Get group id from cn
 			if($category == 'group') {
-				$group = new XGroup();
 				if(Hubzero_Group::exists($cn)) {
-					$group->select($cn);
+					$group = Hubzero_Group::getInstance($cn);
 					$refid = $group->gidNumber;
 				}
 				else {
@@ -1668,8 +1736,7 @@ class WishlistController extends JObject
 			else if($category == 'group' && !$newlist) {			
 				// create private list for group
 				if(Hubzero_Group::exists($refid)) {
-					$group = new XGroup();
-					$group->select($refid);	
+					$group = Hubzero_Group::getInstance($refid);
 					$newlist = $obj->createlist($cat, $refid, 0, $group->cn.' '.JText::_('GROUP'));
 				}				
 			}
@@ -1709,7 +1776,7 @@ class WishlistController extends JObject
 					}
 					// delete comments if option chosen
 					if(!$options['keepcomments']) {						
-						$reply = new XComment( $database );
+						$reply = new Hubzero_Comment( $database );
 						$comments1 = $reply->getResults( array('id'=>$wishid, 'category'=>'wish') );
 						if (count($comments1) > 0) {
 							foreach ($comments1 as $comment1) 
@@ -1741,7 +1808,7 @@ class WishlistController extends JObject
 					}
 					
 					// send message about transferred wish
-					$xhub =& XFactory::getHub();
+					$xhub =& Hubzero_Factory::getHub();
 					$jconfig =& JFactory::getConfig();
 					$admin_email = $jconfig->getValue('config.mailfrom');
 					
@@ -1750,7 +1817,7 @@ class WishlistController extends JObject
 					
 					$name = JText::_('UNKNOWN');
 					$login = JText::_('UNKNOWN');
-					$ruser =& XProfile::getInstance($objWish->proposed_by);
+					$ruser =& Hubzero_User_Profile::getInstance($objWish->proposed_by);
 					if (is_object($ruser)) {
 						$name = $ruser->get('name');
 						$login = $ruser->get('username');
@@ -1852,7 +1919,7 @@ class WishlistController extends JObject
 		}	
 		
 		// check available user funds		
-		$BTL 		= new BankTeller( $database, $juser->get('id') );
+		$BTL 		= new Hubzero_Bank_Teller( $database, $juser->get('id') );
 		$balance 	= $BTL->summary();
 		$credit 	= $BTL->credit_summary();
 		$funds 		= $balance - $credit;			
@@ -1873,7 +1940,7 @@ class WishlistController extends JObject
 		}
 		
 		// put the  amount on hold
-		$BTL = new BankTeller( $database, $juser->get('id') );
+		$BTL = new Hubzero_Bank_Teller( $database, $juser->get('id') );
 		$BTL->hold($amount, JText::_('BANKING_HOLD').' #'.$wishid.' '.JText::_('FOR').' '.$wishlist->title, 'wish', $wishid);
 			
 		$this->_redirect = JRoute::_('index.php?option='.$this->_option.a.'task=wish'.a.'category='.$wishlist->category.a.'rid='.$wishlist->referenceid.a.'wishid='.$wishid);
@@ -2106,7 +2173,7 @@ class WishlistController extends JObject
 		$co_reg = 0.2;	
 				
 		// do we give more weight to votes coming from advisory committee?
-		$votesplit = isset($this->config->parameters['votesplit']) ? trim($this->config->parameters['votesplit']) : 0;	
+		$votesplit = $this->config->get('votesplit') ? $this->config->get('votesplit')  : 0;	
 		
 		if($wishlist->items) {
 			
@@ -2264,7 +2331,7 @@ class WishlistController extends JObject
 		}
 		
 		if ($id && $category) {
-			$row = new XComment( $database );
+			$row = new Hubzero_Comment( $database );
 			if (!$row->bind( $_POST )) {
 				JError::raiseError( 500, $row->getError() );
 				return;
@@ -2299,13 +2366,13 @@ class WishlistController extends JObject
 				$objWish->load($wishid);
 							
 				// Build e-mail components
-				$xhub =& XFactory::getHub();
+				$xhub =& Hubzero_Factory::getHub();
 				$jconfig =& JFactory::getConfig();
 				$admin_email = $jconfig->getValue('config.mailfrom');
 					
 				$name = JText::_('UNKNOWN');
 				$login = JText::_('UNKNOWN');
-				$ruser =& XProfile::getInstance($row->added_by);
+				$ruser =& Hubzero_User_Profile::getInstance($row->added_by);
 				if (is_object($ruser)) {
 					$name = $ruser->get('name');
 					$login = $ruser->get('username');
@@ -2340,13 +2407,13 @@ class WishlistController extends JObject
 				$subject4 = JText::_(strtoupper($this->_name)).', '.$name.' '.JText::_('MSG_COMMENTED_AFTER_YOU').' #'.$wishid;
 				
 					
-				$message  = JText::_('WISH').' #'.$row->id.', '.$wishlist->title.' '.JText::_('WISHLIST').r.n;
+				$message  = JText::_('WISH').' #'.$wishid.', '.$wishlist->title.' '.JText::_('WISHLIST').r.n;
 				$message .= JText::_('WISH_DETAILS_SUMMARY').': '.stripslashes($objWish->subject).r.n;
 				$message .= '----------------------------'.r.n;
 				$message .= JText::_('MSG_COMMENT_BY').' '.$name.' ';
 				$message .= $row->anonymous ? '' : '('.$login.')';
 				$message .= ' '.JText::_('MSG_POSTED_ON').' '.JHTML::_('date',$row->added, '%d %b, %Y').':'.r.n;
-				$message .= $attach->parse($row->comment).r.n.r.n;
+				$message .= $attach->parse( Hubzero_View_Helper_Html::purifyText($row->comment)).r.n.r.n;
 				$message .= r.n;
 					
 					
@@ -2384,7 +2451,7 @@ class WishlistController extends JObject
 				
 				// get comment author if reply is posted to a comment
 				if($category=='wishcomment') {
-					$parent = new XComment( $database );
+					$parent = new Hubzero_Comment( $database );
 					$parent->load($id);
 					$cuser =& JUser::getInstance($parent->added_by);
 					
@@ -2415,6 +2482,42 @@ class WishlistController extends JObject
 		$this->_redirect = JRoute::_('index.php?option='.$this->_option.a.'task=wish'.a.'category='.$wishlist->category.a.'rid='.$wishlist->referenceid.a.'wishid='.$wishid);
 	}
 	
+	//----------------
+	
+	public function deletereply()
+	{
+		$database =& JFactory::getDBO();
+		$juser 	  =& JFactory::getUser();
+		
+		// Incoming
+		$replyid = JRequest::getInt( 'replyid', 0 );
+		
+		$row = new Hubzero_Comment( $database );
+		
+		// Do we have a reply ID?
+		if (!$replyid or !$row->load($replyid)) {
+			$this->setError( JText::_('ERROR_REPLY_NOT_FOUND') );
+			return;
+		}
+		if($row->added_by == $juser->get('id')) {
+			// Delete the comment
+			$row->state = 4;
+			
+			if (!$row->store()) {
+				JError::raiseError( 500, $row->getError() );
+				return;
+			}			
+		}
+		else {
+			$this->setError( JText::_('ERROR_CANNOT_DELETE_REPLY') );
+			return;
+		}
+			
+		// Go back to the page
+		$referer = JRequest::getVar( 'HTTP_REFERER', NULL, 'server' ); // What page they came from
+		$this->_redirect = $referer;
+	}
+	
 	//-----------
 	
 	public function reply()
@@ -2553,7 +2656,7 @@ class WishlistController extends JObject
 	
 	public function getWebPath($wishid=0)
 	{
-		$webpath = isset($this->config->parameters['webpath']) ? $this->config->parameters['webpath'] : 'site/wishes';
+		$webpath = $this->config->get('webpath')  ? $this->config->get('webpath')  : 'site/wishes';
 		
 		$webpath .= $wishid ? DS.$wishid : '';
 		
@@ -2585,7 +2688,7 @@ class WishlistController extends JObject
 			$juser =& JFactory::getUser();
 			
 			$level++;
-			$hc = new XComment( $database );
+			$hc = new Hubzero_Comment( $database );
 			$authors = array();
 			
 			$comments = $hc->getResults( array('id'=>$itemid, 'category'=>$category), 1 , 1 );
@@ -2593,7 +2696,7 @@ class WishlistController extends JObject
 			if ($comments) {
 			
 				// Parse comment text for attachment tags
-				$xhub =& XFactory::getHub();
+				$xhub =& Hubzero_Factory::getHub();
 				
 				if(!$skipattachments) {
 				$webpath = $this->getWebPath($parentid);
@@ -2677,7 +2780,7 @@ class WishlistController extends JObject
 		}
 		
 		if($listid) {
-			$admingroup = isset($this->config->parameters['group']) ? trim($this->config->parameters['group']) : 'hubadmin';
+			$admingroup = $this->config->get('group')  ? trim($this->config->get('group', 'hubadmin') ) : 'hubadmin';
 			
 			// Get list administrators
 			$database =& JFactory::getDBO();
