@@ -1,25 +1,29 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Shawn Rice <zooley@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Shawn Rice <zooley@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
@@ -51,10 +55,10 @@ defined('_JEXEC') or die( 'Restricted access' );
 				$name = $item->authorname;
 			}
 			
-			$assigned = ($item->assigned && ($admin==2 or $admin==1)) ? JText::_('assigned to').' <a href="'.JRoute::_('index.php?option='.$option.a.'task=wish'.a.'category='.$wishlist->category.a.'rid='.$wishlist->referenceid.a.'wishid='.$item->id).'?filterby='.$filters['filterby'].a.'action=editplan#plan">'.$item->assignedto.'</a>' : '';	
+			$assigned = ($item->assigned && ($admin==2 or $admin==1)) ? JText::_('assigned to').' <a href="'.JRoute::_('index.php?option='.$option.a.'task=wish'.a.'category='.$wishlist->category.a.'rid='.$wishlist->referenceid.a.'wishid='.$item->id).'?filterby='.$filters['filterby'].a.'sortby='.$filters['sortby'].a.'tags='.$filters['tag'].a.'action=editplan#plan">'.$item->assignedto.'</a>' : '';	
 			
 			if(!$assigned && ($admin==2 or $admin==1) && $item->status==0) {
-			$assigned = '<a href="'.JRoute::_('index.php?option='.$option.a.'task=wish'.a.'category='.$wishlist->category.a.'rid='.$wishlist->referenceid.a.'wishid='.$item->id).'?filterby='.$filters['filterby'].a.'action=editplan#plan">'.JText::_('unassigned').'</a>';
+			$assigned = '<a href="'.JRoute::_('index.php?option='.$option.a.'task=wish'.a.'category='.$wishlist->category.a.'rid='.$wishlist->referenceid.a.'wishid='.$item->id).'?filterby='.$filters['filterby'].a.'sortby='.$filters['sortby'].a.'tags='.$filters['tag'].a.'action=editplan#plan">'.JText::_('unassigned').'</a>';
 			}
 				
 			$item->status = ($item->accepted==1 && $item->status==0) ? 6 : $item->status;
@@ -111,16 +115,16 @@ defined('_JEXEC') or die( 'Restricted access' );
 				$html .= t.'<ul id="useroptions">'.n;				
 				$html .= t.t.'<li>'.n;
 				if($item->prev) {
-					$html .= t.t.t.'<a href="index.php?option='.$option.a.'task=wish'.a.'category='.$wishlist->category.a.'rid='.$wishlist->referenceid.a.'wishid='.$item->prev.a.'filterby='.$filters['filterby'].'"><span>&lsaquo; '.JText::_('PREV').'</span></a>'.n;
+					$html .= t.t.t.'<a href="index.php?option='.$option.a.'task=wish'.a.'category='.$wishlist->category.a.'rid='.$wishlist->referenceid.a.'wishid='.$item->prev.a.'filterby='.$filters['filterby'].a.'sortby='.$filters['sortby'].a.'tags='.$filters['tag'].'"><span>&lsaquo; '.JText::_('PREV').'</span></a>'.n;
 				} else {
 					$html .=t.t.t.'<span>&lsaquo; '.JText::_('PREV').'</span>'.n;
 				}
 				$html .= t.t.'</li>'.n;
 				
-				$html .= t.t.'<li><a href="'.JRoute::_('index.php?option='.$option.a.'task=wishlist'.a.'category='.$wishlist->category.a.'rid='.$wishlist->referenceid.a.'filterby='.$filters['filterby']).'" ><span>'.JText::_('All').'</span></a></li>'.n;
+				$html .= t.t.'<li><a href="'.JRoute::_('index.php?option='.$option.a.'task=wishlist'.a.'category='.$wishlist->category.a.'rid='.$wishlist->referenceid.a.'filterby='.$filters['filterby'].a.'sortby='.$filters['sortby'].a.'tags='.$filters['tag']).'" ><span>'.JText::_('All').'</span></a></li>'.n;
 				$html .= t.t.'<li class="last">';
 				if($item->next) {
-					$html .= t.t.t.'<a href="index.php?option='.$option.a.'task=wish'.a.'category='.$wishlist->category.a.'rid='.$wishlist->referenceid.a.'wishid='.$item->next.a.'filterby='.$filters['filterby'].'"><span>'.JText::_('NEXT').' &rsaquo;</span></a>'.n;
+					$html .= t.t.t.'<a href="index.php?option='.$option.a.'task=wish'.a.'category='.$wishlist->category.a.'rid='.$wishlist->referenceid.a.'wishid='.$item->next.a.'filterby='.$filters['filterby'].a.'sortby='.$filters['sortby'].a.'tags='.$filters['tag'].'"><span>'.JText::_('NEXT').' &rsaquo;</span></a>'.n;
 				}
 				else {
 					$html .=t.t.t.'<span>'.JText::_('NEXT').' &rsaquo; </span>'.n;
@@ -182,6 +186,7 @@ defined('_JEXEC') or die( 'Restricted access' );
 						$item->about = trim(stripslashes($item->about));
 						$item->about = preg_replace('/<br\\s*?\/??>/i', "", $item->about);
 						$item->about = htmlspecialchars(WishlistHtml::txt_unpee($item->about));
+						$item->about = str_replace("\n",'<br />',$item->about);
 						$html .= t.t.t.'<p>'.$item->about.'</p>'.n;
 					}
 				
@@ -521,9 +526,9 @@ defined('_JEXEC') or die( 'Restricted access' );
 							$html .= t.t.t.'	  <label>'.n;
 						
 							$document =& JFactory::getDocument();
-							$document->addScript('components'.DS.'com_support'.DS.'observer.js');
+							$document->addScript('components'.DS.'com_wishlist'.DS.'observer.js');
 							$document->addScript('components'.DS.'com_wishlist'.DS.'autocompleter.js');
-							$document->addStyleSheet('components'.DS.'com_support'.DS.'autocompleter.css');
+							$document->addStyleSheet('components'.DS.'com_wishlist'.DS.'autocompleter.css');
 						
 							$html .= t.t.t.'<input type="text" name="group" value="';
 							if($wishlist->category=='group') {
@@ -602,25 +607,30 @@ defined('_JEXEC') or die( 'Restricted access' );
 							foreach ($item->replies as $reply) 
 							{
 								$o = ($o == 'odd') ? 'even' : 'odd';
-		
-								// Comment
-								$html .= '<li class="comment '.$o;
-								if ($this->abuse && $reply->reports > 0) {
-									$html .= ' abusive';
+								if($reply->state==4) {
+									// comment removed by author
+									$html .= '<li class="comment '.$o.' comment-removed">'.JText::_('COMMENT_REMOVED_BY_AUTHOR');
+								}
+								else {
+									// Comment
+									$html .= '<li class="comment '.$o;
+									if ($this->abuse && $reply->reports > 0) {
+										$html .= ' abusive';
+									}
+									$html .= '" id="c'.$reply->id.'r">';
+			
+									$view = new JView( array('name'=>'wish', 'layout'=>'comment') );
+									$view->option = $option;
+									$view->reply = $reply;
+									$view->juser = $juser;
+									$view->listid = $wishlist->id;
+									$view->wishid = $item->id;
+									$view->wishauthor = $item->proposed_by;
+									$view->level = 1;
+									$view->abuse = $abuse;
+									$view->addcomment = $addcomment;
+									$html .= $view->loadTemplate();
 								}
-								$html .= '" id="c'.$reply->id.'r">';
-		
-								$view = new JView( array('name'=>'wish', 'layout'=>'comment') );
-								$view->option = $option;
-								$view->reply = $reply;
-								$view->juser = $juser;
-								$view->listid = $wishlist->id;
-								$view->wishid = $item->id;
-								$view->wishauthor = $item->proposed_by;
-								$view->level = 1;
-								$view->abuse = $abuse;
-								$view->addcomment = $addcomment;
-								$html .= $view->loadTemplate();
 								
 								// Another level? 
 								if (count($reply->replies) > 0) {
@@ -628,24 +638,29 @@ defined('_JEXEC') or die( 'Restricted access' );
 									foreach ($reply->replies as $r) 
 									{
 										$o = ($o == 'odd') ? 'even' : 'odd';
-		
-										$html .= '<li class="comment '.$o;
-										if ($this->abuse && $r->reports > 0) {
-											$html .= ' abusive';
+										if($r->state==4) {
+											// comment removed by author
+											$html .= '<li class="comment '.$o.' comment-removed">'.JText::_('COMMENT_REMOVED_BY_AUTHOR');
+										}
+										else {
+											$html .= '<li class="comment '.$o;
+											if ($this->abuse && $r->reports > 0) {
+												$html .= ' abusive';
+											}
+											$html .= '" id="c'.$r->id.'r">';
+											
+											$view = new JView( array('name'=>'wish', 'layout'=>'comment') );
+											$view->option = $option;
+											$view->reply = $r;
+											$view->juser = $juser;
+											$view->listid = $wishlist->id;
+											$view->wishid = $item->id;
+											$view->wishauthor = $item->proposed_by;
+											$view->level = 2;
+											$view->abuse = $abuse;
+											$view->addcomment = $addcomment;
+											$html .= $view->loadTemplate();
 										}
-										$html .= '" id="c'.$r->id.'r">';
-										
-										$view = new JView( array('name'=>'wish', 'layout'=>'comment') );
-										$view->option = $option;
-										$view->reply = $r;
-										$view->juser = $juser;
-										$view->listid = $wishlist->id;
-										$view->wishid = $item->id;
-										$view->wishauthor = $item->proposed_by;
-										$view->level = 2;
-										$view->abuse = $abuse;
-										$view->addcomment = $addcomment;
-										$html .= $view->loadTemplate();
 		
 										// Yet another level?? 
 										if (count($r->replies) > 0) {
@@ -653,24 +668,30 @@ defined('_JEXEC') or die( 'Restricted access' );
 											foreach ($r->replies as $rr) 
 											{
 												$o = ($o == 'odd') ? 'even' : 'odd';
-		
-												$html .= t.'<li class="comment '.$o;
-												if ($this->abuse && $rr->reports > 0) {
-													$html .= ' abusive';
+												if($rr->state==4) {
+													// comment removed by author
+													$html .= '<li class="comment '.$o.' comment-removed">'.JText::_('COMMENT_REMOVED_BY_AUTHOR');
+													$html .= '</li>';
+												}
+												else {
+													$html .= t.'<li class="comment '.$o;
+													if ($this->abuse && $rr->reports > 0) {
+														$html .= ' abusive';
+													}
+													$html .= '" id="c'.$rr->id.'r">';
+													$view = new JView( array('name'=>'wish', 'layout'=>'comment') );
+													$view->option = $option;
+													$view->reply = $rr;
+													$view->juser = $juser;
+													$view->listid = $wishlist->id;
+													$view->wishid = $item->id;
+													$view->wishauthor = $item->proposed_by;
+													$view->level = 3;
+													$view->abuse = $abuse;
+													$view->addcomment = $addcomment;
+													$html .= $view->loadTemplate();
+													$html .= '</li>';
 												}
-												$html .= '" id="c'.$rr->id.'r">';
-												$view = new JView( array('name'=>'wish', 'layout'=>'comment') );
-												$view->option = $option;
-												$view->reply = $rr;
-												$view->juser = $juser;
-												$view->listid = $wishlist->id;
-												$view->wishid = $item->id;
-												$view->wishauthor = $item->proposed_by;
-												$view->level = 3;
-												$view->abuse = $abuse;
-												$view->addcomment = $addcomment;
-												$html .= $view->loadTemplate();
-												$html .= '</li>';
 											}
 											$html .= '</ol><!-- end pass4 -->';
 										}
@@ -796,9 +817,19 @@ defined('_JEXEC') or die( 'Restricted access' );
 							
 							$html .=t.t.t.'<div class="planbody">'.n;
 							$html .=t.t.t.'<p class="plannote">'.JText::_('PLAN_LAST_EDIT').' '.JHTML::_('date', $plan->created, '%d %b %Y').' at '.JHTML::_('date',$plan->created, '%I:%M %p').' '.JText::_('by').' '.$plan->authorname.'</p>'.n;
-							ximport('wiki.parser');
-							$p = new WikiParser( $wishlist->title, $option, 'wishlist'.DS.$wishlist->id, 'resources', $wishlist->id);
-							$maintext = $p->parse( n.stripslashes($plan->pagetext) );					
+				
+							$wikiconfig = array(
+								'option'   => $this->_option,
+								'scope'    => 'wishlist'.DS.$wishlist->id,
+								'pagename' => $wishlist->id,
+								'pageid'   => $wishlist->id,
+								'filepath' => '',
+								'domain'   => '' 
+							);
+							ximport('Hubzero_Wiki_Parser');
+							$p =& Hubzero_Wiki_Parser::getInstance();
+							$maintext = $p->parse($plan->pagetext, $wikiconfig);
+							
 							$html .=t.t.t.$maintext.n;
 							$html .=t.t.t.'</div>'.n;
 						}
@@ -816,4 +847,4 @@ defined('_JEXEC') or die( 'Restricted access' );
 		}
 		
 		echo $html;	
-?>
+?>
\ No newline at end of file
