@@ -1,39 +1,43 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Nicholas J. Kisseberth <nkissebe@purdue.edu>
- * @copyright	Copyright 2008-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Nicholas J. Kisseberth <nkissebe@purdue.edu>
+ * @copyright   Copyright 2008-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2008-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2008-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
 
-ximport('xprofile');
+ximport('Hubzero_User_Profile');
 
 $mycount = 0;
 
 function _compareusers($mode = 0)
 {
 	$mycount = 0;
-	$xhub = &XFactory::getHub();
-	$conn = &XFactory::getPLDC();
+	$xhub = &Hubzero_Factory::getHub();
+	$conn = &Hubzero_Factory::getPLDC();
 	$db = &JFactory::getDBO();
 
     $hubLDAPBaseDN = $xhub->getCfg('hubLDAPBaseDN');
@@ -72,7 +76,7 @@ function _compareusers($mode = 0)
 		    continue;
 		}
 
-		$profile = new XProfile();
+		$profile = new Hubzero_User_Profile();
 			
 		$result = $profile->load($attributes['uid'][0]);
 			
@@ -593,8 +597,8 @@ function printuser($name)
 	if ($mycount > 1000)
 		exit();
 
-	$profile = new XProfile();
-	$profile2 = new XProfile();
+	$profile = new Hubzero_User_Profile();
+	$profile2 = new Hubzero_User_Profile();
 
 	$profile->load($name,'ldap');
 	$profile2->load($name,'mysql');
@@ -670,7 +674,7 @@ function printuser($name)
 
 function _showusers() 
 {
-XProfileHelper::iterate_profiles('printuser','ldap');
+Hubzero_User_Profile_Helper::iterate_profiles('printuser','ldap');
 return;
 }
-?>
+?>
\ No newline at end of file
