@@ -1,25 +1,29 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Shawn Rice <zooley@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Shawn Rice <zooley@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
@@ -45,67 +49,39 @@ class plgGroupsMembers extends JPlugin
 	
 	//-----------
 	
-	public function &onGroupAreas( $authorized )
+	public function &onGroupAreas()
 	{
-		/*if (!$authorized) {
-			$areas = array();
-		} else {*/
-			$areas = array(
-				'members' => JText::_('PLG_GROUPS_MEMBERS')
-			);
-		//}
-
-		return $areas;
+		$area = array(
+			'name' => 'members',
+			'title' => JText::_('PLG_GROUPS_MEMBERS'),
+			'default_access' => 'members'
+		);
+		
+		return $area;
 	}
 
 	//-----------
 
-	public function onGroup( $group, $option, $authorized, $limit=0, $limitstart=0, $action='', $areas=null )
+	public function onGroup( $group, $option, $authorized, $limit=0, $limitstart=0, $action='', $access, $areas=null )
 	{
 		$return = 'html';
+		$active = 'members';
+		
+		// The output array we're returning
+		$arr = array(
+			'html'=>''
+		);
+		
+	
+		//get this area details
+		$this_area = $this->onGroupAreas();
 		
 		// Check if our area is in the array of areas we want to return results for
 		if (is_array( $areas ) && $limit) {
-			if (!array_intersect( $areas, $this->onGroupAreas( $authorized ) ) 
-			&& !array_intersect( $areas, array_keys( $this->onGroupAreas( $authorized ) ) )) {
-				$return = '';
+			if(!in_array($this_area['name'],$areas)) {
+				return;
 			}
 		}
-
-		// The output array we're returning
-		$arr = array(
-			'html'=>'',
-			'metadata'=>'',
-			'dashboard'=>''
-		);
-
-		$juser =& JFactory::getUser();
-		if ($juser->get('guest')) {
-			if ($return == 'html') {
-				ximport('xmodule');
-				$arr['html']  = '<p class="warning">'. JText::_('GROUPS_LOGIN_NOTICE') . '</p>';
-				$arr['html'] .= XModuleHelper::renderModules('force_mod');
-			}
-			return $arr;
-		}
-		
-		// Return no data if the user is not authorized
-		if (!$authorized || ($authorized != 'admin' && $authorized != 'manager' && $authorized != 'member')) {
-			if ($return == 'html') {
-				$arr['html'] = '<p class="warning">'. JText::_('PLG_GROUPS_MESSAGES_ERROR_NOT_AUTHORIZED') . '</p>';
-			}
-			return $arr;
-		}
-		
-		// Are we on the overview page?
-		if ($areas[0] == 'overview') {
-			$return = 'metadata';
-		}
-		
-		// Do we need to return any data?
-		if ($return != 'html' && $return != 'metadata') {
-			return $arr;
-		}
 		
 		// Set some variables so other functions have access
 		$this->authorized = $authorized;
@@ -116,6 +92,36 @@ class plgGroupsMembers extends JPlugin
 
 		// Only perform the following if this is the active tab/plugin
 		if ($return == 'html') {
+			
+			//set group members plugin access level
+			$group_plugin_acl = $access[$active];
+			
+			//Create user object
+			$juser =& JFactory::getUser();
+		
+			//get the group members
+			$members = $group->get('members');
+
+			//if set to nobody make sure cant access
+			if($group_plugin_acl == 'nobody') {
+				$arr['html'] = "<p class=\"info\">".JText::sprintf('GROUPS_PLUGIN_OFF', ucfirst($active))."</p>";
+				return $arr;
+			}
+			
+			//check if guest and force login if plugin access is registered or members
+			if ($juser->get('guest') && ($group_plugin_acl == 'registered' || $group_plugin_acl == 'members')) {
+				ximport('Hubzero_Module_Helper');
+				$arr['html']  = "<p class=\"warning\">".JText::sprintf('GROUPS_PLUGIN_REGISTERED', ucfirst($active))."</p>";
+				$arr['html'] .= Hubzero_Module_Helper::renderModules('force_mod');
+				return $arr;
+			}
+			
+			//check to see if user is member and plugin access requires members
+			if(!in_array($juser->get('id'),$members) && $group_plugin_acl == 'members' && $authorized != 'admin') {
+				$arr['html'] = "<p class=\"info\">".JText::sprintf('GROUPS_PLUGIN_REQUIRES_MEMBER', ucfirst($active))."</p>";
+				return $arr;
+			}
+			
 			// Set the page title
 			$document =& JFactory::getDocument();
 			$document->setTitle( JText::_(strtoupper($this->_name)).': '.$this->group->description.': '.JText::_('PLG_GROUPS_MEMBERS') );
@@ -124,6 +130,9 @@ class plgGroupsMembers extends JPlugin
 			if (is_file(JPATH_ROOT.DS.'plugins'.DS.'groups'.DS.'members'.DS.'members.js')) {
 				$document->addScript('plugins'.DS.'groups'.DS.'members'.DS.'members.js');
 			}
+			
+			ximport('Hubzero_Document');
+			Hubzero_Document::addPluginStylesheet('groups', 'members');
 
 			// Do we need to perform any actions?
 			if ($action) {
@@ -150,19 +159,38 @@ class plgGroupsMembers extends JPlugin
 						'name'=>'browse'
 					)
 				);
+				
 				$view->option = $option;
 				$view->group = $group;
 				$view->authorized = $authorized;
 				
 				$view->q = JRequest::getVar('q', '');
 				$view->filter = JRequest::getVar('filter', '');
+				$view->role_filter = JRequest::getVar('role_filter','');
+				
 				if ($view->authorized != 'manager' && $view->authorized != 'admin') {
 					$view->filter = ($view->filter == 'managers') ? $view->filter : 'members';
 				}
+				
+				//get messages plugin access level
+				$view->messages_acl = $group->getPluginAccess($group,'messages');
+				
+				//get all member roles
+				$db =& JFactory::getDBO();
+				$sql = "SELECT * FROM #__xgroups_roles WHERE gidNumber='".$group->get('gidNumber')."'";
+				$db->setQuery($sql);
+				$view->member_roles = $db->loadAssocList(); 
+				
+				$group_inviteemails = new Hubzero_Group_Invite_Email($this->database);
+				$view->current_inviteemails = $group_inviteemails->getInviteEmails($this->group->get('gidNumber'), true);
+				
 				switch ($view->filter) 
 				{
 					case 'invitees':
 						$view->groupusers = ($view->q) ? $group->search('invitees', $view->q) : $group->get('invitees');
+						foreach($view->current_inviteemails as $ie) {
+							$view->groupusers[] = $ie;
+						}
 						$view->managers = array();
 					break;
 					case 'pending':
@@ -171,17 +199,20 @@ class plgGroupsMembers extends JPlugin
 					break;
 					case 'managers':
 						$view->groupusers  = ($view->q) ? $group->search('managers', $view->q) : $group->get('managers');
+						$view->groupusers = ($view->role_filter) ? $group->search_roles($view->role_filter) : $view->groupusers;
 						$view->managers = $group->get('managers');
 					break;
 					case 'members':
 					default:
 						$view->groupusers = ($view->q) ? $group->search('members', $view->q) : $group->get('members');
+						$view->groupusers = ($view->role_filter) ? $group->search_roles($view->role_filter) : $view->groupusers;
 						$view->managers = $group->get('managers');
 					break;
 				}
 				
 				$view->limit = JRequest::getInt('limit', 25);
 				$view->start = JRequest::getInt('limitstart', 0);
+				$view->start = ($view->limit == 0) ? 0 : $view->start;
 				$view->no_html = JRequest::getInt( 'no_html', 0 );
 				
 				// Initiate paging
@@ -300,7 +331,7 @@ class plgGroupsMembers extends JPlugin
 				
 				// Remove record of reason wanting to join group
 				$reason = new GroupsReason( $database );
-				$reason->deleteReason( $targetuser->get('username'), $this->group->get('cn') );
+				$reason->deleteReason( $targetuser->get('id'), $this->group->get('gidNumber') );
 					
 				// Are they approved for membership?
 				$admchange .= "\t\t".$targetuser->get('name')."\r\n";
@@ -631,7 +662,7 @@ class plgGroupsMembers extends JPlugin
 			return false;
 		}
 		
-		$xhub = XFactory::getHub();
+		$xhub = Hubzero_Factory::getHub();
 		$xhub->redirect( JRoute::_('index.php?option=com_groups&gid='.$this->group->get('cn').'&task=invite&return=members') );
 	}
 
@@ -701,7 +732,7 @@ class plgGroupsMembers extends JPlugin
 				
 				// Remove record of reason wanting to join group
 				$reason = new GroupsReason( $database );
-				$reason->deleteReason( $targetuser->get('username'), $this->group->get('cn') );
+				$reason->deleteReason( $targetuser->get('id'), $this->group->get('gidNumber') );
 
 				// Add them to the array of users to deny
 				$users[] = $targetuser->get('id');
@@ -784,6 +815,7 @@ class plgGroupsMembers extends JPlugin
 		
 		// An array for the users we're going to deny
 		$users = array();
+		$user_emails = array();
 		
 		// Incoming array of users to demote
 		$mbrs = JRequest::getVar( 'users', array(0), 'post' );
@@ -793,22 +825,28 @@ class plgGroupsMembers extends JPlugin
 
 		foreach ($mbrs as $mbr)
 		{
-			// Retrieve user's account info
-			$targetuser =& JUser::getInstance($mbr);
+			//if an email address
+			if(eregi("^[_\.\%0-9a-zA-Z-]+@([0-9a-zA-Z-]+\.)+[a-zA-Z]{2,6}$", $mbr)) {
+				$user_emails[] = $mbr;
+				$this->notifyEmailInvitedUser($mbr);
+			} else {	
+				// Retrieve user's account info
+				$targetuser =& JUser::getInstance($mbr);
 				
-			// Ensure we found an account
-			if (is_object($targetuser)) {
-				$admchange .= "\t\t".$targetuser->get('name')."\r\n";
-				$admchange .= "\t\t".$targetuser->get('username') .' ('. $targetuser->get('email') .')';
-				$admchange .= (count($mbrs) > 1) ? "\r\n" : '';
+				// Ensure we found an account
+				if (is_object($targetuser)) {
+					$admchange .= "\t\t".$targetuser->get('name')."\r\n";
+					$admchange .= "\t\t".$targetuser->get('username') .' ('. $targetuser->get('email') .')';
+					$admchange .= (count($mbrs) > 1) ? "\r\n" : '';
 				
-				// Add them to the array of users to cancel invitations
-				$users[] = $targetuser->get('id');
+					// Add them to the array of users to cancel invitations
+					$users[] = $targetuser->get('id');
 				
-				// E-mail the user, letting them know the invitation has been cancelled
-				$this->notifyUser( $targetuser );
-			} else {
-				$this->setError( JText::_('PLG_GROUPS_MESSAGES_ERROR_USER_NOTFOUND').' '.$mbr );
+					// E-mail the user, letting them know the invitation has been cancelled
+					$this->notifyUser( $targetuser );
+				} else {
+					$this->setError( JText::_('PLG_GROUPS_MESSAGES_ERROR_USER_NOTFOUND').' '.$mbr );
+				}
 			}
 		}
 
@@ -817,6 +855,14 @@ class plgGroupsMembers extends JPlugin
 
 		// Save changes
 		$this->group->update();
+		
+		//delete any email invited users
+		$db =& JFactory::getDBO();
+		foreach($user_emails as $ue) {
+			$sql = "DELETE FROM #__xgroups_inviteemails WHERE email=".$db->quote($ue);
+			$db->setQuery($sql);
+			$db->query();
+		}
 
 		// Log the changes
 		$juser =& JFactory::getUser();
@@ -832,6 +878,19 @@ class plgGroupsMembers extends JPlugin
 				$this->setError( $log->getError() );
 			}
 		}
+		
+		foreach ($user_emails as $user) 
+		{
+			$log = new XGroupLog( $database );
+			$log->gid = $this->group->get('gidNumber');
+			$log->uid = $user;
+			$log->timestamp = date( 'Y-m-d H:i:s', time() );
+			$log->action = 'membership_invite_cancelled';
+			$log->actorid = $juser->get('id');
+			if (!$log->store()) {
+				$this->setError( $log->getError() );
+			}
+		}
 
 		// Notify the site administrator?
 		if (count($users) > 0) {
@@ -839,6 +898,151 @@ class plgGroupsMembers extends JPlugin
 		}
 	}
 	
+	
+	/* Member Roles */
+	private function addrole()
+	{
+		$role = JRequest::getVar('role', '');
+		$gid = JRequest::getVar('gid', '');
+		
+		if(!$role || !$gid) {
+			return false;
+		}
+		
+		$db = JFactory::getDBO();
+		$sql = "INSERT INTO #__xgroups_roles(gidNumber,role) VALUES('".$gid."','".$role."')";
+		$db->setQuery($sql);
+		if(!$db->query()) {
+			$this->setError('An error occurred while trying to add the member role. Please try again.');
+		}
+		
+		$xhub = Hubzero_Factory::getHub();
+		$xhub->redirect( JRoute::_('index.php?option=com_groups&gid='.$this->group->get('cn').'&active=members') );
+	}
+	
+	//------
+	
+	private function removerole()
+	{
+		$role = JRequest::getVar('role','');
+		
+		if(!$role) {
+			return false;
+		}
+		
+		$db =& JFactory::getDBO();
+		$sql = "DELETE FROM #__xgroups_member_roles WHERE role='".$role."'";
+		$db->setQuery($sql);
+		$db->query();
+		
+		$sql = "DELETE FROM #__xgroups_roles WHERE id='".$role."'";
+		$db->setQuery($sql);
+		$db->query();
+		
+		if(!$db->query()) {
+			$this->setError('An error occurred while trying to remove the member role. Please try again.');
+		}
+		
+		$xhub = Hubzero_Factory::getHub();
+		$xhub->redirect( JRoute::_('index.php?option=com_groups&gid='.$this->group->get('cn').'&active=members') );
+	}
+	
+	//-----
+	
+	private function assignrole()
+	{
+		if ($this->authorized != 'manager' && $this->authorized != 'admin') {
+			return false;
+		}
+		
+		$uid = JRequest::getVar('uid','');
+		if(!$uid) {
+			return false;
+		}
+
+		// Set the page title
+		$document =& JFactory::getDocument();
+		$document->setTitle( JText::_(strtoupper($this->_name)).': '.$this->group->get('description').': '.JText::_(strtoupper($this->action)) );
+		
+		// Cancel membership confirmation screen
+		ximport('Hubzero_Plugin_View');
+		$view = new Hubzero_Plugin_View(
+			array(
+				'folder'=>'groups',
+				'element'=>'members',
+				'name'=>'assignrole'
+			)
+		);
+		
+		$db =& JFactory::getDBO();
+		$sql = "SELECT * FROM #__xgroups_roles WHERE gidNumber=".$db->Quote($this->group->get('gidNumber'));
+		$db->setQuery($sql);
+		$roles = $db->loadAssocList();
+		
+		
+		$view->option = $this->_option;
+		$view->group = $this->group;
+		$view->authorized = $this->authorized;
+		$view->uid = $uid;
+		$view->roles = $roles;
+		$view->no_html = JRequest::getInt( 'no_html', 0 );
+		if ($this->getError()) {
+			$view->setError( $this->getError() );
+		}
+		
+		$this->_output = $view->loadTemplate();
+	}
+	
+	//-----
+	
+	private function submitrole()
+	{
+		$uid = JRequest::getVar('uid', '','post');
+		$role = JRequest::getVar('role','','post');
+		$no_html = JRequest::getInt('no_html', 0,'post');
+		
+		if(!$uid || !$role) {
+			$this->setError('You must select a role.');
+			$this->assignrole();
+			return;
+		}
+			
+		$db =& JFactory::getDBO();
+		$sql = "INSERT INTO #__xgroups_member_roles(role,uidNumber) VALUES('".$role."','".$uid."')";
+		$db->setQuery($sql);
+		$db->query();
+		
+		if($no_html == 0) {
+			$xhub = Hubzero_Factory::getHub();
+			$xhub->redirect( JRoute::_('index.php?option=com_groups&gid='.$this->group->get('cn').'&active=members') );
+		}
+	}
+	
+	//-----
+	
+	private function deleterole()
+	{
+		$uid = JRequest::getVar('uid','');
+		$role = JRequest::getVar('role','');
+		
+		if(!$uid || !$role) {
+			return false;
+		}
+		
+		$db =& JFactory::getDBO();
+		
+		$sql = "DELETE FROM #__xgroups_member_roles WHERE role='".$role."' AND uidNumber='".$uid."'";
+		$db->setQuery($sql);
+		$db->query();
+		
+		if(!$db->query()) {
+			$this->setError('An error occurred while trying to remove the members role. Please try again.');
+		}
+		
+		$xhub = Hubzero_Factory::getHub();
+		$xhub->redirect( JRoute::_('index.php?option=com_groups&gid='.$this->group->get('cn').'&active=members') );
+	}
+	
 	//----------------------------------------------------------
 	// Messaging
 	//----------------------------------------------------------
@@ -924,7 +1128,7 @@ class plgGroupsMembers extends JPlugin
 		
 		// Build the SEF referenced in the message
 		$juri =& JURI::getInstance();
-		$sef = JRoute::_('index.php?option='.$this->_option.a.'gid='. $group->get('cn'));
+		$sef = JRoute::_('index.php?option='.$this->_option.'&gid='. $group->get('cn'));
 		if (substr($sef,0,1) == '/') {
 			$sef = substr($sef,1,strlen($sef));
 		}
@@ -1019,4 +1223,59 @@ class plgGroupsMembers extends JPlugin
 			$this->setError( JText::_('PLG_GROUPS_MESSAGES_ERROR_MSG_MEMBERS_FAILED') );
 		}
 	}
+
+	//------
+	
+	private function notifyEmailInvitedUser( $email )
+	{
+		// Get the group information
+		$group = $this->group;
+		
+		// Build the SEF referenced in the message
+		$juri =& JURI::getInstance();
+		$sef = JRoute::_('index.php?option='.$this->_option.'&gid='. $group->get('cn'));
+		if (substr($sef,0,1) == '/') {
+			$sef = substr($sef,1,strlen($sef));
+		}
+		
+		// Get the site configuration
+		$jconfig =& JFactory::getConfig();
+		
+		//get the reason
+		$reason = JRequest::getVar( 'reason', '', 'post' );
+		
+		// Build the "from" info for e-mails
+		$from = array();
+		$from['name']  = $jconfig->getValue('config.sitename').' '.JText::_(strtoupper($this->_name));
+		$from['email'] = $jconfig->getValue('config.mailfrom');
+		
+		//create the subject
+		$subject = JText::_('PLG_GROUPS_MESSAGES_SUBJECT_INVITATION_CANCELLED');
+		
+		//create the message body
+		$message  = "Your invitation for membership in the " . $group->get('description') . " group has been cancelled.\r\n\r\n";
+		if ($reason) {
+			$message .= stripslashes($reason)."\r\n\r\n";
+		}
+		$message .= "If you feel this is in error, you may try to join the group by going to:\r\n";
+		$message .= $juri->base().$sef . "\r\n";
+		
+		//send the message
+		if ($email) {
+			$args = "-f '" . $from['email'] . "'";
+			$headers  = "MIME-Version: 1.0\n";
+			$headers .= "Content-type: text/plain; charset=utf-8\n";
+			$headers .= 'From: ' . $from['name'] .' <'. $from['email'] . ">\n";
+			$headers .= 'Reply-To: ' . $from['name'] .' <'. $from['email'] . ">\n";
+			$headers .= "X-Priority: 3\n";
+			$headers .= "X-MSMail-Priority: High\n";
+			$headers .= 'X-Mailer: '. $from['name'] ."\n";
+			if (mail($email, $subject, $message, $headers, $args)) {
+				return true;
+			}
+		}
+		return false;
+	}
+
 }
+
