@@ -1,25 +1,29 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Shawn Rice <zooley@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Shawn Rice <zooley@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
@@ -48,48 +52,71 @@ class plgGroupsResources extends JPlugin
 		$this->_plugin = JPluginHelper::getPlugin( 'groups', 'resources' );
 		$this->_params = new JParameter( $this->_plugin->params );
 		
-		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_resources'.DS.'resources.type.php' );
-		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_resources'.DS.'resources.resource.php' );
+		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_resources'.DS.'tables'.DS.'type.php' );
+		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_resources'.DS.'tables'.DS.'resource.php' );
 	}
 
 	//-----------
 	
-	public function &onGroupAreas( $authorized )
+	public function &onGroupAreas()
 	{
-		$areas = array(
-			'resources' => JText::_('PLG_GROUPS_RESOURCES')
+		$area = array(
+			'name' => 'resources',
+			'title' => JText::_('PLG_GROUPS_RESOURCES'),
+			'default_access' => 'members'
 		);
-		return $areas;
+		
+		return $area;
 	}
 
 	//-----------
 
-	public function onGroup( $group, $option, $authorized, $limit=0, $limitstart=0, $action='', $areas=null )
+	public function onGroup( $group, $option, $authorized, $limit=0, $limitstart=0, $action='', $access, $areas=null )
 	{
 		$return = 'html';
-
-		// Check if our area is in the array of areas we want to return results for
-		if (is_array( $areas ) && $limit) {
-			if (!array_intersect( $areas, $this->onGroupAreas( $authorized ) ) 
-			&& !array_intersect( $areas, array_keys( $this->onGroupAreas( $authorized ) ) )) {
-				$return = '';
-			}
-		}
-		
-		// Are we on the overview page?
-		if ($areas[0] == 'overview') {
-			$return = 'metadata';
-		}
+		$active = 'resources';
 		
 		// The output array we're returning
 		$arr = array(
-			'html'=>'',
-			'metadata'=>'',
-			'dashboard'=>''
+			'html'=>''
 		);
+		
+		//get this area details
+		$this_area = $this->onGroupAreas();
+		
+		// Check if our area is in the array of areas we want to return results for
+		if (is_array( $areas ) && $limit) {
+			if(!in_array($this_area['name'],$areas)) {
+				return;
+			}
+		}
+		
+		//set group members plugin access level
+		$group_plugin_acl = $access[$active];
+		
+		//Create user object
+		$juser =& JFactory::getUser();
+	
+		//get the group members
+		$members = $group->get('members');
 
-		// Do we need to return any data?
-		if ($return != 'html' && $return != 'metadata') {
+		//if set to nobody make sure cant access
+		if($group_plugin_acl == 'nobody') {
+			$arr['html'] = "<p class=\"info\">".JText::sprintf('GROUPS_PLUGIN_OFF', ucfirst($active))."</p>";
+			return $arr;
+		}
+		
+		//check if guest and force login if plugin access is registered or members
+		if ($juser->get('guest') && ($group_plugin_acl == 'registered' || $group_plugin_acl == 'members')) {
+			ximport('Hubzero_Module_Helper');
+			$arr['html']  = "<p class=\"warning\">".JText::sprintf('GROUPS_PLUGIN_REGISTERED', ucfirst($active))."</p>";
+			$arr['html'] .= Hubzero_Module_Helper::renderModules('force_mod');
+			return $arr;
+		}
+		
+		//check to see if user is member and plugin access requires members
+		if(!in_array($juser->get('id'),$members) && $group_plugin_acl == 'members' && $authorized != 'admin') {
+			$arr['html'] = "<p class=\"info\">".JText::sprintf('GROUPS_PLUGIN_REQUIRES_MEMBER', ucfirst($active))."</p>";
 			return $arr;
 		}
 		
@@ -211,6 +238,10 @@ class plgGroupsResources extends JPlugin
 						'name'=>'results'
 					)
 				);
+				
+				//push the stylesheet to the view
+				ximport('Hubzero_Document');
+				Hubzero_Document::addPluginStylesheet('groups', 'resources');
 
 				// Pass the view some info
 				$view->option = $option;
@@ -498,11 +529,11 @@ class plgGroupsResources extends JPlugin
 	 	$document =& JFactory::getDocument();
 		$document->addScript('components'.DS.'com_resources'.DS.'resources.js');
 		
-		ximport('xdocument');
-		XDocument::addComponentStylesheet('com_resources');
+		ximport('Hubzero_Document');
+		Hubzero_Document::addComponentStylesheet('com_resources');
 
-		include_once( JPATH_ROOT.DS.'components'.DS.'com_resources'.DS.'resources.extended.php' );
-		ximport('resourcestats');
+		include_once( JPATH_ROOT.DS.'components'.DS.'com_resources'.DS.'helpers'.DS.'helper.php' );
+		include_once( JPATH_ROOT.DS.'components'.DS.'com_resources'.DS.'helpers'.DS.'usage.php' );
 	}
 	
 	//-----------
@@ -545,13 +576,23 @@ class plgGroupsResources extends JPlugin
 			$row->href = substr($row->href,1,strlen($row->href));
 		}
 
-		$html  = "\t".'<li class="resource">'."\n";
+		$html  = "\t".'<li class="';
+		switch ($row->access)
+		{
+			case 1: $html .= 'registered'; break;
+			case 2: $html .= 'special';    break;
+			case 3: $html .= 'protected';  break;
+			case 4: $html .= 'private';    break;
+			case 0:
+			default: $html .= 'public'; break;
+		}
+		$html .= ' resource">'."\n";
 		$html .= "\t\t".'<p class="';
-		if ($row->access == 4) {
+		/*if ($row->access == 4) {
 			$html .= 'private ';
 		} elseif ($row->access == 3) {
 			$html .= 'protected ';
-		}
+		}*/
 		$html .= 'title"><a href="'.$row->href.'">'.stripslashes($row->title).'</a></p>'."\n";
 			
 		if ($params->get('show_ranking')) {
@@ -626,3 +667,4 @@ class plgGroupsResources extends JPlugin
 		// ...
 	}*/
 }
+
