@@ -1,25 +1,29 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Shawn Rice <zooley@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Shawn Rice <zooley@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
@@ -85,10 +89,13 @@ class plgMembersMessages extends JPlugin
 		$database =& JFactory::getDBO();
 
 		// Load some needed libraries
-		ximport('xmessage');
+		ximport('Hubzero_Message');
 		
 		// Are we returning HTML?
 		if ($returnhtml) {
+			ximport('Hubzero_Document');
+			Hubzero_Document::addPluginStylesheet('members', 'messages');
+			
 			$task = JRequest::getVar('action','');
 			if (!$task) {
 				$task = JRequest::getVar('inaction','');
@@ -121,7 +128,7 @@ class plgMembersMessages extends JPlugin
 				default: $arr['html'] = $this->inbox($database, $option, $member); break;
 			}
 		} else {
-			$recipient = new XMessageRecipient( $database );
+			$recipient = new Hubzero_Message_Recipient( $database );
 			$rows = $recipient->getUnreadMessages( $member->get('uidNumber'), 0 );
 			
 			$arr['metadata'] = '<p class="messages"><a href="'.JRoute::_('index.php?option='.$option.'&id='.$member->get('uidNumber').'&active=messages').'">'.JText::sprintf('PLG_MEMBERS_MESSAGES_UNREAD', count($rows)).'</a></p>'.n;
@@ -149,7 +156,7 @@ class plgMembersMessages extends JPlugin
 		$filter = JRequest::getVar('filter', '');
 		$filters['filter'] = ($filter) ? 'com_'.$filter : '';
 		
-		$recipient = new XMessageRecipient( $database );
+		$recipient = new Hubzero_Message_Recipient( $database );
 		
 		$total = $recipient->getMessagesCount( $member->get('uidNumber'), $filters );
 		
@@ -158,15 +165,17 @@ class plgMembersMessages extends JPlugin
 		jimport('joomla.html.pagination');
 		$pageNav = new JPagination( $total, $filters['start'], $filters['limit'] );
 
-		$xmc = new XMessageComponent( $database );
+		$xmc = new Hubzero_Message_Component( $database );
 		$components = $xmc->getComponents();
 
 		$pagenavhtml = $pageNav->getListFooter();
+		$pagenavhtml = str_replace('members?','members/'.$member->get('uidNumber').'/messages/inbox/?',$pagenavhtml);
 		$pagenavhtml = str_replace('members/?','members/'.$member->get('uidNumber').'/messages/inbox/?',$pagenavhtml);
 		$pagenavhtml = str_replace('action=inbox','',$pagenavhtml);
 		$pagenavhtml = str_replace('&amp;&amp;','&amp;',$pagenavhtml);
 		$pagenavhtml = str_replace('?&amp;','?',$pagenavhtml);
-		
+		$pagenavhtml = str_replace('href="<li class=limit','href="members/'.$member->get('uidNumber').'/messages/inbox/?limit',$pagenavhtml);
+
 		ximport('Hubzero_Plugin_View');
 		$view = new Hubzero_Plugin_View(
 			array(
@@ -205,7 +214,7 @@ class plgMembersMessages extends JPlugin
 		$filter = JRequest::getVar('filter', '');
 		$filters['filter'] = ($filter) ? 'com_'.$filter : '';
 		
-		$recipient = new XMessageRecipient( $database );
+		$recipient = new Hubzero_Message_Recipient( $database );
 		
 		$total = $recipient->getMessagesCount( $member->get('uidNumber'), $filters );
 		
@@ -214,14 +223,16 @@ class plgMembersMessages extends JPlugin
 		jimport('joomla.html.pagination');
 		$pageNav = new JPagination( $total, $filters['start'], $filters['limit'] );
 
-		$xmc = new XMessageComponent( $database );
+		$xmc = new Hubzero_Message_Component( $database );
 		$components = $xmc->getComponents();
 
 		$pagenavhtml = $pageNav->getListFooter();
+		$pagenavhtml = str_replace('members?','members/'.$member->get('uidNumber').'/messages/archive/?',$pagenavhtml);
 		$pagenavhtml = str_replace('members/?','members/'.$member->get('uidNumber').'/messages/archive/?',$pagenavhtml);
 		$pagenavhtml = str_replace('action=archive','',$pagenavhtml);
 		$pagenavhtml = str_replace('&amp;&amp;','&amp;',$pagenavhtml);
 		$pagenavhtml = str_replace('?&amp;','?',$pagenavhtml);
+		$pagenavhtml = str_replace('href="<li class=limit','href="members/'.$member->get('uidNumber').'/messages/inbox/?limit',$pagenavhtml);
 
 		ximport('Hubzero_Plugin_View');
 		$view = new Hubzero_Plugin_View(
@@ -261,7 +272,7 @@ class plgMembersMessages extends JPlugin
 		$filter = JRequest::getVar('filter', '');
 		$filters['filter'] = ($filter) ? 'com_'.$filter : '';
 		
-		$recipient = new XMessageRecipient( $database );
+		$recipient = new Hubzero_Message_Recipient( $database );
 		
 		$total = $recipient->getMessagesCount( $member->get('uidNumber'), $filters );
 		
@@ -270,14 +281,16 @@ class plgMembersMessages extends JPlugin
 		jimport('joomla.html.pagination');
 		$pageNav = new JPagination( $total, $filters['start'], $filters['limit'] );
 
-		$xmc = new XMessageComponent( $database );
+		$xmc = new Hubzero_Message_Component( $database );
 		$components = $xmc->getComponents();
 
 		$pagenavhtml = $pageNav->getListFooter();
+		$pagenavhtml = str_replace('members?','members/'.$member->get('uidNumber').'/messages/trash/?',$pagenavhtml);
 		$pagenavhtml = str_replace('members/?','members/'.$member->get('uidNumber').'/messages/trash/?',$pagenavhtml);
 		$pagenavhtml = str_replace('action=trash','',$pagenavhtml);
 		$pagenavhtml = str_replace('&amp;&amp;','&amp;',$pagenavhtml);
 		$pagenavhtml = str_replace('?&amp;','?',$pagenavhtml);
+		$pagenavhtml = str_replace('href="<li class=limit','href="members/'.$member->get('uidNumber').'/messages/inbox/?limit',$pagenavhtml);
 
 		ximport('Hubzero_Plugin_View');
 		$view = new Hubzero_Plugin_View(
@@ -315,7 +328,7 @@ class plgMembersMessages extends JPlugin
 		$filters['start'] = JRequest::getInt('limitstart', 0);
 		$filters['created_by'] = $member->get('uidNumber');
 		
-		$recipient = new XMessage( $database );
+		$recipient = new Hubzero_Message_Message( $database );
 		
 		$total = $recipient->getSentMessagesCount( $filters );
 		
@@ -325,10 +338,12 @@ class plgMembersMessages extends JPlugin
 		$pageNav = new JPagination( $total, $filters['start'], $filters['limit'] );
 
 		$pagenavhtml = $pageNav->getListFooter();
+		$pagenavhtml = str_replace('members?','members/'.$member->get('uidNumber').'/messages/sent/?',$pagenavhtml);
 		$pagenavhtml = str_replace('members/?','members/'.$member->get('uidNumber').'/messages/sent/?',$pagenavhtml);
 		$pagenavhtml = str_replace('action=sent','',$pagenavhtml);
 		$pagenavhtml = str_replace('&amp;&amp;','&amp;',$pagenavhtml);
 		$pagenavhtml = str_replace('?&amp;','?',$pagenavhtml);
+		$pagenavhtml = str_replace('href="<li class=limit','href="members/'.$member->get('uidNumber').'/messages/inbox/?limit',$pagenavhtml);
 		
 		ximport('Hubzero_Plugin_View');
 		$view = new Hubzero_Plugin_View(
@@ -357,7 +372,7 @@ class plgMembersMessages extends JPlugin
 		if (count($mids) > 0) {
 			foreach ($mids as $mid) 
 			{
-				$recipient = new XMessageRecipient( $database );
+				$recipient = new Hubzero_Message_Recipient( $database );
 				$recipient->mid = $mid;
 				$recipient->uid = $member->get('uidNumber');
 				$recipient->loadRecord();
@@ -366,7 +381,7 @@ class plgMembersMessages extends JPlugin
 					$this->setError( $recipient->getError() );
 				}
 				
-				$xseen = new XMessageSeen( $database );
+				$xseen = new Hubzero_Message_Seen( $database );
 				$xseen->mid = $mid;
 				$xseen->uid = $member->get('uidNumber');
 				$xseen->loadRecord();
@@ -389,7 +404,7 @@ class plgMembersMessages extends JPlugin
 		if (count($mids) > 0) {
 			foreach ($mids as $mid) 
 			{
-				$recipient = new XMessageRecipient( $database );
+				$recipient = new Hubzero_Message_Recipient( $database );
 				$recipient->mid = $mid;
 				$recipient->uid = $member->get('uidNumber');
 				$recipient->loadRecord();
@@ -412,12 +427,12 @@ class plgMembersMessages extends JPlugin
 		if (count($mids) > 0) {
 			foreach ($mids as $mid) 
 			{
-				$recipient = new XMessageRecipient( $database );
+				$recipient = new Hubzero_Message_Recipient( $database );
 				$recipient->mid = $mid;
 				$recipient->uid = $member->get('uidNumber');
 				$recipient->loadRecord();
 				
-				$xseen = new XMessageSeen( $database );
+				$xseen = new Hubzero_Message_Seen( $database );
 				$xseen->mid = $mid;
 				$xseen->uid = $member->get('uidNumber');
 				$xseen->loadRecord();
@@ -441,7 +456,7 @@ class plgMembersMessages extends JPlugin
 	
 	public function emptytrash($database, $option, $member) 
 	{
-		$recipient = new XMessageRecipient( $database );
+		$recipient = new Hubzero_Message_Recipient( $database );
 		$recipient->uid = $member->get('uidNumber');
 		if (!$recipient->deleteTrash()) {
 			$this->setError( $recipient->getError() );
@@ -459,7 +474,7 @@ class plgMembersMessages extends JPlugin
 		if (count($mids) > 0) {
 			foreach ($mids as $mid) 
 			{
-				$recipient = new XMessageRecipient( $database );
+				$recipient = new Hubzero_Message_Recipient( $database );
 				$recipient->mid = $mid;
 				$recipient->uid = $member->get('uidNumber');
 				$recipient->loadRecord();
@@ -481,7 +496,7 @@ class plgMembersMessages extends JPlugin
 		if (count($ids) > 0) {
 			foreach ($ids as $mid) 
 			{
-				$xseen = new XMessageSeen( $database );
+				$xseen = new Hubzero_Message_Seen( $database );
 				$xseen->mid = $mid;
 				$xseen->uid = $member->get('uidNumber');
 				$xseen->loadRecord();
@@ -499,11 +514,11 @@ class plgMembersMessages extends JPlugin
 	
 	public function view($database, $option, $member, $mid) 
 	{
-		$xmessage = new XMessage( $database );
+		$xmessage = new Hubzero_Message_Message( $database );
 		$xmessage->load( $mid );
 		$xmessage->message = stripslashes($xmessage->message);
 		
-		$xmr = new XMessageRecipient( $database );
+		$xmr = new Hubzero_Message_Recipient( $database );
 		$xmr->loadRecord( $mid, $member->get('uidNumber') );
 
 		$xmessage->message = str_replace("\n","\n ",$xmessage->message);
@@ -516,13 +531,16 @@ class plgMembersMessages extends JPlugin
 			$xmessage->component = substr($xmessage->component,4);
 		}
 		
-		$xseen = new XMessageSeen( $database );
+		$xseen = new Hubzero_Message_Seen( $database );
 		$xseen->mid = $mid;
 		$xseen->uid = $member->get('uidNumber');
 		$xseen->loadRecord();
-		if ($xseen->whenseen == '' || $xseen->whenseen == '0000-00-00 00:00:00' || $xseen->whenseen == NULL) {
-			$xseen->whenseen = date( 'Y-m-d H:i:s', time() );
-			$xseen->store( true );
+		$juser =& JFactory::getUser();
+		if ($juser->get('id') == $member->get('uidNumber')) {
+			if ($xseen->whenseen == '' || $xseen->whenseen == '0000-00-00 00:00:00' || $xseen->whenseen == NULL) {
+				$xseen->whenseen = date( 'Y-m-d H:i:s', time() );
+				$xseen->store( true );
+			}
 		}
 		
 		if (substr($xmessage->type, -8) == '_message') {
@@ -572,7 +590,7 @@ class plgMembersMessages extends JPlugin
 		$name = trim($href);
 		if (substr($name, 0, 7) == 'mailto:') {
 			$name = substr($name, 7, strlen($name));
-			$name = Eventshtml::obfuscate($name);
+			$name = plgMembersMessages::obfuscate($name);
 			//$href = Eventshtml::obfuscate($href);
 			$href = 'mailto:'.$name;
 		}
@@ -582,6 +600,20 @@ class plgMembersMessages extends JPlugin
 		return $l;
 	}
 	
+	//-----------
+	
+	public function obfuscate( $email )
+	{
+		$length = strlen($email);
+		$obfuscatedEmail = '';
+		for ($i = 0; $i < $length; $i++) 
+		{
+			$obfuscatedEmail .= '&#'. ord($email[$i]) .';';
+		}
+		
+		return $obfuscatedEmail;
+	}
+	
 	//-----------
 
 	public function selectMethod($notimethods, $name, $values=array(), $ids=array())
@@ -619,7 +651,7 @@ class plgMembersMessages extends JPlugin
 			$document->addScript('plugins'.DS.'members'.DS.'messages'.DS.'messages.js');
 		}
 		
-		$xmc = new XMessageComponent( $database );
+		$xmc = new Hubzero_Message_Component( $database );
 		$components = $xmc->getRecords();
 		
 		ximport('Hubzero_Plugin_View');
@@ -657,7 +689,7 @@ class plgMembersMessages extends JPlugin
 		$default_method = null;
 		
 		// Instantiate our notify object
-		$notify = new XMessageNotify( $database );
+		$notify = new Hubzero_Message_Notify( $database );
 		
 		// Get the user's selected methods
 		$methods = $notify->getRecords( $member->get('uidNumber') );
@@ -714,7 +746,7 @@ class plgMembersMessages extends JPlugin
 				{
 					if ($v) {
 						// Instantiate a Notify object and set its values
-						$notify = new XMessageNotify( $database );
+						$notify = new Hubzero_Message_Notify( $database );
 						$notify->uid = $member->get('uidNumber');
 						$notify->method = $v;
 						$notify->type = $key;
@@ -736,7 +768,7 @@ class plgMembersMessages extends JPlugin
 				}
 			}
 
-			$notify = new XMessageNotify( $database );
+			$notify = new Hubzero_Message_Notify( $database );
 			foreach ($ids as $key=>$value) 
 			{
 				foreach ($value as $k=>$v) 
@@ -760,7 +792,7 @@ class plgMembersMessages extends JPlugin
 			// This creates a single entry to let the system know that the user has explicitly chosen "none" for all options
 			// It ensures we can know the difference between someone who has never changed their settings (thus, no database entries) 
 			// and someone who purposely wants everything turned off.
-			$notify = new XMessageNotify( $database );
+			$notify = new Hubzero_Message_Notify( $database );
 			$notify->uid = $member->get('uidNumber');
 			
 			$records = $notify->getRecords( $member->get('uidNumber'), 'all' );
@@ -843,3 +875,4 @@ class plgMembersMessages extends JPlugin
 		}
 	}
 }
+
