@@ -1,25 +1,29 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Alissa Nedossekina <alisa@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Alissa Nedossekina <alisa@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // No direct access
@@ -34,7 +38,7 @@ JPlugin::loadLanguage( 'com_jobs' );
 
 class plgMembersResume extends JPlugin
 {
-	function plgMembersResume(&$subject, $config)
+	public function plgMembersResume(&$subject, $config)
 	{
 		parent::__construct($subject, $config);
 
@@ -42,7 +46,17 @@ class plgMembersResume extends JPlugin
 		$this->_plugin = JPluginHelper::getPlugin( 'members', 'resume' );
 		$this->_params = new JParameter( $this->_plugin->params );
 		
-		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_jobs'.DS.'jobs.class.php' );
+		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_jobs'.DS.'tables'.DS.'admin.php' );
+		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_jobs'.DS.'tables'.DS.'application.php' );
+		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_jobs'.DS.'tables'.DS.'category.php' );
+		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_jobs'.DS.'tables'.DS.'employer.php' );
+		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_jobs'.DS.'tables'.DS.'job.php' );
+		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_jobs'.DS.'tables'.DS.'prefs.php' );
+		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_jobs'.DS.'tables'.DS.'resume.php' );
+		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_jobs'.DS.'tables'.DS.'seeker.php' );
+		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_jobs'.DS.'tables'.DS.'shortlist.php' );
+		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_jobs'.DS.'tables'.DS.'stats.php' );
+		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_jobs'.DS.'tables'.DS.'type.php' );
 
 		$config =& JComponentHelper::getParams( 'com_jobs' );
 		$this->config = $config;		
@@ -50,7 +64,7 @@ class plgMembersResume extends JPlugin
 	
 	//-----------
 	
-	function &onMembersAreas( $authorized) 
+	public function &onMembersAreas($authorized) 
 	{	
 		$emp = $this->isEmployer();
 		
@@ -58,7 +72,6 @@ class plgMembersResume extends JPlugin
 			$areas = array(
 				'resume' => ucfirst(JText::_('Resume'))
 			);
-			
 		} else {
 			$areas = array();
 		}
@@ -68,22 +81,21 @@ class plgMembersResume extends JPlugin
 	
 	//-----------
 
-	function isEmployer ( $member='', $authorized = '')
+	public function isEmployer( $member='', $authorized = '')
 	{		
 		$juser 	  =& JFactory::getUser();
 		$database =& JFactory::getDBO();
-		$employer = new Employer ( $database );
+		$employer = new Employer( $database );
 		
 		// determine who is veiwing the page
 		$emp = 0;
 		$emp = $employer->isEmployer($juser->get('id'));
 		
 		// check if they belong to a dedicated admin group
-		if($this->config->get('admingroup')) {
-			ximport('xgroup');
-			ximport('xuserhelper');
+		if ($this->config->get('admingroup')) {
+			ximport('Hubzero_User_Helper');
 				
-			$ugs = XUserHelper::getGroups( $juser->get('id') );
+			$ugs = Hubzero_User_Helper::getGroups( $juser->get('id') );
 			if ($ugs && count($ugs) > 0) {
 				foreach ($ugs as $ug) 
 				{
@@ -94,13 +106,13 @@ class plgMembersResume extends JPlugin
 			}
 		}
 		
-		if($authorized) {
+		if ($authorized) {
 			$emp = 1;
 		}
 		
-		if($member) {		
-		$my =  $member->get('uidNumber') == $juser->get('id') ? 1 : 0;
-		$emp = $my && $emp ? 0 : $emp;
+		if ($member) {		
+			$my =  $member->get('uidNumber') == $juser->get('id') ? 1 : 0;
+			$emp = $my && $emp ? 0 : $emp;
 		}
 		
 		return $emp;
@@ -108,16 +120,15 @@ class plgMembersResume extends JPlugin
 	
 	//-----------
 
-	function isAdmin ($admin = 0)
+	public function isAdmin($admin = 0)
 	{		
-		$juser 	  =& JFactory::getUser();
+		$juser =& JFactory::getUser();
 		
 		// check if they belong to a dedicated admin group
-		if($this->config->get('admingroup')) {
-			ximport('xgroup');
-			ximport('xuserhelper');
+		if ($this->config->get('admingroup')) {
+			ximport('Hubzero_User_Helper');
 				
-			$ugs = XUserHelper::getGroups( $juser->get('id') );
+			$ugs = Hubzero_User_Helper::getGroups( $juser->get('id') );
 			if ($ugs && count($ugs) > 0) {
 				foreach ($ugs as $ug) {
 					if ($ug->cn == $this->config->get('admingroup')) {
@@ -132,7 +143,7 @@ class plgMembersResume extends JPlugin
 
 	//-----------
 
-	function onMembers( $member, $option, $authorized, $areas )
+	public function onMembers( $member, $option, $authorized, $areas )
 	{		
 		$return = 'html';
 		$active = 'resume';
@@ -172,7 +183,7 @@ class plgMembersResume extends JPlugin
 		}
 		
 		// Get authorization
-		$emp 	= $this->isEmployer($member, $authorized);
+		$emp = $this->isEmployer($member, $authorized);
 						
 		// Are we returning HTML?
 		if ($return == 'html'  && $areas[0] == 'resume') {
@@ -191,7 +202,7 @@ class plgMembersResume extends JPlugin
 				case 'view': 
 				default: $arr['html'] = $this->view($database, $option, $member, $emp, $edittitle = 0 ); break;
 			}
-		} else if($authorized or $emp) {
+		} else if ($authorized or $emp) {
 			$arr['metadata'] = '<p class="resume"><a href="'.JRoute::_('index.php?option='.$option.a.'id='.$member->get('uidNumber').a.'active=resume').'">'.ucfirst(JText::_('Resume')).'</a></p>'.n;
 		}
 			
@@ -208,34 +219,34 @@ class plgMembersResume extends JPlugin
 		$author = JRequest::getInt('author', 0);
 		$title = JRequest::getVar('title','');
 
-		if($task=='saveprefs') {
+		if ($task=='saveprefs') {
 			$js = new JobSeeker ( $database );
 			
-			if(!$js->load($member->get('uidNumber'))) {
+			if (!$js->load($member->get('uidNumber'))) {
 				$this->setError( JText::_('PLG_RESUME_ERROR_PROFILE_NOT_FOUND') );
 				return '';
 			}
 			
 			if (!$js->bind( $_POST )) {
-			echo $this->alert( $js->getError() );
-			exit();
+				echo $this->alert( $js->getError() );
+				exit();
 			}
 			
 			$js->active = $active;
 			$js->updated = date( 'Y-m-d H:i:s', time() );	
 			
 			if (!$js->store()) {
-			echo $this->alert( $js->getError() );
-			exit();
+				echo $this->alert( $js->getError() );
+				exit();
 			}		
 		}
-		else if($task=='savetitle' && $author && $title) {
+		else if ($task=='savetitle' && $author && $title) {
 			$resume = new Resume ( $database );
-			if($resume->load($author)) {
+			if ($resume->load($author)) {
 				$resume->title = $title;
 				if (!$resume->store()) {
-				echo $this->alert( $resume->getError() );
-				exit();
+					echo $this->alert( $resume->getError() );
+					exit();
 				}
 			}
 		}
@@ -252,10 +263,10 @@ class plgMembersResume extends JPlugin
 				
 		$js = new JobSeeker ( $database );
 		
-		if(!$js->load($member->get('uidNumber'))) {
+		if (!$js->load($member->get('uidNumber'))) {
 			$this->setError( JText::_('PLG_RESUME_ERROR_PROFILE_NOT_FOUND') );
 			return '';
-		} else if(!$active) {
+		} else if (!$active) {
 			$js->active = $active;
 			$js->updated = date( 'Y-m-d H:i:s', time() );	
 			
@@ -276,20 +287,21 @@ class plgMembersResume extends JPlugin
 	
 	//----------
 	
-	public function getThumb ($uid) 
+	public function getThumb($uid) 
 	{	
 		// do we have a thumb image for the user?
-		require_once( JPATH_ROOT.DS.'components'.DS.'com_members'.DS.'members.imghandler.php' );
-		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_members'.DS.'members.class.php' );
-		ximport('fileuploadutils');
+		require_once( JPATH_ROOT.DS.'components'.DS.'com_members'.DS.'helpers'.DS.'imghandler.php' );
+		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_members'.DS.'tables'.DS.'profile.php' );
+		include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_members'.DS.'tables'.DS.'association.php' );
 						
-		$profile = new XProfile();
+		$profile = new Hubzero_User_Profile();
 		$profile->load( $uid );
 		$thumb = '';
 		
 		$config =& JComponentHelper::getParams( 'com_members' );
 		$ih = new MembersImgHandler();
-		$dir = FileUploadUtils::niceidformat( $uid );
+		ximport('Hubzero_View_Helper_Html');
+		$dir = Hubzero_View_Helper_Html::niceidformat( $uid );
 		$path = JPATH_ROOT.$config->get('webpath').DS.$dir;
 		
 		if ($profile->get('picture')) {
@@ -309,11 +321,11 @@ class plgMembersResume extends JPlugin
 	public function view($database, $option, $member, $emp, $edittitle = 0, $editpref = 0) 
 	{
 		$out = '';
-		$juser 	  =& JFactory::getUser();		
+		$juser =& JFactory::getUser();		
 		
 		// get job seeker info on the user
 		$js = new JobSeeker ( $database );
-		if(!$js->load($member->get('uidNumber'))) {
+		if (!$js->load($member->get('uidNumber'))) {
 				
 			// make a new entry
 			$js = new JobSeeker ( $database );
@@ -334,18 +346,18 @@ class plgMembersResume extends JPlugin
 		}
 		
 		// Add styles and scripts
-		ximport('xdocument');
-		XDocument::addComponentStylesheet('com_jobs');
+		ximport('Hubzero_Document');
+		Hubzero_Document::addComponentStylesheet('com_jobs');
 		
-		$jt = new JobType ( $database );
-		$jc = new JobCategory ( $database );
+		$jt = new JobType( $database );
+		$jc = new JobCategory( $database );
 		
 		// get active resume
-		$resume = new Resume ($database);
+		$resume = new Resume($database);
 		$file = '';
 		$path = $this->build_path( $member->get('uidNumber') );
 				
-		if($resume->load($member->get('uidNumber'))) {
+		if ($resume->load($member->get('uidNumber'))) {
 			$file = JPATH_ROOT.$path.DS.$resume->filename;
 			if (!is_file($file)) { $file = ''; }		
 		}
@@ -358,7 +370,7 @@ class plgMembersResume extends JPlugin
 		$stats = $jobstats->getStats ($member->get('uidNumber'), 'seeker');			
 	
 		$out = '<div class="aside">'.n;
-		if(!$emp) {
+		if (!$emp) {
 			$out .= t.t.'<p>'.JText::_('PLG_RESUME_HUB_OFFERS').'</p>'.n;
 		}
 		else {
@@ -367,7 +379,7 @@ class plgMembersResume extends JPlugin
 		$hd = JText::_('View Jobs');
 		$hd .= $this->config->get('industry') ? ' '.JText::_('IN').' '.$this->config->get('industry') : '';
 		$out .= t.t.'<a href="'.JRoute::_('index.php?option=com_jobs').'" class="minimenu">'.$hd.'</a>'.n;
-		if(!$emp && $js->active) {
+		if (!$emp && $js->active) {
 			$out .= '<ul class="jobstats">'.n;
 			$out .= '<li class="statstitle">'.JText::_('PLG_RESUME_YOUR_STATS').'</li>'.n;
 			$out .= '<li>';
@@ -394,16 +406,16 @@ class plgMembersResume extends JPlugin
 		}		
 		$out .= '</div>'.n;
 		$out .= '<div class="subject">'.n;
-		if(!$emp && $file) {
+		if (!$emp && $file) {
 			$out .= '<div id="prefs" class="'.$class1.'">'.n;
 			$out .= ' <p>'.n;
-			if($js->active && $file )  {
+			if ($js->active && $file )  {
 				$out .= JText::_('PLG_RESUME_PROFILE_INCLUDED');
 			}
-			else if($file) {
+			else if ($file) {
 				$out .= JText::_('PLG_RESUME_PROFILE_NOT_INCLUDED');
 			}
-			if(!$editpref) {
+			if (!$editpref) {
 				$out .= ' <span class="includeme"><a href="'.JRoute::_('index.php?option='.$option.a.'id='.$member->get('uidNumber').a.'active=resume'.a.'action=activate').a.'on=';
 				if ($js->active && $file) {
 				$out .= '0">[-] '.JText::_('PLG_RESUME_ACTION_HIDE');
@@ -490,11 +502,11 @@ class plgMembersResume extends JPlugin
 		}
 		
 		// seeker details block
-		if($js->active && $file) {
+		if ($js->active && $file) {
 			// get seeker info
 			$seeker = $js->getSeeker($member->get('uidNumber'), $juser->get('id'));
 			
-			if(!$seeker or count($seeker)==0) {
+			if (!$seeker or count($seeker)==0) {
 				$out .= t.t.t.'<p class="error">'.JText::_('PLG_RESUME_ERROR_RETRIEVING_PROFILE').'</p>'.n;	
 				
 			}
@@ -503,8 +515,8 @@ class plgMembersResume extends JPlugin
 			}	
 		}
 		
-		//if(($resume->id  && $file) && (!$emp or ($emp && $js->active)) ) {	
-		if($resume->id  && $file && !$emp) {	
+		//if (($resume->id  && $file) && (!$emp or ($emp && $js->active)) ) {	
+		if ($resume->id  && $file && !$emp) {	
 			$out .= t.'<table class="list">'.n;
 			$out .= t.t.'<thead>'.n;
 			$out .= t.t.t.'<tr>'.n;
@@ -518,7 +530,7 @@ class plgMembersResume extends JPlugin
 			$out .= t.t.t.t.'<td>';
 			$title = $resume->title ?  stripslashes($resume->title) : $resume->filename;
 			$default_title = $member->get('firstname') ? $member->get('firstname').' '.$member->get('lastname').' '.ucfirst(JText::_('Resume')) : $member->get('name').' '.ucfirst(JText::_('Resume'));
-			if($edittitle && !$emp) {
+			if ($edittitle && !$emp) {
 				$out .= t.'<form id="editTitleForm" method="post" action="'.JRoute::_('index.php?option='.$option.a.'id='.$member->get('uidNumber').a.'active=resume'.a.'action=savetitle').'" >'.n;
 				$out .= t.t.'<fieldset>'.n;
 				$out .= t.t.t.t.'<label class="resume">'.n;	
@@ -547,13 +559,13 @@ class plgMembersResume extends JPlugin
 			$out .= t.t.'</tbody>'.n;
 			$out .= t.'</table>'.n;
 		}
-		else if(!$js->active) {
+		else if (!$js->active) {
 			$out .= '<p class="no_resume">';
 			$out .= ($emp) ? JText::_('PLG_RESUME_USER_HAS_NO RESUME') : JText::_('PLG_RESUME_YOU_HAVE_NO_RESUME');
 			$out .='</p>'.n;
 		}
 		
-		if(!$emp) {
+		if (!$emp) {
 			$out .= ' <form class="addResumeForm" method="post" action="'.JRoute::_('index.php?option='.$option.a.'id='.$member->get('uidNumber').a.'active=resume').'" enctype="multipart/form-data">'.n;
 			$out .= t.t.'<fieldset>'.n;
 			$out .= t.t.t.'<legend>'.n;
@@ -586,8 +598,8 @@ class plgMembersResume extends JPlugin
 	function showSeeker( $seeker, $emp, $admin, $option, $list=0) 
 	{
 		$database =& JFactory::getDBO();
-		$jt = new JobType ( $database );
-		$jc = new JobCategory ( $database );
+		$jt = new JobType( $database );
+		$jc = new JobCategory( $database );
 		
 		$out = '';
 			
@@ -631,10 +643,10 @@ class plgMembersResume extends JPlugin
 		$out .= '</span>'.n;
 		$out .= t.'<span class="abouttext">'.stripslashes($seeker->lookingfor).'</span></div>'.n;
 	
-		if($seeker->mine) {
+		if ($seeker->mine) {
 			$out .= t.'<span class="editbt"><a href="'.JRoute::_('index.php?option='.$option.a.'id='.$seeker->uid.a.'active=resume'.a.'action=editprefs').'" title="'.JText::_('ACTION_EDIT_MY_PROFILE').'">&nbsp;</a></span>'.n;
 		}
-		else if($emp or $admin) {
+		else if ($emp or $admin) {
 			$out .= t.'<span id ="o'.$seeker->uid.'"><a href="';
 			$out .= JRoute::_('index.php?option=com_jobs'.a.'oid='.$seeker->uid.a.'task=shortlist').'" class="favvit" title="';
 			$out .= isset($seeker->shortlisted) && $seeker->shortlisted ? JText::_('ACTION_REMOVE_FROM_SHORTLIST') : JText::_('ACTION_ADD_TO_SHORTLIST');
@@ -649,7 +661,7 @@ class plgMembersResume extends JPlugin
 			*/
 		$out .= t.'<div class="clear leftclear"></div>'.n;	
 		$out .= t.'<span class="indented">';
-		if($resume) {
+		if ($resume) {
 			$out .= '<a href="'.JRoute::_('index.php?option='.$option.a.'id='.$seeker->uid.a.'active=resume'.a.'action=download').'" class="resume getit" title="'.$title.'">'.ucfirst(JText::_('PLG_RESUME_RESUME')).'</a> <span class="mini">'.JText::_('PLG_RESUME_LAST_UPDATE').': '.$this->nicetime($seeker->created).'</span>  '.n;
 			//$out .= $seeker->url ? '<a href="'.$seeker->url.'" class="web" title="'.JText::_('Member website').'">'.$seeker->url.'</a>' : '';
 			$out .= $seeker->url ? '<span class="mini"> | </span> <span class="mini"><a href="'.$seeker->url.'" class="web" rel="external" title="'.JText::_('PLG_RESUME_MEMBER_WEBSITE').': '.$seeker->url.'">'.JText::_('PLG_RESUME_WEBSITE').'</a></span>' : '';
@@ -680,21 +692,20 @@ class plgMembersResume extends JPlugin
 			if (substr($base_path, 0, 1) != DS) { 
 				$base_path = DS.$base_path;
 			}
-		}
-		else {
+		} else {
 			$base_path = DS.'site'.DS.'members';
 		}
 		
-		ximport('fileuploadutils');
-		$dir  = FileUploadUtils::niceidformat( $uid );
+		ximport('Hubzero_View_Helper_Html');
+		$dir = Hubzero_View_Helper_Html::niceidformat( $uid );
 		
 		$listdir = $base_path.DS.$dir;
 		
 		if (!is_dir(JPATH_ROOT.$listdir)) {
-				jimport('joomla.filesystem.folder');
-				if (!JFolder::create( JPATH_ROOT.$listdir, 0777 )) {
-					return false;
-				}
+			jimport('joomla.filesystem.folder');
+			if (!JFolder::create( JPATH_ROOT.$listdir, 0777 )) {
+				return false;
+			}
 		}
 		
 		// Build the path
@@ -729,7 +740,7 @@ class plgMembersResume extends JPlugin
 		$path = JPATH_ROOT.$path;
 		
 		// Replace file title with user name		
-		$file_ext      = substr($file['name'], strripos($file['name'], '.'));
+		$file_ext = substr($file['name'], strripos($file['name'], '.'));
 		$file['name'] = $member->get('firstname') ? $member->get('firstname').' '.$member->get('lastname').' '.ucfirst(JText::_('PLG_RESUME_RESUME')) : $member->get('name').' '.ucfirst(JText::_('PLG_RESUME_RESUME'));
 		$file['name'] .= $file_ext;
 		
@@ -741,7 +752,7 @@ class plgMembersResume extends JPlugin
 		
 		$row = new Resume( $database );
 			
-		if(!$row->load($member->get('uidNumber'))) {
+		if (!$row->load($member->get('uidNumber'))) {
 				$row = new Resume( $database );
 				$row->id = 0;		
 				$row->uid = $member->get('uidNumber');	
@@ -783,7 +794,7 @@ class plgMembersResume extends JPlugin
 	protected function deleteresume($database, $option, $member, $emp)
 	{		
 		$row = new Resume( $database );
-		if(!$row->load($member->get('uidNumber'))) {
+		if (!$row->load($member->get('uidNumber'))) {
 			$this->setError( JText::_('Resume ID not found.') );
 			return '';
 		}
@@ -797,7 +808,6 @@ class plgMembersResume extends JPlugin
 			$this->setError( JText::_('FILE_NOT_FOUND') ); 
 			return '';
 		} else {
-			
 			// Attempt to delete the file
 			jimport('joomla.filesystem.file');
 			if (!JFile::delete(JPATH_ROOT.$path.DS.$file)) {
@@ -817,14 +827,15 @@ class plgMembersResume extends JPlugin
 			$js->bind( array('active'=>0) );
 			if (!$js->store()) {
 				$this->setError( $js->getError() );
-			}
-			else {
+			} else {
 				// Push through to the main view
 				return $this->view($database, $option, $member, $emp);
 			}			
 		}	
 	}
+	
 	//-----------
+	
 	function onMembersShortlist( ) 
 	{
 		$oid = JRequest::getInt( 'oid', 0 );
@@ -833,13 +844,13 @@ class plgMembersResume extends JPlugin
 			$this->shortlist( $oid, $ajax=1 );
 		}
 	}
+	
 	//-----------
 	
 	function shortlist( $oid, $ajax=0 ) 
 	{
 		$juser =& JFactory::getUser();
 		if (!$juser->get('guest')) {
-
 			$database =& JFactory::getDBO();
 
 			$shortlist = new Shortlist( $database );
@@ -854,8 +865,9 @@ class plgMembersResume extends JPlugin
 				$shortlist->store();				
 			} else {
 				$shortlist->delete();				
-			}			
-			if($ajax) {			
+			}
+						
+			if ($ajax) {			
 				// get seeker info
 				$js = new JobSeeker ( $database );
 				$seeker = $js->getSeeker($oid, $juser->get('id'));
@@ -876,15 +888,15 @@ class plgMembersResume extends JPlugin
 	public function formSelect($name, $array, $value, $class='')
 	{
 		$out  = '<select name="'.$name.'" id="'.$name.'"';
-		$out .= ($class) ? ' class="'.$class.'">'.n : '>'.n;
+		$out .= ($class) ? ' class="'.$class.'">'."\n" : '>'."\n";
 		foreach ($array as $avalue => $alabel) 
 		{
 		 	$selected = ($avalue == $value || $alabel == $value)
 					  ? ' selected="selected" '
 					  : '';
-			$out .= ' <option value="'.$avalue.'"'.$selected.'>'.$alabel.'</option>'.n;
+			$out .= ' <option value="'.$avalue.'"'.$selected.'>'.$alabel.'</option>'."\n";
 		}
-		$out .= '</select>'.n;
+		$out .= '</select>'."\n";
 		return $out;
 	}
 		
@@ -892,39 +904,39 @@ class plgMembersResume extends JPlugin
 	
 	public function nicetime($date)
 	{
-		if(empty($date)) {
+		if (empty($date)) {
 			return "No date provided";
 		}
 		
-		$periods         = array("second", "minute", "hour", "day", "week", "month", "year", "decade");
-		$lengths         = array("60","60","24","7","4.35","12","10");
+		$periods = array("second", "minute", "hour", "day", "week", "month", "year", "decade");
+		$lengths = array("60","60","24","7","4.35","12","10");
 		
-		$now             = time();
-		$unix_date         = strtotime($date);
+		$now = time();
+		$unix_date = strtotime($date);
 		
 		// check validity of date
-		if(empty($unix_date)) {    
+		if (empty($unix_date)) {    
 			return "Bad date";
 		}
 	
 		// is it future date or past date
-		if($now > $unix_date) {    
-			$difference     = $now - $unix_date;
-			$tense         = "ago";
+		if ($now > $unix_date) {    
+			$difference = $now - $unix_date;
+			$tense = "ago";
 			
 		} else {
-			$difference     = $unix_date - $now;
-			//$tense         = "from now";
-			$tense         = "";
+			$difference = $unix_date - $now;
+			//$tense = "from now";
+			$tense = "";
 		}
 		
-		for($j = 0; $difference >= $lengths[$j] && $j < count($lengths)-1; $j++) {
+		for ($j = 0; $difference >= $lengths[$j] && $j < count($lengths)-1; $j++) {
 			$difference /= $lengths[$j];
 		}
 		
 		$difference = round($difference);
 		
-		if($difference != 1) {
+		if ($difference != 1) {
 			$periods[$j].= "s";
 		}
 		
@@ -936,7 +948,7 @@ class plgMembersResume extends JPlugin
 	protected function download($member)
 	{
 		// Get some needed libraries
-		ximport('xserver');
+		ximport('Hubzero_Content_Server');
 
 		$database =& JFactory::getDBO();
 		$juser    =& JFactory::getUser();
@@ -948,18 +960,18 @@ class plgMembersResume extends JPlugin
 		}
 		
 		// Incoming
-		$uid   = $member->get('uidNumber');
+		$uid = $member->get('uidNumber');
 		
 		// Load the resume
-		$resume = new Resume ($database);
+		$resume = new Resume($database);
 		$file = '';
 		$path = $this->build_path( $uid );
 				
-		if($resume->load($uid)) {
+		if ($resume->load($uid)) {
 			$file = JPATH_ROOT.$path.DS.$resume->filename;	
 		}
 		
-		if(!is_file($file)) {
+		if (!is_file($file)) {
 			JError::raiseError( 404, JText::_('FILE_NOT_FOUND') );
 			return;
 		}	
@@ -969,12 +981,12 @@ class plgMembersResume extends JPlugin
 		$default_title .= substr($resume->filename, strripos($resume->filename, '.'));;	
 		
 		// Initiate a new content server and serve up the file
-		$xserver = new XContentServer();
+		$xserver = new Hubzero_Content_Server();
 		$xserver->filename($file);
 		
 		// record view
 		$stats = new JobStats($database);
-		if($juser->get('id') != $uid ) {
+		if ($juser->get('id') != $uid ) {
 			$stats->saveView ($uid, 'seeker');
 		}
 		
@@ -983,9 +995,9 @@ class plgMembersResume extends JPlugin
 		$xserver->saveas(stripslashes($resume->title));
 		$result = $xserver->serve_attachment($file, stripslashes($default_title), false); // @TODO fix byte range support
 
- 		if (!$result)
-               JError::raiseError( 404, JText::_('SERVER_ERROR') );
+		if (!$result) {
+			JError::raiseError( 500, JText::_('SERVER_ERROR') );
+		}
 	}
-		
-	//-------------------
-}
\ No newline at end of file
+}
+
