@@ -1,25 +1,29 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Shawn Rice <zooley@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Shawn Rice <zooley@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
@@ -52,11 +56,42 @@ class plgResourcesReviews extends JPlugin
 	
 	public function &onResourcesAreas( $resource )
 	{
-		$areas = array(
-			'reviews' => JText::_('PLG_RESOURCES_REVIEWS')
-		);
+		if ($resource->_type->_params->get('plg_reviews')) {
+			$areas = array(
+				'reviews' => JText::_('PLG_RESOURCES_REVIEWS')
+			);
+		} else {
+			$areas = array();
+		}
 		return $areas;
 	}
+	
+	//-----------
+
+	public function onResourcesRateItem( $option )
+	{
+		$id = JRequest::getInt( 'rid', 0 );
+		
+		$arr = array(
+			'html'=>'',
+			'metadata'=>''
+		);
+		
+		ximport('Hubzero_View_Helper_Html');
+		ximport('Hubzero_Plugin_View');
+		
+		$database =& JFactory::getDBO();
+		$resource = new ResourcesResource($database);
+		$resource->load( $id );
+		
+		$h = new PlgResourcesReviewsHelper();
+		$h->resource = $resource;
+		$h->option = $option;
+		$h->_option = $option;
+		$h->execute();
+		
+		return $arr;
+	}
 
 	//-----------
 
@@ -75,8 +110,15 @@ class plgResourcesReviews extends JPlugin
 			}
 		}
 
+		$ar = $this->onResourcesAreas( $resource );
+		if (empty($ar)) {
+			$rtrn = '';
+		}
+
 		ximport('Hubzero_View_Helper_Html');
 		ximport('Hubzero_Plugin_View');
+		ximport('Hubzero_Comment');
+		ximport('Hubzero_User_Profile');
 
 		// Instantiate a helper object and perform any needed actions
 		$h = new PlgResourcesReviewsHelper();
@@ -92,6 +134,15 @@ class plgResourcesReviews extends JPlugin
 
 		// Are we returning any HTML?
 		if ($rtrn == 'all' || $rtrn == 'html') {
+			ximport('Hubzero_Document');
+			Hubzero_Document::addPluginStylesheet('resources', 'reviews');
+			
+			// Push some scripts to the template
+			if (is_file(JPATH_ROOT.DS.'plugins'.DS.'resources'.DS.'reviews'.DS.'reviews.js')) {
+				$document =& JFactory::getDocument();
+				$document->addScript('plugins'.DS.'resources'.DS.'reviews'.DS.'reviews.js');
+			}
+			
 			// Did they perform an action?
 			// If so, they need to be logged in first.
 			if (!$h->loggedin) {
@@ -117,8 +168,7 @@ class plgResourcesReviews extends JPlugin
 			// Thumbs voting CSS & JS
 			$voting = $this->_params->get('voting');
 			if ($voting) {
-				ximport('xdocument');
-				XDocument::addComponentStylesheet('com_answers', 'vote.css');
+				Hubzero_Document::addComponentStylesheet('com_answers', 'vote.css');
 			}
 			
 			// Pass the view some info
@@ -162,7 +212,7 @@ class plgResourcesReviews extends JPlugin
 		
 		$level++;
 
-		$hc = new XComment( $database );
+		$hc = new Hubzero_Comment( $database );
 		$comments = $hc->getResults( array('id'=>$item->id, 'category'=>$category) );
 		
 		if ($comments) {
@@ -186,6 +236,63 @@ class plgResourcesReviews extends JPlugin
 		$ra = new ReportAbuse( $database );
 		return $ra->getCount( array('id'=>$item, 'category'=>$category) );
 	}
+	
+	public function getMemberPhoto( $member, $anonymous=0 )
+	{
+		$config =& JComponentHelper::getParams( 'com_members' );
+		
+		if (!$anonymous && $member->get('picture')) {
+			$thumb  = $config->get('webpath');
+			if (substr($thumb, 0, 1) != DS) {
+				$thumb = DS.$thumb;
+			}
+			if (substr($thumb, -1, 1) == DS) {
+				$thumb = substr($thumb, 0, (strlen($thumb) - 1));
+			}
+			$thumb .= DS.plgResourcesReviews::niceidformat($member->get('uidNumber')).DS.$member->get('picture');
+			
+			$thumb = plgResourcesReviews::thumbit($thumb);
+		} else {
+			$thumb = '';
+		}
+		
+		$dfthumb = $config->get('defaultpic');
+		if (substr($dfthumb, 0, 1) != DS) {
+			$dfthumb = DS.$dfthumb;
+		}
+		$dfthumb = plgResourcesReviews::thumbit($dfthumb);
+		
+		if ($thumb && is_file(JPATH_ROOT.$thumb)) {
+			return $thumb;
+		} else if (is_file(JPATH_ROOT.$dfthumb)) {
+			return $dfthumb;
+		}
+	}
+	
+	//-----------
+	
+	public function thumbit($thumb) 
+	{
+		$image = explode('.',$thumb);
+		$n = count($image);
+		$image[$n-2] .= '_thumb';
+		$end = array_pop($image);
+		$image[] = $end;
+		$thumb = implode('.',$image);
+		
+		return $thumb;
+	}
+	
+	//-----------
+
+	public function niceidformat($someid) 
+	{
+		while (strlen($someid) < 5) 
+		{
+			$someid = 0 . "$someid";
+		}
+		return $someid;
+	}
 }
 
 //-----------
@@ -284,9 +391,9 @@ class PlgResourcesReviewsHelper extends JObject
 		}
 		
 		$database =& JFactory::getDBO();
-		ximport( 'xcomment' );
+		ximport( 'Hubzero_Comment' );
 			
-		$row = new XComment( $database );
+		$row = new Hubzero_Comment( $database );
 		if (!$row->bind( $_POST )) {
 			$this->setError( $row->getError() );
 			return;
@@ -335,8 +442,8 @@ class PlgResourcesReviewsHelper extends JObject
 		}
 		
 		// Delete the review
-		ximport( 'xcomment' );
-		$reply = new XComment( $database );
+		ximport( 'Hubzero_Comment' );
+		$reply = new Hubzero_Comment( $database );
 		
 		$comments = $reply->getResults( array('id'=>$replyid, 'category'=>'reviewcomment') );
 		if (count($comments) > 0) {
@@ -412,7 +519,7 @@ class PlgResourcesReviewsHelper extends JObject
 				$view->item = $response[0];
 				$view->display();
 			} else {				
-				$this->_redirect = JRoute::_('index.php?option='.$this->_option.'&task=reviews&id='.$rid);
+				$this->_redirect = JRoute::_('index.php?option='.$this->_option.'&id='.$rid.'&active=reviews');
 			}
 		}
 	}
@@ -581,8 +688,8 @@ class PlgResourcesReviewsHelper extends JObject
 		$review = new ResourcesReview( $database );
 		
 		// Delete the review's comments
-		ximport( 'xcomment' );
-		$reply = new XComment( $database );
+		ximport( 'Hubzero_Comment' );
+		$reply = new Hubzero_Comment( $database );
 		
 		$comments1 = $reply->getResults( array('id'=>$reviewid, 'category'=>'review') );
 		if (count($comments1) > 0) {
@@ -663,3 +770,4 @@ class PlgResourcesReviewsHelper extends JObject
 		return $_SERVER[$index];
 	}
 }
+
