@@ -1,39 +1,44 @@
 <?php
 /**
  * @package		HUBzero
- * @package		HUBzero CMS
- * @author		Nicholas J. Kisseberth <nkissebe@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Nicholas J. Kisseberth <nkissebe@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
 
-// Check to ensure this file is within the rest of the framework
-defined('JPATH_BASE') or die();
-
 function ximport($path) {
-	return JLoader::import('.' . $path, JPATH_PLUGINS . DS . "xhub" . DS . "xlibraries");
+	if (substr(strtolower($path),0,7) == 'hubzero') {
+		return JLoader::import('.' . str_replace('_', '.', $path), JPATH_ROOT . DS . 'libraries');
+	} else {
+		return JLoader::import('.' . $path, JPATH_PLUGINS . DS . "xhub" . DS . "xlibraries");
+	}
 }
 
-ximport('xfactory');
+ximport('Hubzero_Factory');
 
 jimport('joomla.application.router');
 
@@ -56,20 +61,15 @@ class XRouter extends JRouter
 	{
 		$vars = array();
 
-		$session = &JFactory::getSession();
-		$xhub = &XFactory::getHub();
+			// Get the application
+		$app =& JFactory::getApplication();
 
-		$redirect = $session->get('session.rewrite');
-
-		if (!empty($redirect))
-		{
-			$query = $uri->getQuery();
-
-			$session->clear('session.rewrite');
-
-			if (!empty($query))
-				$xhub->redirect($redirect . '?' . $query );
+		if($app->getCfg('force_ssl') == 2 && strtolower($uri->getScheme()) != 'https') {
+			//forward to https
+			$uri->setScheme('https');
+			$app->redirect($uri->toString());
 		}
+		
 
 		// Get the path
 		$path = $uri->getPath();
@@ -99,15 +99,14 @@ class XRouter extends JRouter
 		//Set the route
 		$uri->setPath(trim($path , '/'));
 		$vars += parent::parse($uri);
-		$juser = &JFactory::getUser();
-		//$xlog =& XFactory::getLogger();
 		
-		//$dbgname = $juser->get('guest')  ? 'guest' : $juser->get('username');
-		//$xlog->logDebug("Page load by $dbgname");
+		/* HUBzero Extensions Follow to force registration and email confirmation */
+		
+		$juser = &JFactory::getUser();
 
 		if (!$juser->get('guest'))
 		{
-			$xhub =& XFactory::getHub();
+			$xhub =& Hubzero_Factory::getHub();
 			$session =& JFactory::getSession();
 			$registration_incomplete = $session->get('registration.incomplete');
 
@@ -128,7 +127,12 @@ class XRouter extends JRouter
 				{
 					$vars = array();
 					$vars['option'] = 'com_register';
-					$vars['task'] = 'update';
+					
+					if ($juser->get('tmp_user'))
+						$vars['task'] = 'create';
+					else
+						$vars['task'] = 'update';
+					
 					$vars['act'] = '';
 				
 					$this->setVars($vars);
@@ -137,17 +141,10 @@ class XRouter extends JRouter
 				}
 			}
 
-			$xprofile = &XFactory::getProfile();
+			$xprofile = &Hubzero_Factory::getProfile();
 
 			if (is_object($xprofile) && ($xprofile->get('emailConfirmed') != 1) && ($xprofile->get('emailConfirmed') != 3))
 			{
-				/*if ($vars['option'] == 'com_email') 
-				{
-					if (!empty($vars['task']))
-					if ( ($vars['task'] == 'unconfirmed') || ($vars['task'] == 'change') || ($vars['task'] == 'resend') || ($vars['task'] == 'confirm') )
-						return $vars;
-				}
-				else*/
 				if ($vars['option'] == 'com_hub')
 				{
 					if (!empty($vars['task']))
@@ -169,9 +166,7 @@ class XRouter extends JRouter
 				}
 
 				$vars = array();
-				//$vars['option'] = 'com_email';
 				$vars['option'] = 'com_register';
-				//$vars['view'] = 'registration';
 				$vars['task'] = 'unconfirmed';
 
 				$this->setVars($vars);
@@ -252,7 +247,9 @@ class XRouter extends JRouter
 		if(count($this->getVars()) == 1)
 		{
 			$item = $menu->getItem($this->getVar('Itemid'));
-			$vars = $vars + $item->query;
+			if($item !== NULL && is_array($item->query)) {
+				$vars = $vars + $item->query;
+			}
 		}
 
 		// Set the active menu item
@@ -263,176 +260,209 @@ class XRouter extends JRouter
 
 	function _parseSefRoute(&$uri)
 	{
-		$menu =& JSite::getMenu(true);
-		$route = ltrim($uri->getPath(), '/');
+		$vars   = array();
+
+		$menu  =& JSite::getMenu(true);
+		$route = $uri->getPath();
+
+		//Get the variables from the uri
 		$vars = $uri->getQuery(true);
 
-		if (empty($route) && empty($vars['option']))
-			$route = 'home';
+		//Handle an empty URL (special case)
+		if(empty($route))
+		{
+
+			//If route is empty AND option is set in the query, assume it's non-sef url, and parse apropriately
+			if(isset($vars['option']) || isset($vars['Itemid'])) {
+				return $this->_parseRawRoute($uri);
+			}
+
+			$item = $menu->getDefault();
+
+			//Set the information in the request
+			$vars = $item->query;
+
+			//Get the itemid
+			$vars['Itemid'] = $item->id;
+
+			// Set the active menu item
+			$menu->setActive($vars['Itemid']);
+
+			return $vars;
+		}
+
+
+		/*
+		 * Parse the application route
+		 */
 		
-		//Need to reverse the array (highest sublevels first)
-		$items = array_reverse($menu->getMenu());
-		$mlen = 0;
-
-		foreach ($items as $item)
+		if(substr($route, 0, 9) == 'component')
 		{
-			$lenght = strlen($item->route); //get the lenght of the route
+			$segments	= explode('/', $route);
+			$route      = str_replace('component/'.$segments[1], '', $route);
 
-			if(($lenght > $mlen) && strpos($route.'/', $item->route.'/') === 0 && $item->type != 'menulink')
-			{
-				$mlen = $lenght;
-				$mitem = $item;
-			}
+			$vars['option'] = 'com_'.$segments[1];
+			$vars['Itemid'] = null;
 		}
-
-		if (!empty($mitem)) // route matches a menu path
+		else
 		{
-			// TODO: review this section as it may be trying to handle
-			// situations that may no longer exist
+			//Need to reverse the array (highest sublevels first)
+			$items = array_reverse($menu->getMenu());
 
-			$remainder = substr($route, $mlen+1);
-			if (empty($remainder) || ($mitem->type == 'component' && $mitem->component != 'com_content'))
-                        {
-			if (($mitem->type == 'component') || empty($remainder))
-				$route = $remainder;
-
-			$vars = $mitem->query;
-
-			if (!empty($mitem->component))
+			foreach ($items as $item)
 			{
-				$vars['option'] = $mitem->component;
+				$lenght = strlen($item->route); //get the lenght of the route
 
-				if (empty($vars['Itemid']))
-					$vars['Itemid'] = $mitem->id;
-			}
-			else if (empty($route))
-			{
-				$route = trim($mitem->link,'/');
+				if($lenght > 0 && strpos($route.'/', $item->route.'/') === 0 && $item->type != 'menulink') 
+				{
+					// HUBzero Extension to pass local URLs through menu unchanged
+					
+					if ($item->type == 'url') { // Pass local URLs through, but record Itemid
+						if (strpos("://",$item->route[0]) === false) {
+							$vars['Itemid'] = $item->id;
+							break;
+						}
+					}
+					
+					// End HUBzero Extension to pass local URLs through menu unchanged
 				
-				if (empty($vars['Itemid']))
-					$vars['Itemid'] = $mitem->id;
+					$route   = substr($route, $lenght);
+
+					$vars['Itemid'] = $item->id;
+					$vars['option'] = $item->component;
+					break;
+				}
 			}
 		}
+	
+		// HUBzero Extension to parse com_content component specially
+
+		if (empty($vars['option'])) {
+			$vars = $this->_parseContentRoute(explode('/',ltrim($route,"/")));
+			if (!empty($vars['option'])) {
+				$route = false;
+			}
 		}
 
-		$segments = explode('/', $route);
+		// End HUBzero Extension to parse com_content component specially
 
-		if (empty($segments[0]))
-			array_shift($segments);
-
-		if (empty($vars['option']))
-		{
-			if (substr($route, 0, 10) == 'component/')
-			{
-				$route = ltrim( str_replace('component/'.$segments[1], '', $route), '/');
-				$vars['option'] = 'com_'.$segments[1];
-				array_shift($segments);
-				array_shift($segments);
-			}
-			else if ($route == 'logout')
-			{
-				$vars['option'] = 'com_hub';
-			}
-			else if ($route == 'login')
-			{
-				$vars['option'] = 'com_hub';
-			}
-			//else if ($route == 'register' || substr($route, 0, strlen('registration')) == 'registration' || $route == 'lostusername' || $route == 'lostpassword')
-			else if ($route == 'lostusername' || $route == 'lostpassword')
-			{
-				$vars['option'] = 'com_hub';
-			}
-			else if (substr($route, 0, 6) == 'search')
-				$vars['option'] = 'com_xsearch';
-		}
-
-		// Set the active menu item
-		if ( isset($vars['Itemid']) )
-			$menu->setActive( $vars['Itemid'] );
+		// HUBzero Extension to route based on unprefixed component name (if other routing fails to match)
 
 		if (empty($vars['option']))
 		{
+			$segments	= explode('/', $route);
+			
 			$file = JPATH_BASE.DS.'components'.DS.'com_'.$segments[0].DS.$segments[0].".php";
 		
 			if (file_exists($file)) 
 			{
-				$vars['option'] = 'com_' . $segments[0];
-				array_shift($segments);
+				$vars['option'] = 'com_'.$segments[0];
+				
+				if (!isset($vars['Itemid'])) {
+					$vars['Itemid'] = null;
+				}
+			
+				$route = preg_replace('/^' . $segments[0]. '/', '', $route);
 			}
 		}
 
-		if (empty($vars['option']) || $vars['option'] == 'com_content')
-			$vars = array_merge($vars, $this->_parseContentRoute($segments));
+		// End HUBzero Extension to route based on unprefixed component name (if other routing fails to match)
+		
+		// Set the active menu item
+		if ( isset($vars['Itemid']) ) {
+			$menu->setActive(  $vars['Itemid'] );
+		}
 
-		// Handle component route
- 
- 		if( !empty($vars['option']) && (($vars['option'] != 'com_content') || (!empty($route))))
+		//Set the variables
+		$this->setVars($vars);
+
+		/*
+		 * Parse the component route
+		 */
+		if(!empty($route) && isset($this->_vars['option']) )
 		{
-			$component = preg_replace('/[^A-Z0-9_\.-]/i', '', $vars['option']);
+			$segments = explode('/', $route);
+			array_shift($segments);
+
+			// Handle component	route
+			$component = preg_replace('/[^A-Z0-9_\.-]/i', '', $this->_vars['option']);
+
 			// Use the component routing handler if it exists
-			$path = JPATH_BASE.DS.'components'.DS.$component.DS.'router.php';
-			
-			if (file_exists($path))
+			$path = JPATH_SITE.DS.'components'.DS.$component.DS.'router.php';
+
+			if (file_exists($path) && count($segments))
 			{
-				//decode the route segments
-				//$segments = $this->_decodeSegments($segments);
+				if ($component != "com_search") { // Cheap fix on searches
+					//decode the route segments
+					if ($component == "com_content") { // @FIXME: HUBZERO don't do : to - conversion except in com_content
+						$segments = $this->_decodeSegments($segments);
+					}
+				}
+				else { // fix up search for URL
+					$total = count($segments);
+					for($i=0; $i<$total; $i++) {
+						// urldecode twice because it is encoded twice
+						$segments[$i] = urldecode(urldecode(stripcslashes($segments[$i])));
+					}
+				}
 
 				require_once $path;
-				$function = substr($component, 4).'ParseRoute';
+				$function =  substr($component, 4).'ParseRoute';
+				$vars =  $function($segments);
 
-				if (count($segments) || ($component != 'com_content'))
-					$vars = array_merge($vars, $function($segments));
-
-				// handle rerouting to symbolic com_content content
-
-				if (!empty($vars['option']) && ($vars['option'] == 'com_content') && (!empty($vars['route'])))
-					$vars = array_merge($vars, $this->_parseContentRoute(explode('/',ltrim($vars['route'],"/"))));
+				$this->setVars($vars);
 			}
 		}
 		else
 		{
+			// HUBzero Extension to check redirection table if otherwise unable to match URL to content
+			
+			if (!isset($vars['option'])) {
+				jimport('joomla.juri');
+				$db =& JFactory::getDBO();
+				$sql = "SELECT * FROM #__redirection WHERE oldurl=" . $db->Quote($route);
+	        	$db->setQuery($sql);
+	        	$row =& $db->loadObject();
+
+				if (!empty($row))
+				{
+					$myuri = JURI::getInstance( $row->newurl );
+					$vars = $myuri->getQuery(true);
+				
+					if ( isset($vars['Itemid']) ) {
+						$menu->setActive(  $vars['Itemid'] );
+					}
+				}
+			}
+
+			// End HUBzero Extension to check redirection table if otherwise unable to match URL to content
+			
 			//Set active menu item
-			if($item =& $menu->getActive())
-				$vars = array_merge($vars, $item->query);
-		}
-
-		if (empty($vars['Itemid']))
-		{
-		 	$item =& $menu->getActive();
-
-			if (empty($item))
-			{
-				$item = $menu->getDefault();
-				$menu->setActive( $item->id );
+			if($item =& $menu->getActive()) {
+				$vars = $item->query;
 			}
 			
-			$vars['Itemid'] = $item->id;
+		
 		}
+		
+		// HUBzero Extension to pass common query parameters to apache (for logging)
+
+		if (!empty($vars['option']))
+			apache_note('component',$vars['option']);
+		if (!empty($vars['view']))
+			apache_note('view',$vars['view']);
+		if (!empty($vars['task']))
+			apache_note('task',$vars['task']);
+		if (!empty($vars['action']))
+			apache_note('action',$vars['action']);
+		if (!empty($vars['id']))
+			apache_note('action',$vars['id']);
 			
-		if (empty($vars['option']))
-		{
-			jimport('joomla.juri');
-			$db =& JFactory::getDBO();
-			$sql = "SELECT * FROM #__redirection WHERE oldurl=" . $db->Quote($route);
-		        $db->setQuery($sql);
-		        $row =& $db->loadObject();
-
-			if (!empty($row))
-			{
-				$myuri = JURI::getInstance( $row->newurl );
-				$vars = $myuri->getQuery(true);
-			}
-			else
-				JError::raiseError(404, JText::_("Page Not Found"));
-		}
-
-		$this->setVars($vars);
-	
-		//Set the variables
-
-		return $this->_vars;
+		// End HUBzero Extension pass common query parameters to apache (for logging)
+		
+		return $vars;
 	}
-
+	
 	function _buildRawRoute(&$uri)
 	{
 	}
@@ -446,6 +476,29 @@ class XRouter extends JRouter
 		$query = $uri->getQuery(true);
 
 		if(!isset($query['option'])) {
+			// HUBzero Extension to handle section, category, alias routing of com_content pages
+			
+			$parts = $this->_buildContentRoute($query);
+			
+			if (empty($parts)) {
+				return;
+			}
+			
+			$query['option'] = 'com_content';
+			$parts = $this->_encodeSegments($parts);
+			$result	= implode('/', $parts);
+			$tmp	= ($result != "") ? '/'.$result : '';
+			//$tmp = 'component/'.substr($query['option'], 4).'/'.$tmp;
+			$route .= '/'.$tmp;
+
+			// Unset unneeded query information
+			unset($query['Itemid']);
+			unset($query['option']);
+
+			//Set query again in the URI
+			$uri->setQuery($query);
+			$uri->setPath($route);
+			// End HUBzero Extension to handle section, category, alias routing of com_content pages
 			return;
 		}
 
@@ -454,8 +507,8 @@ class XRouter extends JRouter
 		/*
 		 * Build the component route
 		 */
-		$component = preg_replace('/[^A-Z0-9_\.-]/i', '', $query['option']);
-		$tmp = '';
+		$component	= preg_replace('/[^A-Z0-9_\.-]/i', '', $query['option']);
+		$tmp 		= '';
 
 		// Use the component routing handler if it exists
 		$path = JPATH_BASE.DS.'components'.DS.$component.DS.'router.php';
@@ -464,34 +517,44 @@ class XRouter extends JRouter
 		if (file_exists($path) && !empty($query))
 		{
 			require_once $path;
-			$function = substr($component, 4).'BuildRoute';
-			$parts = $function($query);
+			$function	= substr($component, 4).'BuildRoute';
+			$parts		= $function($query);
 
 			// encode the route segments
-			if ($component == 'com_content')
-				$parts = $this->_encodeSegments($parts);
-
-			$result = implode('/', $parts);
-			$tmp = ($result != "") ? '/'.$result : '';
+			if ($component != "com_search") { // Cheep fix on searches
+				if ($component == "com_content") { // @FIXME: quick fix for joomla breaking ':' in urls in com_wiki/com_topics (others?) {
+					$parts = $this->_encodeSegments($parts);
+				}
+			}
+			else { // fix up search for URL
+				$total = count($parts);
+				for($i=0; $i<$total; $i++) {
+					// urlencode twice because it is decoded once after redirect
+					$parts[$i] = urlencode(urlencode(stripcslashes($parts[$i])));
+				}
+			}
+			
+			$result	= implode('/', $parts);
+			$tmp	= ($result != "") ? '/'.$result : '';
 		}
 
 		/*
 		 * Build the application route
 		 */
-		if (!empty($query['Itemid']))
+		$built = false;
+		if (isset($query['Itemid']) && !empty($query['Itemid']))
 		{
 			$item = $menu->getItem($query['Itemid']);
 
-			if (!empty($item) && $query['option'] == $item->component) {
+			if (is_object($item) && $query['option'] == $item->component) {
 				$tmp = !empty($tmp) ? $item->route.'/'.$tmp : $item->route;
+				$built = true;
 			}
 		}
-		else
-		{
+
+		if(!$built) {
 			//$tmp = 'component/'.substr($query['option'], 4).'/'.$tmp;
-			if ($component != 'com_hub') {
-				$tmp = substr($query['option'], 4).'/'.$tmp;
-			}
+			$tmp = substr($query['option'], 4).'/'.$tmp; /* HUBZERO: strip 'component' from url */
 		}
 
 		$route .= '/'.$tmp;
@@ -573,9 +636,9 @@ class XRouter extends JRouter
 
 		if(is_null($itemid))
 		{
-			if($option = $uri->getVar('option'))
+			if($option	= $uri->getVar('option'))
 			{
-				$item = $menu->getItem($this->getVar('Itemid'));
+				$item	= $menu->getItem($this->getVar('Itemid'));
 				if(isset($item) && $item->component == $option) {
 					$uri->setVar('Itemid', $item->id);
 				}
@@ -599,7 +662,6 @@ class XRouter extends JRouter
 				$uri->setVar('option', $item->component);
 			}
 		}
-
 		return $uri;
 	}
 
@@ -647,7 +709,8 @@ class XRouter extends JRouter
 
 			unset($query['view']);
 			unset($query['id']);
-
+			unset($query['catid']);
+			
 			return $segments;
 		}
 		else {
@@ -729,7 +792,7 @@ class XRouter extends JRouter
 			array_shift($segments);
 	
 		//decode the route segments
-		$segments = $this->_decodeSegments($segments);
+		//$segments = $this->_decodeSegments($segments);
 		$count = count($segments);
 		
 		if ($count > 3) {
@@ -789,31 +852,15 @@ class XRouter extends JRouter
 			$page = $segments[0];
 			$category = $segments[0];
 			$section = $segments[0];
-			//$routesegments = explode('/', $item->route);
-			//$rcount = count($routesegments);
-			//if ($rcount > 1) {
-			//	$category = $routesegments[$rcount-1];
-			//	$section = $routesegments[$rcount-2];
-			//} 
-			//else if ($rcount > 0) {
-			//	$category = $routesegments[$rcount-1];
-			//	$section = $routesegments[$rcount-1];
-			//}
 
-			$queryn = "SELECT #__content.id from `#__content`, `#__categories`, `#__sections` WHERE " .
-				"#__content.alias='" . $page . "' AND " .
-				"#__content.catid=#__categories.id AND " .
-				"#__categories.alias='" . $category . "' AND " .
-				"#__categories.section=#__sections.id AND " .
-				"#__sections.alias='" . $section . "' AND #__content.state='1' LIMIT 1;";
-				$query = "SELECT #__content.id from `#__content`, `#__categories`, `#__sections` WHERE " .
+			$query = "SELECT #__content.id from `#__content`, `#__categories`, `#__sections` WHERE " .
 				"#__content.alias='" . $page . "' AND " .
 				"(" .
-				"(#__content.catid=#__categories.id AND " . "#__categories.alias='" . $category . "' AND " .
-				"#__content.sectionid=#__sections.id AND " . "#__sections.alias='" . $section . "')" .
-					 " OR " .
-					 "(#__content.catid=0 AND #__content.sectionid=0) " .
-					 ") AND #__content.state='1' LIMIT 1;";
+					"(#__content.catid=#__categories.id AND " . "#__categories.alias='" . $category . "' AND " .
+					"#__content.sectionid=#__sections.id AND " . "#__sections.alias='" . $section . "')" .
+					" OR " .
+					"(#__content.catid=0 AND #__content.sectionid=0) " .
+				") AND #__content.state='1' LIMIT 1;";
 
 		}
 		else if ($count == 0)
@@ -864,29 +911,6 @@ class XRouter extends JRouter
 
 		return array();
 	}
-
-	/**
-	 * Returns a reference to the global Router object, only creating it
-	 * if it doesn't already exist.
-	 *
-	 * This method must be invoked as:
-	 *	<pre> $router = &JRouter::getInstance();</pre>
-	 *
-	 * @access public
-	 * @return JRouter The Router object.
-	 * @since 1.5
-	 */
-
-	function &getInstance($options = array())
-	{
-		static $instance;
-
-		if (!is_object($instance))
-			$instance = new XRouter($options);
-
-		return $instance;
-	}
-
 }
 
 jimport('joomla.event.plugin');
@@ -907,10 +931,32 @@ class plgSystemXhub extends JPlugin
 		parent::__construct($subject, NULL);
 	}
 
+        function onAfterRoute()
+        {
+                $app = &JFactory::getApplication();
+                JHTML::_('behavior.mootools');
+                $jdocument =& JFactory::getDocument();
+                $template = $app->getTemplate();
+                $router = &$app->getRouter();
+ 
+                if (get_class($router) == 'XRouter')
+                {
+                        if (file_exists( JPATH_ROOT . '/templates/' . $template . '/js/hub.js' ))
+                                $jdocument->addScript('/templates/' . $template . '/js/hub.js');
+                        else
+                                $jdocument->addScript('/components/com_hub/js/hub.js');
+ 
+                        if (file_exists( JPATH_ROOT . '/templates/' . $template . '/css/main.css'))
+                                $jdocument->addStyleSheet('/templates/' . $template . '/css/main.css');
+                        else
+                                $jdocument->addStyleSheet('/components/com_hub/css/main.css');
+                }
+        }
+
 	function onAfterInitialise()
 	{
-		jimport('joomla.database.table');
-		ximport('xsession');
+		//jimport('joomla.database.table');
+		ximport('Hubzero_Session_Helper');
 
 		$app = &JFactory::getApplication();
 		$router = &$app->getRouter();
@@ -924,27 +970,13 @@ class plgSystemXhub extends JPlugin
 
 		// Create a JRouter object
 		if (get_class($router) == 'JRouterSite') {
-			$router = XRouter::getInstance($options);
+			$router = new XRouter($options);
 			$router->setMode($app->getCfg('sef'));
-			JHTML::_('behavior.mootools');
-			$jdocument =& JFactory::getDocument();
-			$template = $app->getTemplate();
-
-			if (file_exists( JPATH_ROOT . '/templates/' . $template . '/js/hub.js' ))
-				$jdocument->addScript('/templates/' . $template . '/js/hub.js');
-			else
-				$jdocument->addScript('/components/com_hub/js/hub.js');
-
-			if (file_exists( JPATH_ROOT . '/templates/' . $template . '/css/main.css'))
-				$jdocument->addStyleSheet('/templates/' . $template . '/css/main.css');
-			else
-				$jdocument->addStyleSheet('/components/com_hub/css/main.css');
 		}
 
-
 		// Get the session object
 		$session =& JFactory::getSession();
-
+		$sid = $session->getId();
 		$start = $session->get('session.timer.start');
 		$now = $session->get('session.timer.now');
 		$last = $session->get('session.timer.last');
@@ -954,40 +986,33 @@ class plgSystemXhub extends JPlugin
 		$lifetime = $app->getCfg('lifetime') * 60;
 		$expired = ($now - $last) >= $lifetime;
 		$newsession = ($start == $now) && ($start == $last);
-		$knownsession = !empty($_COOKIE[$sname]) && $_COOKIE[$sname] == $session->getId();
+		$knownsession = !empty($_COOKIE[$sname]) && $_COOKIE[$sname] == $sid;
 
 		$table = & JTable::getInstance('session');
-		$table->load( $session->getId() );
-		XSessionHelper::purge();
+		$table->load($sid);
+		Hubzero_Session_Helper::purge();
 
-		/*
-		if (!empty($_COOKIE[$sname]) && $_COOKIE[$sname] != $session->getId())
+		$myuser = $session->get('user');
+		$jid = (is_object($myuser)) ? $myuser->get('id') : '0';
+
+		if (empty($jid))
 		{
-			echo "DETECTED LOGIN SESSION CHANGE.<br>";
-			echo "OLD SESSION: $_COOKIE[$sname].<br>";
-			echo "NEW SESSION: " . $session->getId() . "<br>";
+			apache_note('userid','-');
+			apache_note('auth','-');
 		}
-		*/
-
-		/*
-		if (($newsession && $knownsession) || $expired) // joomla started a new session or session is stale
+		else
 		{
-			if (empty($table->data)) {
-				//$table->delete(); // delete the expired or improperly restarted session
-				//session_regenerate_id();
-				//unset($_COOKIE[$sname]); // make this appear as a new session below
-				//$xtable->ip = $_SERVER['REMOTE_ADDR'];
-				//$table->insert($session->getId(),0);
-				//$xtable->insert($session->getId(),0);
-				XSessionHelper::set_ip($session->getId(), $_SERVER['REMOTE_ADDR']);
-			} 
+			apache_note('userid',$jid);
+			apache_note('auth','session');
 		}
-		*/
 
-		if ( empty($_COOKIE[$sname]) ) // new session, log it
+		apache_note('jsession',$sid);
+
+		if ( empty($jid) )
 		{
-			ximport('xlog');
+			ximport('Hubzero_Log');
 			jimport('joomla.utilities.utility');
+			jimport('joomla.user.helper');
 			$hash = JUtility::getHash('XHUB_REMEMBER');
 			$username = '-';
 			if ($str = JRequest::getString($hash, '', 'cookie', JREQUEST_ALLOWRAW | JREQUEST_NOTRIM))
@@ -1000,29 +1025,32 @@ class plgSystemXhub extends JPlugin
 				$crypt = new JSimpleCrypt($key);
 				$str = $crypt->decrypt($str);
 				$user = unserialize($str);
+				// We should store userid not username in cookie, will save us a database query here
 				$username = $user['username'];
+				
+				if ($id = JUserHelper::getUserId($id)) {
+					$myuser = JUser::getInstance($id);
+					if (is_object($myuser))
+					{
+						apache_note('userid',$myuser->get('id'));
+						apache_note('auth','cookie');
+                    $authlog = Hubzero_Factory::getAuthLogger();
+                    	$authlog->logAuth( $username . ' ' . $_SERVER['REMOTE_ADDR'] . ' detect');
+					}
+				}
 			}
-
-			$authlog = XFactory::getAuthLogger();
-			$authlog->logAuth( $username . ' ' . $_SERVER['REMOTE_ADDR'] . ' detect');
 		}
 
-		// drop/refresh an xhub session tracker cookie
-	
-		// jimport('joomla.utilities.utility');
-		// setcookie( JUtility::getHash('XHUB_TRACKER'), $session->getId(), $lifetime, '/' );
-	
-		//setcookie('b3192990284393a84bff56f22eb7042d', $session->getId(), $lifetime, '/' );
-
-		XSessionHelper::set_ip($session->getId(), $_SERVER['REMOTE_ADDR']);
+		Hubzero_Session_Helper::set_ip($session->getId(), $_SERVER['REMOTE_ADDR']);
 	}
 
 	function onLoginFailure($response)
 	{
-		$authlog = XFactory::getAuthLogger();
+		$authlog = Hubzero_Factory::getAuthLogger();
 		$authlog->logAuth( $_POST['username'] . ' ' . $_SERVER['REMOTE_ADDR'] . ' invalid');
+		apache_note('auth','invalid');
 
-		return true; /* we expect the Joomla user plugin to handle the rest */
+		return true;
 	}
 }
 
