@@ -1,3 +1,10 @@
+/**
+ * @package     hubzero-cms
+ * @file        plugins/tageditor/autocompleter.js
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
+ */
+
 /**
  * Autocompleter
  *
@@ -598,7 +605,7 @@ HUB.CompleteTags = {
 		if (el) {
 			var actags = new AppleboxList(el, {'hideempty': false, 'resizable': {'step': 8}});
 			
-			var completer2 = new Autocompleter.MultiSelectable.Ajax.Json($('maininput'), 'index2.php?option=com_tags&no_html=1&task=autocomplete', {
+			var completer2 = new Autocompleter.MultiSelectable.Ajax.Json($('maininput'), '/index.php?option=com_tags&no_html=1&task=autocomplete', {
 				'tagger': actags,
 				'minLength': 1, // We wait for at least one character
 				'overflow': true, // Overflow for more entries
@@ -610,4 +617,4 @@ HUB.CompleteTags = {
 
 //----------------------------------------------------------
 
-window.addEvent('domready', HUB.CompleteTags.initialize);
\ No newline at end of file
+window.addEvent('domready', HUB.CompleteTags.initialize);
