@@ -1,25 +1,29 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Shawn Rice <zooley@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Shawn Rice <zooley@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
@@ -343,7 +347,7 @@ class plgUsageChart extends JPlugin
 
 	protected function outputData($option, $label, $db, $id, $period, $datetime) 
 	{
-		include_once( JPATH_ROOT.DS.'plugins'.DS.'xhub'.DS.'xlibraries'.DS.'ofc'.DS.'php-ofc-library'.DS.'open-flash-chart.php' );
+		include_once( JPATH_ROOT.DS.'libraries'.DS.'ofc'.DS.'php-ofc-library'.DS.'open-flash-chart.php' );
 		
 		// ------
 		// Chart 1
@@ -442,9 +446,9 @@ class plgUsageChart extends JPlugin
 		
 		$js = '
 		window.addEvent("domready", function(){
-			swfobject.embedSWF("/plugins/xhub/xlibraries/ofc/open-flash-chart.swf", "chart1", "600", "350", "9.0.0", "expressInstall.swf", {"get-data":"get_data_1"});
-			swfobject.embedSWF("/plugins/xhub/xlibraries/ofc/open-flash-chart.swf", "chart2", "300", "300", "9.0.0", "expressInstall.swf", {"get-data":"get_data_2"});
-			swfobject.embedSWF("/plugins/xhub/xlibraries/ofc/open-flash-chart.swf", "chart3", "300", "300", "9.0.0", "expressInstall.swf", {"get-data":"get_data_3"});
+			swfobject.embedSWF("/libraries/ofc/open-flash-chart.swf", "chart1", "600", "350", "9.0.0", "expressInstall.swf", {"get-data":"get_data_1"});
+			swfobject.embedSWF("/libraries/ofc/open-flash-chart.swf", "chart2", "300", "300", "9.0.0", "expressInstall.swf", {"get-data":"get_data_2"});
+			swfobject.embedSWF("/libraries/ofc/open-flash-chart.swf", "chart3", "300", "300", "9.0.0", "expressInstall.swf", {"get-data":"get_data_3"});
 		});
 		
 		var ig = '.(count($data['points']) - 1).';
@@ -468,8 +472,8 @@ class plgUsageChart extends JPlugin
 		{
 			ig = index;
 
-			swfobject.embedSWF("/plugins/xhub/xlibraries/ofc/open-flash-chart.swf", "chart2", "300", "300", "9.0.0", "expressInstall.swf", {"get-data":"get_data_2"});
-			swfobject.embedSWF("/plugins/xhub/xlibraries/ofc/open-flash-chart.swf", "chart3", "300", "300", "9.0.0", "expressInstall.swf", {"get-data":"get_data_3"});
+			swfobject.embedSWF("/libraries/ofc/open-flash-chart.swf", "chart2", "300", "300", "9.0.0", "expressInstall.swf", {"get-data":"get_data_2"});
+			swfobject.embedSWF("/libraries/ofc/open-flash-chart.swf", "chart3", "300", "300", "9.0.0", "expressInstall.swf", {"get-data":"get_data_3"});
 		}
 		
 		var data = new Array();
@@ -549,9 +553,9 @@ class plgUsageChart extends JPlugin
 		//$monthsReverse = $this->monthsReverse;
 
 		$document =& JFactory::getDocument();
-		if (is_file('plugins'.DS.'xhub'.DS.'xlibraries'.DS.'ofc'.DS.'js'.DS.'swfobject.js')) {
-			$document->addScript('plugins'.DS.'xhub'.DS.'xlibraries'.DS.'ofc'.DS.'js'.DS.'json'.DS.'json2.js');
-			$document->addScript('plugins'.DS.'xhub'.DS.'xlibraries'.DS.'ofc'.DS.'js'.DS.'swfobject.js');
+		if (is_file('libraries'.DS.'ofc'.DS.'js'.DS.'swfobject.js')) {
+			$document->addScript(DS.'libraries'.DS.'ofc'.DS.'js'.DS.'json'.DS.'json2.js');
+			$document->addScript(DS.'libraries'.DS.'ofc'.DS.'js'.DS.'swfobject.js');
 			//$document->addScriptDeclaration("window.addEvent('domready', HUB.Usage.loadOFC);");
 		}
 
