@@ -1,25 +1,29 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Shawn Rice <zooley@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Shawn Rice <zooley@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
@@ -74,7 +78,7 @@ class plgUsageOverview extends JPlugin
 	
 	private function _check_for_data(&$db, $yearmonth, $period) 
 	{
-	   	$sql = "SELECT COUNT(datetime) FROM totalvals WHERE datetime LIKE '" . mysql_escape_string($yearmonth) . "-%' AND period = '" . mysql_escape_string($period) . "'";
+	   	$sql = "SELECT COUNT(datetime) FROM summary_user_vals WHERE datetime LIKE '" . mysql_escape_string($yearmonth) . "-%' AND period = '" . mysql_escape_string($period) . "'";
 		$db->setQuery( $sql );
 		$result = $db->loadResult();   	
 
@@ -102,7 +106,19 @@ class plgUsageOverview extends JPlugin
 				if ($i == 1) {
 					$cls = ' class="highlight"';
 				}
-				$html .= "\t\t\t".'<td'.$cls.'>'.trim($this->_fmt_result($row->value,$row->valfmt)).'</td>'."\n";
+				if ($i == 2)
+                    $res_iden = $row->value;
+                if ($i == 7)
+                    $org_iden = $row->value;
+
+                if ($i == 3 || $i == 4 || $i == 5 || $i == 6) {
+                    $val = ($row->value/$res_iden) * 100;
+                } else if ($i == 8 || $i == 9 || $i == 10 || $i == 11) {
+                    $val = ($row->value/$org_iden) * 100;
+                } else {
+                    $val = $row->value;
+				}
+				$html .= "\t\t\t".'<td'.$cls.'>'.trim($this->_fmt_result($val,$row->valfmt)).'</td>'."\n";
 			}
 		}
 		if ($i == 1) {
@@ -190,8 +206,18 @@ class plgUsageOverview extends JPlugin
 			$value = number_format($value).$valfmt[$fmt];
 			return $value;
 		} else if ($fmt == 5) {
-			$value = number_format(($value/86400)).' '.$valfmt[$fmt];
-			return $value;
+			if ($value < '60') {
+                $val = number_format($value).' seconds';
+            } else if ($value >= '60' && $value < '3600') {
+                $val = number_format($value/60).' minutes';
+            } else if ($value >= '3600'  && $value < '86400') {
+                $val = number_format($value/3600).' hours';
+            } else if ($value >= '86400') {
+                $val = number_format($value/86400).' days';
+            } else {
+                $val = number_format($value);
+            }
+            return $val;
 		} else if ($fmt == 6) {
 			return $value;
 		} else {
@@ -256,7 +282,7 @@ class plgUsageOverview extends JPlugin
 		$selectedPeriod = JRequest::getVar('selectedPeriod', '');
 		
 		if (!$selectedPeriod) {
-	        $sql = "SELECT MAX(datetime) FROM summary_collab_vals";
+	        $sql = "SELECT MAX(datetime) FROM summary_misc_vals";
 			$db->setQuery( $sql );
 			$lastdate = $db->loadResult();
 	        if ($lastdate) {
@@ -513,9 +539,9 @@ class plgUsageOverview extends JPlugin
 		$html .= '</form>'."\n";
 
 		//--------------------------------
-
+		$tbl_cnt = 0;
 		$html .= '<table summary="'.JText::_('A break-down of site visitors.').'">'."\n";
-		$html .= "\t".'<caption>'.JText::_('Table 1: User statistics').'</caption>'."\n";
+		$html .= "\t".'<caption>'.JText::_('Table '.++$tbl_cnt.': User statistics').'</caption>'."\n";
 		$html .= "\t".'<thead>'."\n";
 		$html .= "\t\t".'<tr>'."\n";
 		$html .= "\t\t\t".'<th scope="col" rowspan="2" colspan="2">'.JText::_('Users').'</th>'."\n";
@@ -584,7 +610,7 @@ class plgUsageOverview extends JPlugin
 
 		// Start simulation Usage
 		$html .= '<table summary="'.JText::_('Simulation Usage').'">'."\n";
-		$html .= "\t".'<caption>'.JText::_('Table 2: Simulation Usage').'</caption>'."\n";
+		$html .= "\t".'<caption>'.JText::_('Table '.++$tbl_cnt.': Simulation Usage').'</caption>'."\n";
 		$html .= "\t".'<tbody>'."\n";
 		$sql = "SELECT a.label,b.value,b.valfmt,a.plot,a.id FROM summary_simusage AS a, summary_simusage_vals AS b WHERE a.id=b.rowid AND b.period = '".$period."' AND b.datetime = '".$datetime."' ORDER BY a.id";
 		$db->setQuery( $sql );
@@ -630,7 +656,7 @@ class plgUsageOverview extends JPlugin
 
 		// Start miscellaneous
 		$html .= '<table summary="'.JText::_('Miscellaneous Statistics').'">'."\n";
-		$html .= "\t".'<caption>'.JText::_('Table 3: Miscellaneous Statistics').'</caption>'."\n";
+		$html .= "\t".'<caption>'.JText::_('Table '.++$tbl_cnt.': Miscellaneous Statistics').'</caption>'."\n";
 		$html .= "\t".'<tbody>'."\n";
 		$sql = "SELECT a.label,b.value,b.valfmt FROM summary_misc AS a, summary_misc_vals AS b WHERE a.id=b.rowid AND b.period = '".$period."' AND b.datetime = '".$datetime."' ORDER BY a.id";
 		$db->setQuery( $sql );
@@ -658,10 +684,10 @@ class plgUsageOverview extends JPlugin
 		$html .= "\t".'</tbody>'."\n";
 		$html .= '</table>'."\n";
 		
-		
+	/*	
 		// "and more" Usage
 		$html .= '<table summary="'.JText::_('&quot;and more&quot; Usage').'">'."\n";
-		$html .= "\t".'<caption>'.JText::_('Table 4: &quot;and more&quot; Usage').'</caption>'."\n";
+		$html .= "\t".'<caption>'.JText::_('Table '.++$tbl_cnt.': &quot;and more&quot; Usage').'</caption>'."\n";
 		$html .= "\t".'<thead>'."\n";
 		$html .= "\t\t".'<tr>'."\n";
 		$html .= "\t\t\t".'<th scope="col" rowspan="2">'.JText::_('Type').'</th>'."\n";
@@ -745,9 +771,10 @@ class plgUsageOverview extends JPlugin
 		$html .= "\t".'</tbody>'."\n";
 		$html .= '</table>'."\n";
 
+
 		// Collaboration Usage
 		$html .= '<table summary="'.JText::_('Collaboration Usage').'">'."\n";
-		$html .= "\t".'<caption>'.JText::_('Table 5: Collaboration Usage').'</caption>'."\n";
+		$html .= "\t".'<caption>'.JText::_('Table '.++$tbl_cnt.': Collaboration Usage').'</caption>'."\n";
 		$html .= "\t".'<tbody>'."\n";
 		$sql = "SELECT a.label,b.value,b.valfmt FROM summary_collab AS a, summary_collab_vals AS b WHERE a.id=b.rowid AND b.period = '".$period."' AND b.datetime = '".$datetime."' ORDER BY a.id";
 		$db->setQuery( $sql );
@@ -775,9 +802,10 @@ class plgUsageOverview extends JPlugin
 		$html .= "\t".'</tbody>'."\n";
 		$html .= '</table>'."\n";
 
+	*/
 
 		$html .= '<table summary="'.JText::_('User statistics by registered/unregistered').'">'."\n";
-		$html .= "\t".'<caption><a name="tot"></a>'.JText::_('Table 6: User statistics by registered/unregistered').'</caption>'."\n";
+		$html .= "\t".'<caption><a name="tot"></a>'.JText::_('Table '.++$tbl_cnt.': User statistics by registered/unregistered').'</caption>'."\n";
 		$html .= "\t".'<thead>'."\n";
 		$html .= "\t\t".'<tr>'."\n";
 		$html .= "\t\t\t".'<th scope="col" rowspan="2" colspan="2">'.JText::_('Users').'</th>'."\n";
@@ -868,4 +896,4 @@ class plgUsageOverview extends JPlugin
 		return $html;
 	}
 }
-?>
+?>
\ No newline at end of file
