@@ -1,25 +1,29 @@
 <?php
 /**
- * @package		HUBzero CMS
- * @author		Shawn Rice <zooley@purdue.edu>
- * @copyright	Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906
- * @license		http://www.gnu.org/licenses/gpl-2.0.html GPLv2
+ * @package     hubzero-cms
+ * @author      Shawn Rice <zooley@purdue.edu>
+ * @copyright   Copyright 2005-2011 Purdue University. All rights reserved.
+ * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright 2005-2009 by Purdue Research Foundation, West Lafayette, IN 47906.
- * All rights reserved.
+ * Copyright 2005-2011 Purdue University. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License,
- * version 2 as published by the Free Software Foundation.
+ * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
  *
- * This program is distributed in the hope that it will be useful,
+ * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+ * software: you can redistribute it and/or modify it under the terms of
+ * the GNU Lesser General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
+ *
+ * HUBzero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * HUBzero is a registered trademark of Purdue University.
  */
 
 // Check to ensure this file is included in Joomla!
@@ -101,7 +105,7 @@ class plgUsageTools extends JPlugin
 					}
 					$html .= "\t\t".'<tr class="'.$cls.'">'."\n";
 					$html .= "\t\t\t".'<td>'.$row->rank.'</td>'."\n";
-					$html .= "\t\t\t".'<td class="textual-data"><a href="'.JRoute::_('index.php?option='.$this->_option.'&task=tools&id='.$name[0].'&period='.$period).'">'.$name[1].'</a></td>'."\n";
+					$html .= "\t\t\t".'<td class="textual-data"><a href="'.JRoute::_('index.php?option=com_resources&id='.$name[0].'&active=usage').'">'.$name[1].'</a></td>'."\n";
 					$html .= "\t\t\t".'<td>'.$value.'</td>'."\n";
 					$html .= "\t\t\t".'<td>'.round((($row->value/$total)*100),2).'%</td>'."\n";
 					$html .= "\t\t".'</tr>'."\n";
@@ -170,7 +174,7 @@ class plgUsageTools extends JPlugin
 	{
 		$html = '';
 		
-		$sql = 'SELECT COUNT(DISTINCT c.id) FROM #__resources r, #__citations c, #__citations_assoc ca WHERE r.id = ca.oid AND ca.cid = c.id AND ca.table = "resource" AND r.type = "7" AND standalone = "1"';
+		$sql = 'SELECT COUNT(DISTINCT c.id) FROM #__resources r, #__citations c, #__citations_assoc ca WHERE r.id = ca.oid AND ca.cid = c.id AND ca.table = "resource" AND r.type = "7" AND standalone = "1" AND published = "1"';
 		$database->setQuery( $sql );
 		$result = $database->loadResult();
 		
@@ -192,7 +196,7 @@ class plgUsageTools extends JPlugin
 		}
 		
 		$count = 1;
-		$sql = 'SELECT DISTINCT r.id, r.title, r.published, COUNT(c.id) AS citations FROM #__resources r, #__citations c, #__citations_assoc ca WHERE r.id = ca.oid AND ca.cid = c.id AND ca.table = "resource" AND r.type = "7" AND standalone = "1" GROUP BY r.id ORDER BY citations DESC';
+		$sql = 'SELECT DISTINCT r.id, r.title, r.published, COUNT(c.id) AS citations FROM #__resources r, #__citations c, #__citations_assoc ca WHERE r.id = ca.oid AND ca.cid = c.id AND ca.table = "resource" AND r.type = "7" AND standalone = "1" AND published = "1" GROUP BY r.id ORDER BY citations DESC';
 		$database->setQuery( $sql );
 		$results = $database->loadObjectList();
 		
@@ -520,7 +524,7 @@ class plgUsageTools extends JPlugin
 		// Incoming
 		$period = JRequest::getVar( 'period', '12' );
 		$dthis  = JRequest::getVar( 'dthis', date('Y').'-'.date('m') );
-		$s_top  = JRequest::getVar( 'top', '1' );
+		$s_top  = JRequest::getVar( 'top', '2' );
 
 		// Build the HTML
 		$html  = $this->navlinks($period, $s_top);
@@ -572,4 +576,4 @@ class plgUsageTools extends JPlugin
 		return $html;
 	}
 }
-?>
+
